@@ -30,6 +30,7 @@
 #include "bstprocedure.h"
 #include "bstprojectctrl.h"
 #include "bstprofiler.h"
+#include "bstusermessage.h"
 #include <string.h>
 
 
@@ -69,6 +70,13 @@ enum {
   ACTION_URL_BEAST_SITE,
   ACTION_URL_ONLINE_SYNTHESIZERS,
   ACTION_URL_ONLINE_DEMOS,
+  ACTION_DEMO_DIALOG_FATAL,
+  ACTION_DEMO_DIALOG_ERROR,
+  ACTION_DEMO_DIALOG_WARNING,
+  ACTION_DEMO_DIALOG_SCRIPT,
+  ACTION_DEMO_DIALOG_INFO,
+  ACTION_DEMO_DIALOG_DIAG,
+  ACTION_DEMO_DIALOG_DEBUG,
 };
 static const GxkStockAction file_open_actions[] = {
   { N_("_New"),                 "<ctrl>N",      N_("Create new project"),
@@ -176,10 +184,25 @@ static const GxkStockAction online_synthesizers[] = {
     ACTION_URL_ONLINE_SYNTHESIZERS, BST_STOCK_ONLINE_SOUND_ARCHIVE },
 };
 static const GxkStockAction online_demos[] = {
-  { N_("Online Demos..."),          NULL,           N_("Start a web browser pointing to online demo songs"),
+  { N_("Online Demos..."),      NULL,           N_("Start a web browser pointing to online demo songs"),
     ACTION_URL_ONLINE_DEMOS,        BST_STOCK_ONLINE_SOUND_ARCHIVE },
 };
-
+static const GxkStockAction demo_dialogs[] = {
+  { "Demo Fatal Error Dialog",  NULL,           "Fire up a fatal error dialog for demonstration purposes",
+    ACTION_DEMO_DIALOG_FATAL,   BST_STOCK_ERROR },
+  { "Demo Error Dialog",        NULL,           "Fire up an error dialog for demonstration purposes",
+    ACTION_DEMO_DIALOG_ERROR,   BST_STOCK_ERROR },
+  { "Demo Warning Dialog",      NULL,           "Fire up a warning dialog for demonstration purposes",
+    ACTION_DEMO_DIALOG_WARNING, BST_STOCK_WARNING },
+  { "Demo Script Dialog",       NULL,           "Fire up a script dialog for demonstration purposes",
+    ACTION_DEMO_DIALOG_SCRIPT,  BST_STOCK_EXECUTE },
+  { "Demo Info Dialog",         NULL,           "Fire up an information dialog for demonstration purposes",
+    ACTION_DEMO_DIALOG_INFO,    BST_STOCK_INFO },
+  { "Demo Diag Dialog",         NULL,           "Fire up a diagnostics dialog for demonstration purposes",
+    ACTION_DEMO_DIALOG_DIAG,    BST_STOCK_DIAG },
+  { "Demo Debug Dialog",        NULL,           "Fire up a debug dialog for demonstration purposes",
+    ACTION_DEMO_DIALOG_DEBUG,   BST_STOCK_DIAG },
+};
 
 /* --- variables --- */
 static BstAppClass    *bst_app_class = NULL;
@@ -249,6 +272,9 @@ bst_app_init (BstApp *self)
                               NULL, app_action_check, app_action_exec);
   gxk_widget_publish_actions (self, "online-demos", G_N_ELEMENTS (online_demos), online_demos,
                               NULL, app_action_check, app_action_exec);
+  if (BST_DVL_HINTS)
+    gxk_widget_publish_actions (self, "demo-dialogs", G_N_ELEMENTS (demo_dialogs), demo_dialogs,
+                                NULL, app_action_check, app_action_exec);
   /* Project utilities */
   cseq = bse_categories_match ("/Project/*");
   al1 = bst_action_list_from_cats (cseq, 1, BST_STOCK_EXECUTE, NULL, bst_app_run_script_proc, self);
@@ -612,14 +638,29 @@ static gboolean
 bst_app_handle_delete_event (GtkWidget   *widget,
                              GdkEventAny *event)
 {
-  BstApp *app;
-  
-  g_return_val_if_fail (BST_IS_APP (widget), FALSE);
-  
-  app = BST_APP (widget);
-  
-  gtk_widget_destroy (widget);
-  
+  BstApp *self = BST_APP (widget);
+  if (bse_project_is_dirty (self->project))
+    {
+      guint result = bst_msg_dialog (BST_MSG_WARNING,
+                                     BST_MSG_TITLE (_("Close %s"), bse_item_get_name (self->project)),
+                                     BST_MSG_TEXT1 (_("The project has been modified.")),
+                                     BST_MSG_TEXT2 (_("Changes were made to project \"%s\" since the last time it was saved to disk."),
+                                                    bse_item_get_name (self->project)),
+                                     BST_MSG_TEXT2 (_("Save the project before closing its window?")),
+                                     BST_MSG_CHOICE   (2, _("Save Changes"), BST_STOCK_SAVE),
+                                     BST_MSG_CHOICE   (1, _("Discard Changes"), BST_STOCK_DELETE),
+                                     BST_MSG_CHOICE_D (0, _("Cancel"), BST_STOCK_CANCEL));
+      if (result == 1)
+        gtk_widget_destroy (widget);
+      else if (result == 2)
+        {
+          GtkWidget *fdialog = bst_file_dialog_popup_save_project (self, self->project, FALSE, TRUE);
+          if (!fdialog)
+            gtk_widget_destroy (widget);
+        }
+    }
+  else
+    gtk_widget_destroy (widget);
   return TRUE;
 }
 
@@ -691,7 +732,7 @@ demo_play_song (gpointer data,
 {
   const gchar *file_name = demo_entries[callback_action - BST_ACTION_LOAD_DEMO_0000].file;
   SfiProxy project = bse_server_use_new_project (BSE_SERVER, file_name);
-  BseErrorType error = bst_project_restore_from_file (project, file_name);
+  BseErrorType error = bst_project_restore_from_file (project, file_name, TRUE);
   if (error)
     bst_status_eprintf (error, _("Opening project `%s'"), file_name);
   else
@@ -788,12 +829,12 @@ bst_app_run_script_proc (gpointer data,
   if (BSE_IS_SONG (super))
     song = "song";
   else if (BSE_IS_WAVE_REPO (super))
-    wave_repo = "wrepo";
+    wave_repo = "wave-repo";
   else if (BSE_IS_SNET (super))
     {
-      snet = "snet";
+      snet = "synth-net";
       if (BSE_IS_CSYNTH (super))
-        csynth = "csynth";
+        csynth = "custom-synth";
     }
   
   bst_procedure_exec_auto (cat->type,
@@ -828,6 +869,7 @@ app_action_exec (gpointer data,
     {
       SfiProxy proxy;
       GtkWidget *any;
+      guint demo_type;
     case BST_ACTION_EXIT:
       if (bst_app_class)
         {
@@ -864,8 +906,10 @@ app_action_exec (gpointer data,
       bst_file_dialog_popup_import_midi (self, self->project);
       break;
     case BST_ACTION_SAVE_PROJECT:
+      bst_file_dialog_popup_save_project (self, self->project, FALSE, TRUE);
+      break;
     case BST_ACTION_SAVE_PROJECT_AS:
-      bst_file_dialog_popup_save_project (self, self->project);
+      bst_file_dialog_popup_save_project (self, self->project, TRUE, TRUE);
       break;
     case BST_ACTION_MERGE_EFFECT:
       bst_file_dialog_popup_merge_effect (self, self->project);
@@ -1075,6 +1119,33 @@ app_action_exec (gpointer data,
     case ACTION_URL_ONLINE_DEMOS:
       gxk_show_url ("http://beast.gtk.org/browse-bse-files.html");
       break;
+    case ACTION_DEMO_DIALOG_FATAL:
+    case ACTION_DEMO_DIALOG_ERROR:
+    case ACTION_DEMO_DIALOG_WARNING:
+    case ACTION_DEMO_DIALOG_SCRIPT:
+    case ACTION_DEMO_DIALOG_INFO:
+    case ACTION_DEMO_DIALOG_DIAG:
+    case ACTION_DEMO_DIALOG_DEBUG:
+      switch (action)
+        {
+        default: /* silence compiler */
+        case ACTION_DEMO_DIALOG_FATAL:   demo_type = BST_MSG_FATAL;   break;
+        case ACTION_DEMO_DIALOG_ERROR:   demo_type = BST_MSG_ERROR;   break;
+        case ACTION_DEMO_DIALOG_WARNING: demo_type = BST_MSG_WARNING; break;
+        case ACTION_DEMO_DIALOG_SCRIPT:  demo_type = BST_MSG_SCRIPT;  break;
+        case ACTION_DEMO_DIALOG_INFO:    demo_type = BST_MSG_INFO;    break;
+        case ACTION_DEMO_DIALOG_DIAG:    demo_type = BST_MSG_DIAG;    break;
+        case ACTION_DEMO_DIALOG_DEBUG:   demo_type = BST_MSG_DEBUG;   break;
+        }
+      bst_msg_dialog (demo_type,
+                      SFI_MSG_TEXT0 ("Demonstration Dialog"),
+                      SFI_MSG_TEXT1 ("This is a demonstrative dialog"),
+                      SFI_MSG_TEXT2 ("To help with dialog layout, and to test message display, dialogs may be "
+                                     "fired up for pure demonstration purposes. This is such a dialog, so if you "
+                                     "are currently looking at a prominent warning or error message, there's no "
+                                     "real merit to it."),
+                      SFI_MSG_TEXT3 ("Demo-Dialog-Type: %s", sfi_msg_type_label (demo_type)));
+      break;
     default:
       g_assert_not_reached ();
       break;
@@ -1091,7 +1162,8 @@ app_action_check (gpointer data,
                   guint64  action_stamp)
 {
   BstApp *self = BST_APP (data);
-  
+  if (!self->project)
+    return FALSE;
   switch (action)
     {
       SfiProxy super;
@@ -1101,12 +1173,13 @@ app_action_check (gpointer data,
     case BST_ACTION_OPEN_PROJECT:
     case BST_ACTION_MERGE_PROJECT:
     case BST_ACTION_IMPORT_MIDI:
-    case BST_ACTION_SAVE_PROJECT:
     case BST_ACTION_SAVE_PROJECT_AS:
     case BST_ACTION_NEW_CSYNTH:
     case BST_ACTION_NEW_MIDI_SYNTH:
     case BST_ACTION_CLOSE_PROJECT:
       return TRUE;
+    case BST_ACTION_SAVE_PROJECT:
+      return bse_project_is_dirty (self->project);
     case BST_ACTION_NEW_SONG:
       iseq = bse_container_list_children (self->project);
       for (i = 0; i < iseq->n_items; i++)
@@ -1158,6 +1231,13 @@ app_action_check (gpointer data,
     case ACTION_URL_BEAST_SITE:
     case ACTION_URL_ONLINE_SYNTHESIZERS:
     case ACTION_URL_ONLINE_DEMOS:
+    case ACTION_DEMO_DIALOG_FATAL:
+    case ACTION_DEMO_DIALOG_ERROR:
+    case ACTION_DEMO_DIALOG_WARNING:
+    case ACTION_DEMO_DIALOG_SCRIPT:
+    case ACTION_DEMO_DIALOG_INFO:
+    case ACTION_DEMO_DIALOG_DIAG:
+    case ACTION_DEMO_DIALOG_DEBUG:
       return TRUE;
     case BST_ACTION_EXIT:
       /* abuse generic "Exit" update to sync Tools menu items */
