@@ -33,7 +33,7 @@
 #include <string.h>
 #include <sys/time.h>
 #include <sys/resource.h>
-#include "sfi/toyprof-mem.h"
+// #include "sfi/toyprof-mem.h"
 
 
 /* --- prototypes --- */
@@ -96,14 +96,13 @@ main (int   argc,
   setlocale (LC_ALL, "");
 
   /* initialize GLib guts */
-  if (0)
-    toyprof_init_glib_memtable ("/tmp/beast-leak.debug", 10 /* SIGUSR1 */);
+  // toyprof_init_glib_memtable ("/tmp/beast-leak.debug", 10 /* SIGUSR1 */);
   g_thread_init (NULL);
   g_type_init ();
 
   /* initialize Sfi guts */
   sfi_init ();
-  sfi_debug_allow ("misc");
+  sfi_msg_allow ("misc");
   /* ensure SFI can wake us up */
   sfi_thread_set_name ("Beast GUI");
   sfi_thread_set_wakeup ((SfiThreadWakeup) g_main_context_wakeup,
@@ -250,11 +249,11 @@ main (int   argc,
 
   /* listen to BseServer notification */
   bst_splash_update_entity (beast_splash, _("Dialogs"));
-  bst_catch_scripts_and_msgs ();
+  bst_message_connect_to_server ();
   _bst_init_radgets ();
 
   /* install message dialog handler */
-  sfi_log_set_thread_handler (bst_user_message_log_handler);
+  sfi_msg_set_thread_handler (bst_message_log_handler);
 
   /* open files given on command line */
   if (argc > 1)
@@ -301,7 +300,7 @@ main (int   argc,
 
       /* load projects */
       project = bse_server_use_new_project (BSE_SERVER, argv[i]);
-      error = bst_project_restore_from_file (project, argv[i]);
+      error = bst_project_restore_from_file (project, argv[i], TRUE);
       
       if (!error)
 	{
@@ -352,8 +351,8 @@ main (int   argc,
     }
   
   /* take down GUI */
-  sfi_log_set_thread_handler (NULL);
-  bst_user_messages_kill ();
+  sfi_msg_set_thread_handler (NULL);
+  bst_message_dialogs_popdown ();
   
   /* perform necessary cleanup cycles */
   GDK_THREADS_LEAVE ();
@@ -405,16 +404,16 @@ bst_early_parse_args (int    *argc_p,
   
   envar = getenv ("BST_DEBUG");
   if (envar)
-    sfi_debug_allow (envar);
+    sfi_msg_allow (envar);
   envar = getenv ("BST_NO_DEBUG");
   if (envar)
-    sfi_debug_deny (envar);
+    sfi_msg_deny (envar);
   envar = getenv ("BEAST_DEBUG");
   if (envar)
-    sfi_debug_allow (envar);
+    sfi_msg_allow (envar);
   envar = getenv ("BEAST_NO_DEBUG");
   if (envar)
-    sfi_debug_deny (envar);
+    sfi_msg_deny (envar);
 
   gboolean initialize_bse_and_exit = FALSE;
   for (i = 1; i < argc; i++)
@@ -468,11 +467,14 @@ bst_early_parse_args (int    *argc_p,
 	}
       else if (strcmp ("--debug-list", argv[i]) == 0)
 	{
-	  const gchar **keys = _bst_log_debug_keys ();
+	  const BstMsgID *mids = bst_message_list_types (NULL);
 	  guint j;
-	  g_print ("debug keys: all");
-	  for (j = 0; keys[j]; j++)
-	    g_print (":%s", keys[j]);
+	  g_print ("BEAST debug keys: all");
+	  for (j = 0; mids[j].ident; j++)
+            if (mids[j].type >= SFI_MSG_DEBUG && mids[j].label)
+              g_print (", %s (%s)", mids[j].ident, mids[j].label);
+            else if (mids[j].type >= SFI_MSG_DEBUG)
+              g_print (", %s", mids[j].ident);
 	  g_print ("\n");
 	  exit (0);
 	  argv[i] = NULL;
@@ -483,11 +485,11 @@ bst_early_parse_args (int    *argc_p,
 	  gchar *equal = argv[i] + 7;
 	  
 	  if (*equal == '=')
-            sfi_debug_allow (equal + 1);
+            sfi_msg_allow (equal + 1);
 	  else if (i + 1 < argc)
 	    {
 	      argv[i++] = NULL;
-	      sfi_debug_allow (argv[i]);
+	      sfi_msg_allow (argv[i]);
 	    }
 	  argv[i] = NULL;
 	}
@@ -497,11 +499,11 @@ bst_early_parse_args (int    *argc_p,
 	  gchar *equal = argv[i] + 7;
 	  
 	  if (*equal == '=')
-            sfi_debug_deny (equal + 1);
+            sfi_msg_deny (equal + 1);
 	  else if (i + 1 < argc)
 	    {
 	      argv[i++] = NULL;
-	      sfi_debug_deny (argv[i]);
+	      sfi_msg_deny (argv[i]);
 	    }
 	  argv[i] = NULL;
 	}
@@ -793,7 +795,9 @@ beast_show_about_box (void)
     "Dulmandakh Sukhbaatar",
     "Francisco Javier F. Serrador",
     "Gareth Owen",
+    "Hizkuntza Politikarako Sailburuordetza",
     "Iassen Pramatarov",
+    // "I\xc3\261aki Larra\xc3\261aga Murgotio",
     "Ismael Andres Rubio Rojas",
     "Jorge Gonzalez",
     "Kees van den Broek",
