@@ -51,7 +51,7 @@ bst_preferences_init (BstPreferences *self)
   GtkWidget *pchild;
   SfiRec *rec;
   
-  self->notebook = g_object_new (GTK_TYPE_NOTEBOOK,
+  self->notebook = g_object_new (GXK_TYPE_NOTEBOOK,
                                  "visible", TRUE,
                                  "parent", self,
                                  "tab_pos", GTK_POS_TOP,
@@ -60,9 +60,6 @@ bst_preferences_init (BstPreferences *self)
                                  "border_width", 5,
                                  NULL);
   gxk_nullify_in_object (self, &self->notebook);
-  g_object_connect (self->notebook,
-		    "signal_after::switch-page", gxk_widget_viewable_changed, NULL,
-		    NULL);
   
   pspec = bst_gconfig_pspec ();
   self->rec_gconfig = bst_gconfig_to_rec (bst_gconfig_get_global ());
@@ -383,30 +380,23 @@ bst_preferences_create_buttons (BstPreferences *self,
                                   "swapped_signal::clicked", bst_preferences_save, self,
                                   "swapped_signal::destroy", g_nullify_pointer, &self->apply,
                                   NULL);
-  gtk_tooltips_set_tip (GXK_TOOLTIPS, self->apply,
-			"Apply and save the preference values. Some values may only take effect after "
-			"restart while others can be locked against modifcation during "
-			"playback.",
-			NULL);
+  gxk_widget_set_tooltip (self->apply,
+                          "Apply and save the preference values. Some values may only take effect after "
+                          "restart while others can be locked against modifcation during "
+                          "playback.");
   
   /* Revert
    */
   widget = gxk_dialog_action_swapped (dialog, BST_STOCK_REVERT, bst_preferences_revert, self);
-  gtk_tooltips_set_tip (GXK_TOOLTIPS, widget,
-			"Revert to the currently active values.",
-			NULL);
+  gxk_widget_set_tooltip (widget, "Revert to the currently active values.");
   
   /* Default Revert
    */
   widget = gxk_dialog_action_swapped (dialog, BST_STOCK_DEFAULT_REVERT, bst_preferences_default_revert, self);
-  gtk_tooltips_set_tip (GXK_TOOLTIPS, widget,
-			"Revert to hardcoded default values (factory settings).",
-			NULL);
+  gxk_widget_set_tooltip (widget, "Revert to hardcoded default values (factory settings).");
   
   /* Close
    */
   widget = gxk_dialog_action (dialog, BST_STOCK_CLOSE, gxk_toplevel_delete, NULL);
-  gtk_tooltips_set_tip (GXK_TOOLTIPS, widget,
-			"Discard changes and close dialog.",
-			NULL);
+  gxk_widget_set_tooltip (widget, "Discard changes and close dialog.");
 }
