@@ -19,6 +19,7 @@
 #include "bstparam.h"
 #include "bstgrowbar.h"
 #include "bsttracksynthdialog.h"
+#include "bstitemseqdialog.h"
 #include <stdlib.h> /* strtol */
 #include <string.h>
 
@@ -46,6 +47,7 @@ enum {
   COL_VOICES,
   COL_SYNTH,
   COL_MIDI_CHANNEL,
+  COL_OUTPUTS,
   COL_POST_SYNTH,
   COL_BLURB,
   N_COLS
@@ -59,7 +61,7 @@ enum {
 };
 static const GxkStockAction track_view_actions[] = {
   { N_("Add"),            NULL,         N_("Add a new track to this song"),
-    ACTION_ADD_TRACK,     BST_STOCK_TRACK,
+    ACTION_ADD_TRACK,     BST_STOCK_TRACKS_ADD,
   },
   { N_("Delete"),         NULL,         N_("Delete the currently selected track"),
     ACTION_DELETE_TRACK,  BST_STOCK_TRASHCAN,
@@ -75,13 +77,13 @@ bst_track_view_class_init (BstTrackViewClass *class)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (class);
   BstItemViewClass *item_view_class = BST_ITEM_VIEW_CLASS (class);
-
+  
   gobject_class->finalize = bst_track_view_finalize;
-
+  
   item_view_class->set_container = track_view_set_container;
   item_view_class->listen_on = track_view_listen_on;
   item_view_class->unlisten_on = track_view_unlisten_on;
-
+  
   item_view_class->item_type = "BseTrack";
 }
 
@@ -89,10 +91,10 @@ static void
 bst_track_view_finalize (GObject *object)
 {
   BstTrackView *self = BST_TRACK_VIEW (object);
-
+  
   if (self->tctrl)
     bst_track_roll_controller_unref (self->tctrl);
-
+  
   G_OBJECT_CLASS (bst_track_view_parent_class)->finalize (object);
 }
 
@@ -131,6 +133,8 @@ track_view_fill_value (BstItemView *iview,
       gboolean vbool;
       SfiInt vint;
       SfiProxy item, snet, wave;
+      BseItemSeq *iseq;
+      SfiSeq *seq;
     case COL_SEQID:
       sfi_value_take_string (value, g_strdup_printf ("%03d", seqid));
       break;
@@ -159,6 +163,18 @@ track_view_fill_value (BstItemView *iview,
       bse_proxy_get (item, "midi-channel", &vint, NULL);
       sfi_value_take_string (value, g_strdup_printf ("%2d", vint));
       break;
+    case COL_OUTPUTS:
+      item = bse_container_get_item (iview->container, BST_ITEM_VIEW_GET_CLASS (self)->item_type, seqid);
+      bse_proxy_get (item, "outputs", &seq, NULL);
+      iseq = bse_item_seq_from_seq (seq);
+      if (iseq && iseq->n_items == 1)
+        g_value_take_string (value, g_strdup_printf ("%s", bse_item_get_name_or_type (iseq->items[0])));
+      else if (iseq && iseq->n_items > 1)
+        g_value_take_string (value, g_strdup_printf ("#%u", iseq ? iseq->n_items : 0));
+      else
+        g_value_set_string (value, "");
+      bse_item_seq_free (iseq);
+      break;
     case COL_POST_SYNTH:
       item = bse_container_get_item (iview->container, BST_ITEM_VIEW_GET_CLASS (self)->item_type, seqid);
       snet = 0;
@@ -179,7 +195,7 @@ track_view_synth_edited (BstTrackView *self,
 			 const gchar  *text)
 {
   g_return_if_fail (BST_IS_TRACK_VIEW (self));
-
+  
   if (strpath)
     {
       gint row = gxk_tree_spath_index0 (strpath);
@@ -189,8 +205,10 @@ track_view_synth_edited (BstTrackView *self,
 	  SfiProxy proxy = 0;
 	  GSList *slist = NULL;
 	  /* list possible snet/wave candidates */
-	  slist = g_slist_append (slist, bse_item_list_items (item, "snet"));
-	  slist = g_slist_append (slist, bse_item_list_items (item, "wave"));
+          BsePropertyCandidates *pc = bse_item_get_property_candidates (item, "snet");
+	  slist = g_slist_append (slist, pc->items);
+          pc = bse_item_get_property_candidates (item, "wave");
+	  slist = g_slist_append (slist, pc->items);
 	  /* find best match */
 	  proxy = bst_item_seq_list_match (slist, text);
 	  g_slist_free (slist);
@@ -212,7 +230,7 @@ track_view_post_synth_edited (BstTrackView *self,
                               const gchar  *text)
 {
   g_return_if_fail (BST_IS_TRACK_VIEW (self));
-
+  
   if (strpath)
     {
       gint row = gxk_tree_spath_index0 (strpath);
@@ -222,7 +240,8 @@ track_view_post_synth_edited (BstTrackView *self,
 	  SfiProxy proxy = 0;
 	  GSList *slist = NULL;
 	  /* list possible snet candidates */
-	  slist = g_slist_append (slist, bse_item_list_items (item, "pnet"));
+          BsePropertyCandidates *pc = bse_item_get_property_candidates (item, "pnet");
+	  slist = g_slist_append (slist, pc->items);
 	  /* find best match */
 	  proxy = bst_item_seq_list_match (slist, text);
 	  g_slist_free (slist);
@@ -236,15 +255,29 @@ track_view_post_synth_edited (BstTrackView *self,
     }
 }
 
+typedef struct {
+  BstTrackView         *self;
+  GxkCellRendererPopup *pcell;
+} SynthPopup;
+
 static void
-track_view_synth_popup_cb (GxkCellRendererPopup *pcell,
+track_view_synth_popup_cleanup (gpointer data)
+{
+  SynthPopup *sdata = data;
+  gxk_cell_renderer_popup_change (sdata->pcell, NULL, FALSE, TRUE);
+  g_free (sdata);
+}
+
+static void
+track_view_synth_popup_cb (gpointer              data,
                            SfiProxy              proxy,
                            BstTrackSynthDialog  *tsdialog)
 {
-  gxk_cell_renderer_enter (pcell,
-                           proxy ? bse_item_get_uname_path (proxy) : "",
-                           FALSE,
-                           proxy == 0);
+  SynthPopup *sdata = data;
+  gxk_cell_renderer_popup_change (sdata->pcell,
+                                  proxy ? bse_item_get_uname_path (proxy) : "",
+                                  FALSE,
+                                  proxy == 0);
 }
 
 static void
@@ -254,17 +287,25 @@ track_view_synth_popup (BstTrackView         *self,
 			GxkCellRendererPopup *pcell)
 {
   g_return_if_fail (BST_IS_TRACK_VIEW (self));
-
+  
   if (strpath)
     {
       gint row = gxk_tree_spath_index0 (strpath);
       SfiProxy item = bst_item_view_get_proxy (BST_ITEM_VIEW (self), row);
-      BseItemSeq *iseq = bse_item_list_items (item, "snet");
-      GtkWidget *dialog = bst_track_synth_dialog_popup (self, item,
-                                                        iseq,
-                                                        bse_project_get_wave_repo (bse_item_get_project (item)),
-                                                        track_view_synth_popup_cb, pcell);
-      gxk_cell_renderer_popup_dialog (pcell, dialog);
+      if (bse_item_editable_property (item, "snet"))
+        {
+          BsePropertyCandidates *pc = bse_item_get_property_candidates (item, "snet");
+          SynthPopup sdata = { self, pcell, };
+          GtkWidget *dialog = bst_track_synth_dialog_popup (self, item,
+                                                            pc->label, pc->tooltip, pc->items,
+                                                            _("Available Waves"),
+                                                            _("List of available waves to choose a track instrument from"),
+                                                            bse_project_get_wave_repo (bse_item_get_project (item)),
+                                                            track_view_synth_popup_cb, g_memdup (&sdata, sizeof (sdata)), track_view_synth_popup_cleanup);
+          gxk_cell_renderer_popup_dialog (pcell, dialog);
+        }
+      else
+        gdk_beep();
     }
 }
 
@@ -275,14 +316,77 @@ track_view_post_synth_popup (BstTrackView         *self,
                              GxkCellRendererPopup *pcell)
 {
   g_return_if_fail (BST_IS_TRACK_VIEW (self));
-
+  
   if (strpath)
     {
       gint row = gxk_tree_spath_index0 (strpath);
       SfiProxy item = bst_item_view_get_proxy (BST_ITEM_VIEW (self), row);
-      BseItemSeq *iseq = bse_item_list_items (item, "pnet");
-      GtkWidget *dialog = bst_track_synth_dialog_popup (self, item, iseq, 0,
-                                                        track_view_synth_popup_cb, pcell);
+      if (bse_item_editable_property (item, "pnet"))
+        {
+          BsePropertyCandidates *pc = bse_item_get_property_candidates (item, "pnet");
+          SynthPopup sdata = { self, pcell, };
+          GtkWidget *dialog = bst_track_synth_dialog_popup (self, item,
+                                                            pc->label, pc->tooltip, pc->items,
+                                                            NULL, NULL, 0,
+                                                            track_view_synth_popup_cb, g_memdup (&sdata, sizeof (sdata)), track_view_synth_popup_cleanup);
+          gxk_cell_renderer_popup_dialog (pcell, dialog);
+        }
+      else
+        gdk_beep();
+    }
+}
+
+typedef struct {
+  BstTrackView         *self;
+  GxkCellRendererPopup *pcell;
+  SfiProxy              item;
+} OutputsPopup;
+
+static void
+track_view_outputs_cleanup (gpointer data)
+{
+  OutputsPopup *odata = data;
+  gxk_cell_renderer_popup_change (odata->pcell, NULL, FALSE, FALSE);
+  g_free (odata);
+}
+
+static void
+track_view_outputs_changed (gpointer              data,
+                            BseItemSeq           *iseq,
+                            BstItemSeqDialog     *isdialog)
+{
+  OutputsPopup *odata = data;
+  gxk_cell_renderer_popup_change (odata->pcell, NULL, FALSE, FALSE);
+  SfiSeq *seq = bse_item_seq_to_seq (iseq);
+  GValue *value = sfi_value_seq (seq);
+  sfi_seq_unref (seq);
+  bse_proxy_set_property (odata->item, "outputs", value);
+  sfi_value_free (value);
+}
+
+static void
+track_view_outputs_popup (BstTrackView         *self,
+                          const gchar          *strpath,
+                          const gchar          *text,
+                          GxkCellRendererPopup *pcell)
+{
+  g_return_if_fail (BST_IS_TRACK_VIEW (self));
+  
+  if (strpath)
+    {
+      gint row = gxk_tree_spath_index0 (strpath);
+      SfiProxy item = bst_item_view_get_proxy (BST_ITEM_VIEW (self), row);
+      BsePropertyCandidates *pc = bse_item_get_property_candidates (item, "outputs");
+      GParamSpec *pspec = bse_proxy_get_pspec (item, "outputs");
+      const GValue *value = bse_proxy_get_property (item, "outputs");
+      SfiSeq *seq = g_value_get_boxed (value);
+      BseItemSeq *iseq = bse_item_seq_from_seq (seq);
+      OutputsPopup odata = { self, pcell, item };
+      GtkWidget *dialog = bst_item_seq_dialog_popup (self, item,
+                                                     pc->label, pc->tooltip, pc->items,
+                                                     g_param_spec_get_nick (pspec), g_param_spec_get_blurb (pspec), iseq,
+                                                     track_view_outputs_changed, g_memdup (&odata, sizeof (odata)), track_view_outputs_cleanup);
+      bse_item_seq_free (iseq);
       gxk_cell_renderer_popup_dialog (pcell, dialog);
     }
 }
@@ -293,7 +397,7 @@ track_view_mute_toggled (BstTrackView          *self,
 			 GtkCellRendererToggle *tcell)
 {
   g_return_if_fail (BST_IS_TRACK_VIEW (self));
-
+  
   if (strpath)
     {
       gint row = gxk_tree_spath_index0 (strpath);
@@ -315,7 +419,7 @@ track_view_voice_edited (BstTrackView *self,
                          const gchar  *text)
 {
   g_return_if_fail (BST_IS_TRACK_VIEW (self));
-
+  
   if (strpath)
     {
       gint row = gxk_tree_spath_index0 (strpath);
@@ -335,7 +439,7 @@ track_view_midi_channel_edited (BstTrackView *self,
                                 const gchar  *text)
 {
   g_return_if_fail (BST_IS_TRACK_VIEW (self));
-
+  
   if (strpath)
     {
       gint row = gxk_tree_spath_index0 (strpath);
@@ -403,13 +507,13 @@ bst_track_view_init (BstTrackView *self)
   GtkTreeModel *smodel;
   GxkListWrapper *lwrapper;
   GxkRadget *radget;
-
+  
   /* create GUI */
   gxk_widget_publish_actions (self, "track-view-actions",
                               G_N_ELEMENTS (track_view_actions), track_view_actions,
                               NULL, track_view_action_check, track_view_action_exec);
   radget = gxk_radget_complete (GTK_WIDGET (self), "beast", "track-view", NULL);
-
+  
   /* item list model */
   lwrapper = gxk_list_wrapper_new (N_COLS,
 				   G_TYPE_STRING,	/* COL_SEQID */
@@ -418,6 +522,7 @@ bst_track_view_init (BstTrackView *self)
 				   G_TYPE_STRING,	/* COL_VOICES */
 				   G_TYPE_STRING,	/* COL_SYNTH */
 				   G_TYPE_STRING,	/* COL_MIDI_CHANNEL */
+				   G_TYPE_STRING,	/* COL_OUTPUTS */
 				   G_TYPE_STRING,	/* COL_POST_SYNTH */
 				   G_TYPE_STRING	/* COL_BLURB */
 				   );
@@ -442,7 +547,7 @@ bst_track_view_init (BstTrackView *self)
   gtk_tree_selection_set_mode (tsel, GTK_SELECTION_BROWSE);
   gxk_tree_selection_force_browse (tsel, smodel);
   g_object_unref (smodel);
-
+  
   /* track roll */
   self->troll = g_object_new (BST_TYPE_TRACK_ROLL,
                               "visible", TRUE,
@@ -453,7 +558,7 @@ bst_track_view_init (BstTrackView *self)
   gxk_scroll_canvas_set_vadjustment (GXK_SCROLL_CANVAS (self->troll), gtk_range_get_adjustment (GTK_RANGE (vscroll)));
   bst_track_roll_set_track_callback (self->troll, self, get_track);
   track_view_marks_changed (self);
-
+  
   /* link track roll to tree view and list model */
   g_signal_connect_object (tsel, "changed",
 			   G_CALLBACK (bst_track_roll_reselect),
@@ -467,7 +572,7 @@ bst_track_view_init (BstTrackView *self)
   g_signal_connect_object (iview->wlist, "row-change",
 			   G_CALLBACK (bst_track_roll_abort_edit),
 			   self->troll, G_CONNECT_SWAPPED);
-
+  
   /* track roll controller */
   self->tctrl = bst_track_roll_controller_new (self->troll);
   bst_track_roll_controller_set_song (self->tctrl, iview->container);
@@ -480,7 +585,7 @@ bst_track_view_init (BstTrackView *self)
   gxk_nullify_in_object (self, &self->repeat_toggle);
   g_object_connect (self->repeat_toggle, "swapped_signal::toggled", track_view_repeat_toggled, self, NULL);
   track_view_repeat_changed (self);
-
+  
   /* add zoom spinner */
   adjustment = gtk_adjustment_new (50, 1, 100, 1, 5, 0);
   g_object_connect (adjustment,
@@ -493,29 +598,32 @@ bst_track_view_init (BstTrackView *self)
                                 "digits", 0,
                                 "width_request", 2 * gxk_size_width (GXK_ICON_SIZE_TOOLBAR),
                                 NULL));
-
+  
   /* add list view columns */
   if (BST_DVL_HINTS)
     gxk_tree_view_add_text_column (iview->tree, COL_SEQID, "S",
                                    0.0, "ID", NULL,
                                    NULL, NULL, 0);
   gxk_tree_view_add_text_column (iview->tree, COL_NAME, "S",
-				 0.0, "Name", NULL,
+				 0.0, _("Name"), NULL,
 				 bst_item_view_name_edited, self, G_CONNECT_SWAPPED);
   gxk_tree_view_add_toggle_column (iview->tree, COL_MUTE, "",
-				   0.5, "M", "Notes from unchecked tracks are muted during playback",
+				   0.5, "M", _("Notes from unchecked tracks are ignored by the sequencer during playback"),
 				   track_view_mute_toggled, self, G_CONNECT_SWAPPED);
   gxk_tree_view_add_text_column (iview->tree, COL_VOICES, "",
-				 0.5, "V", "Maximum number of voices for simultaneous playback",
+				 0.5, "V", _("Maximum number of voices for simultaneous playback"),
 				 track_view_voice_edited, self, G_CONNECT_SWAPPED);
   gxk_tree_view_add_popup_column (iview->tree, COL_SYNTH, "#",
-				  0.5, "Synth", "Synthesizer network or wave to be used as voice by this track",
-				  track_view_synth_edited, track_view_synth_popup, self, G_CONNECT_SWAPPED);
+				  0.5, "Synth", _("Synthesis network or wave to be used as instrument by this track"),
+                                  track_view_synth_edited, track_view_synth_popup, self, G_CONNECT_SWAPPED);
   gxk_tree_view_add_text_column (iview->tree, COL_MIDI_CHANNEL, "",
-                                 0.5, "Ch", "Midi channel assigned to this track, 0 uses private per-track channel",
+                                 0.5, "Ch", _("Midi channel assigned to this track, 0 uses private per-track channel"),
                                  track_view_midi_channel_edited, self, G_CONNECT_SWAPPED);
-  gxk_tree_view_add_popup_column (iview->tree, COL_POST_SYNTH, "#",
-				  0.5, "Post", "Postprocessing Synthesizer network for this track",
+  gxk_tree_view_add_popup_column (iview->tree, COL_OUTPUTS, "#",
+				  0.5, "Outputs", _("Mixer busses connected to track output"),
+				  NULL, track_view_outputs_popup, self, G_CONNECT_SWAPPED);
+  gxk_tree_view_add_popup_column (iview->tree, COL_POST_SYNTH, "",
+				  0.5, "Post", _("Synthesis network to be used as postprocessor"),
 				  track_view_post_synth_edited, track_view_post_synth_popup, self, G_CONNECT_SWAPPED);
   gxk_tree_view_add_text_column (iview->tree, COL_BLURB, "",
 				 0.0, _("Comment"), NULL,
@@ -566,6 +674,7 @@ track_view_set_container (BstItemView *iview,
 			 "swapped_signal::property-notify::loop-enabled", track_view_repeat_changed, self,
 			 NULL);
       track_view_marks_changed (self);
+      track_view_repeat_changed (self);
     }
 }
 
@@ -592,6 +701,7 @@ track_view_listen_on (BstItemView *iview,
                      "signal::property-notify::n-voices", track_property_changed, iview, /* COL_VOICES */
                      "signal::property-notify::snet", track_property_changed, iview, /* COL_SYNTH */
                      "signal::property-notify::midi-channel", track_property_changed, iview, /* COL_MIDI_CHANNEL */
+                     "signal::property-notify::outputs", track_property_changed, iview, /* COL_OUTPUTS */
                      "signal::property-notify::pnet", track_property_changed, iview, /* COL_POST_SYNTH */
                      /* COL_BLURB handled by GxkListWrapper */
                      NULL);
@@ -615,10 +725,11 @@ track_view_action_exec (gpointer data,
   BstTrackView *self = BST_TRACK_VIEW (data);
   BstItemView *item_view = BST_ITEM_VIEW (self);
   SfiProxy song = item_view->container;
-
+  
   switch (action)
     {
       SfiProxy item;
+      guint i;
     case ACTION_ADD_TRACK:
       bse_item_group_undo (song, "Add Track");
       item = bse_song_create_track (song);
@@ -628,12 +739,19 @@ track_view_action_exec (gpointer data,
 	  bse_item_set_name (item, string);
 	  g_free (string);
 	  bst_item_view_select (item_view, item);
+          bse_track_ensure_output (item);
 	}
       bse_item_ungroup_undo (song);
       break;
     case ACTION_DELETE_TRACK:
       item = bst_item_view_get_current (item_view);
+      bse_item_group_undo (song, "Delete Track");
+      BseItemSeq *iseq = bse_track_list_parts_uniq (item);
       bse_song_remove_track (song, item);
+      for (i = 0; i < iseq->n_items; i++)
+        if (!bse_song_find_any_track_for_part (song, iseq->items[i]))
+          bse_song_remove_part (song, iseq->items[i]);
+      bse_item_ungroup_undo (song);
       break;
     }
   gxk_widget_update_actions_downwards (self);
