@@ -16,4 +16,4 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#include "bstxxutils.h"
+#include "bstxxutils.hh"
