@@ -75,6 +75,25 @@ gnome_canvas_typed_item_at (GnomeCanvas *canvas,
   return item && g_type_is_a (GTK_OBJECT_TYPE (item), item_type) ? item : NULL;
 }
 
+gboolean
+gnome_canvas_item_check_undisposed (GnomeCanvasItem *item)
+{
+  if (GNOME_IS_CANVAS_ITEM (item))
+    {
+      GnomeCanvasItem *parent = item;
+      if (!item->parent &&
+          (!GNOME_IS_CANVAS_GROUP (item) ||
+           !GNOME_CANVAS_GROUP (item)->item_list))
+        return FALSE;
+      while (parent->parent)
+        parent = parent->parent;
+      if (GNOME_IS_CANVAS (item->canvas) && item->canvas == parent->canvas &&
+          item->canvas->root == parent)
+        return TRUE;
+    }
+  return FALSE;
+}
+
 guint
 gnome_canvas_item_get_stacking (GnomeCanvasItem *item)
 {
@@ -170,7 +189,7 @@ gnome_canvas_text_set_zoom_size (GnomeCanvasText *item,
 {
   g_return_if_fail (GNOME_IS_CANVAS_TEXT (item));
 
-  g_object_set (item, "size_points", pixels, NULL);
+  g_object_set (item, "size_points", pixels * GNOME_CANVAS_ITEM(item)->canvas->pixels_per_unit, NULL);
   g_object_set_double (item, "zoom_size", pixels);
 }
 
