@@ -46,7 +46,7 @@ beauty_float (gdouble f)
   return c;
 }
 
-static GQuark  boxed_type_tag = 0;
+static GQuark boxed_type_tag = 0;
 
 static void
 tag_all_boxed_pspecs (void)
@@ -57,21 +57,21 @@ tag_all_boxed_pspecs (void)
   children = g_type_children (G_TYPE_BOXED, NULL);
   for (i = 0; children[i]; i++)
     {
-      const SfiBoxedRecordInfo *rinfo = sfi_boxed_get_record_info (children[i]);
-      const SfiBoxedSequenceInfo *sinfo = sfi_boxed_get_sequence_info (children[i]);
+      SfiRecFields rfields = sfi_boxed_type_get_rec_fields (children[i]);
+      GParamSpec *element = sfi_boxed_type_get_seq_element (children[i]);
 
-      if (sinfo && sinfo->element)
+      if (element)
 	{
-	  g_param_spec_ref (sinfo->element);
-	  g_param_spec_set_qdata (sinfo->element, boxed_type_tag, g_type_name (children[i]));
+	  g_param_spec_ref (element);
+	  g_param_spec_set_qdata (element, boxed_type_tag, g_type_name (children[i]));
 	}
-      else if (rinfo)
+      else if (rfields.n_fields)
 	{
 	  guint j;
-	  for (j = 0; j < rinfo->fields.n_fields; j++)
+	  for (j = 0; j < rfields.n_fields; j++)
 	    {
-	      g_param_spec_ref (rinfo->fields.fields[j]);
-	      g_param_spec_set_qdata (rinfo->fields.fields[j], boxed_type_tag, g_type_name (children[i]));
+	      g_param_spec_ref (rfields.fields[j]);
+	      g_param_spec_set_qdata (rfields.fields[j], boxed_type_tag, g_type_name (children[i]));
 	    }
 	}
     }
@@ -296,15 +296,15 @@ show_structdoc (void)
   for (i = 0; children[i]; i++)
     {
       GType type = children[i];
-      const SfiBoxedRecordInfo *rinfo = sfi_boxed_get_record_info (type);
-      const SfiBoxedSequenceInfo *sinfo = sfi_boxed_get_sequence_info (type);
+      SfiRecFields rfields = sfi_boxed_type_get_rec_fields (type);
+      GParamSpec *element = sfi_boxed_type_get_seq_element (type);
 
-      if (rinfo || sinfo)
+      if (element || rfields.n_fields)
 	{
 	  const gchar *name = g_type_name (type);
 	  gchar *cname = g_type_name_to_cname (name);
 	  gchar *sname = g_type_name_to_sname (name);
-	  const gchar *dname = rinfo ? "record" : "sequence";
+	  const gchar *dname = rfields.n_fields ? "record" : "sequence";
 	  const gchar *cstring;
 	  SfiRing *ring, *pspecs = NULL;
 	  guint j;
@@ -312,19 +312,20 @@ show_structdoc (void)
 	  g_print ("@item @anchor{%s}@refStructType{%s} @refStructName{%s} @refStructOpen ", name, dname, name);
 
 	  g_print ("@findex @refStructType{%s}@ @refStructName{%s};", dname, name);
-	  cstring = sfi_info_string_find (rinfo ? rinfo->infos : sinfo->infos, "BLURB");
+#if 0
+	  cstring = bse_type_get_blurb (type);
 	  if (cstring)
 	    g_print (" - @refBlurb{%s}", cstring);
+#endif
 	  g_print ("\n");
 
-	  if (rinfo)
-	    for (j = 0; j < rinfo->fields.n_fields; j++)
-	      pspecs = sfi_ring_append (pspecs, rinfo->fields.fields[j]);
-	  else
-	    pspecs = sfi_ring_append (pspecs, sinfo->element);
+          for (j = 0; j < rfields.n_fields; j++)
+            pspecs = sfi_ring_append (pspecs, rfields.fields[j]);
+          if (element)
+	    pspecs = sfi_ring_append (pspecs, element);
 
 	  g_print ("@multitable @columnfractions .3 .3 .3\n");
-	  if (sinfo)
+	  if (element)
 	    {
 	      GParamSpec *pspec = pspecs->data;
 	      gchar *carg = g_type_name_to_cname (pspec->name);
@@ -341,7 +342,7 @@ show_structdoc (void)
 	      const gchar *nick = g_param_spec_get_nick (pspec);
 	      gchar *carg = g_type_name_to_cname (pspec->name);
 	      g_print ("@item @refType{%s%s} @tab @refParameter{%s}; @tab %s\n",
-		       tname, sinfo ? "*" : "",
+		       tname, element ? "*" : "",
 		       carg, blurb ? blurb : nick ? nick : "");
 	      g_free (tname);
 	      g_free (carg);
@@ -349,11 +350,21 @@ show_structdoc (void)
 	  g_print ("@end multitable\n");
 	  g_print ("@refStructClose\n");
 
-	  cstring = sfi_info_string_find (rinfo ? rinfo->infos : sinfo->infos, "HELP");
+	  cstring = bse_type_get_blurb (type);
 	  if (cstring)
 	    g_print ("\n%s\n", cstring);
 	  g_print ("\n");
 
+          cstring = bse_type_get_authors (type);
+          if (cstring)
+            g_print ("\n%s %s\n", _("Authors:"), cstring);
+          g_print ("\n");
+
+          cstring = bse_type_get_license (type);
+          if (cstring)
+            g_print ("\n%s %s\n", _("License:"), cstring);
+          g_print ("\n");
+
 	  g_free (cname);
 	  g_free (sname);
 	  sfi_ring_free (pspecs);
@@ -373,10 +384,167 @@ strequals (const gchar *s1,
 }
 
 static void
-show_objdoc (void)
+showdoc_print_type (GObjectClass *oclass,
+                    gboolean      show_channels)
+{
+  GType btype, type = G_OBJECT_CLASS_TYPE (oclass);
+  guint j, in_itemize = 0;
+  const gchar *string, *pgroup = NULL;
+  g_print ("\n\n@anchor{%s} ", g_type_name (type));
+  g_print ("@unnumbered %s\n", g_type_name (type));
+  string = bse_type_get_authors (type);
+  if (string)
+    g_print ("@* @emph{%s} %s\n", _("Authors:"), string);
+  string = bse_type_get_license (type);
+  if (string)
+    g_print ("@* @emph{%s} %s\n", _("License:"), string);
+  string = bse_type_get_blurb (type);
+  if (string)
+    g_print ("@* %s\n", string);
+  g_print ("@heading %s\n", _("Properties:"));
+  btype = G_TYPE_OBJECT;
+  do
+    {
+      GParamSpec **pspecs;
+      btype = g_type_next_base (type, btype);
+      pspecs = g_object_class_list_properties (g_type_class_peek (btype), NULL);
+      /* show GUI properties */
+      for (j = 0; pspecs[j]; j++)
+        {
+          GParamSpec *pspec = g_object_class_find_property (oclass, pspecs[j]->name);
+          const gchar *group = sfi_pspec_get_group (pspec);
+          if (pspec->owner_type != btype || !sfi_pspec_check_option (pspec, "G"))
+            continue;
+          if (!strequals (group, pgroup))
+            {
+              if (in_itemize)
+                g_print ("@end itemize\n");
+              in_itemize = 0;
+              pgroup = group;
+              if (group)
+                g_print ("@strong{%s:}\n", group);
+            }
+          if (!in_itemize++)
+            g_print ("@itemize\n");
+          g_print ("@anchor{%s::%s} ", g_type_name (type), sfi_pspec_get_name (pspec));
+          g_print ("@item @strong{@emph{%s}}\n", sfi_pspec_get_nick (pspec));
+          g_print ("@* @emph{%s} @var{%s}\n", _("Identifier:"), sfi_pspec_get_name (pspec));
+          if (SFI_IS_PSPEC_INT (pspec))
+            {
+              SfiInt imin, imax;
+              sfi_pspec_get_int_range (pspec, &imin, &imax, NULL);
+              g_print ("@* @emph{%s} %d .. %d\n", _("Range:"), imin, imax);
+            }
+          else if (SFI_IS_PSPEC_REAL (pspec))
+            {
+              SfiReal fmin, fmax;
+              sfi_pspec_get_real_range (pspec, &fmin, &fmax, NULL);
+              g_print ("@* @emph{%s} %s .. %s\n", _("Range:"), beauty_float (fmin), beauty_float (fmax));
+            }
+          string = sfi_pspec_get_blurb (pspec);
+          if (string)
+            g_print ("@* @emph{%s} %s\n", _("Description:"), string);
+        }
+      if (in_itemize)
+        {
+          g_print ("@end itemize\n");
+          in_itemize = 0;
+        }
+      g_free (pspecs);
+    }
+  while (btype != type);
+  /* show signals */
+  guint n, ns, *sigs = g_signal_list_ids (type, &n);
+  if (n)
+    {
+      g_print ("@heading %s\n", _("Signals:"));
+      for (ns = 0; ns < n; ns++)
+        {
+          GSignalQuery query;
+          if (!in_itemize++)
+            g_print ("@itemize\n");
+          g_signal_query (sigs[ns], &query);
+          g_print ("@item %s @strong{@emph{%s}} (\n", g_type_name (query.return_type & ~G_SIGNAL_TYPE_STATIC_SCOPE), query.signal_name);
+          guint np;
+          for (np = 0; np < query.n_params; np++)
+            {
+              if (np)
+                g_print (", ");
+              g_print ("%s", g_type_name (query.param_types[np] & ~G_SIGNAL_TYPE_STATIC_SCOPE));
+            }
+          g_print (");\n");
+        }
+      if (in_itemize)
+        {
+          g_print ("@end itemize\n");
+          in_itemize = 0;
+        }
+    }
+  g_free (sigs);
+  /* show input and output channels */
+  if (show_channels &&
+      !G_TYPE_IS_ABSTRACT (type) &&
+      g_type_is_a (type, BSE_TYPE_SOURCE) &&
+      !strequals ("BseServer", g_type_name (type)))
+    {
+      BseSource *source = g_object_new (type, NULL);
+      if (BSE_SOURCE_N_ICHANNELS (source))
+        g_print ("@heading %s\n", _("Input Channels:"));
+      for (j = 0; j < BSE_SOURCE_N_ICHANNELS (source); j++)
+        {
+          if (!in_itemize++)
+            g_print ("@itemize\n");
+          g_print ("@anchor{%s::%s} ", g_type_name (type), BSE_SOURCE_ICHANNEL_IDENT (source, j));
+          g_print ("@item @strong{@emph{%s %s}}\n", BSE_SOURCE_ICHANNEL_LABEL (source, j),
+                   BSE_SOURCE_IS_JOINT_ICHANNEL (source, j) ? _("(Joint Input)") : "");
+          g_print ("@* @emph{%s} @var{%s}\n", _("Identifier:"), BSE_SOURCE_ICHANNEL_IDENT (source, j));
+          string = BSE_SOURCE_ICHANNEL_BLURB (source, j);
+          if (string)
+            g_print ("@* @emph{%s} %s\n", _("Description:"), string);
+        }
+      if (in_itemize)
+        {
+          g_print ("@end itemize\n");
+          in_itemize = 0;
+        }
+      if (BSE_SOURCE_N_OCHANNELS (source))
+        g_print ("@heading %s\n", _("Output Channels:"));
+      for (j = 0; j < BSE_SOURCE_N_OCHANNELS (source); j++)
+        {
+          if (!in_itemize++)
+            g_print ("@itemize\n");
+          g_print ("@anchor{%s::%s} ", g_type_name (type), BSE_SOURCE_OCHANNEL_IDENT (source, j));
+          g_print ("@item @strong{@emph{%s}} \n", BSE_SOURCE_OCHANNEL_LABEL (source, j));
+          g_print ("@* @emph{%s} @var{%s}\n", _("Identifier:"), BSE_SOURCE_OCHANNEL_IDENT (source, j));
+          string = BSE_SOURCE_OCHANNEL_BLURB (source, j);
+          if (string)
+            g_print ("@* @emph{%s} %s\n", _("Description:"), string);
+        }
+      if (in_itemize)
+        {
+          g_print ("@end itemize\n");
+          in_itemize = 0;
+        }
+      g_print ("\n");
+      g_object_unref (source);
+    }
+}
+
+static void
+showdoc_descendants (GType type)
+{
+  GObjectClass *oclass = g_type_class_ref (type);
+  showdoc_print_type (oclass, TRUE);
+  GType *child, *children = g_type_children (type, NULL);
+  for (child = children; *child; child++)
+    showdoc_descendants (*child);
+  g_free (children);
+  g_type_class_unref (oclass);
+}
+
+static void
+showdoc_alltypes (void)
 {
-  BseCategorySeq *cseq;
-  guint i, j, in_itemize = 0;
   g_print ("\\input texinfo\n"
 	   "@c %%**start of header\n"
 	   "@settitle %s\n"
@@ -397,114 +565,43 @@ show_objdoc (void)
            _("BSE-Objects"),
 	   BST_VERSION,
            _("BSE-Objects"), _(" Object Reference"));
-  cseq = bse_categories_match_typed ("*", BSE_TYPE_SOURCE);
+  showdoc_descendants (BSE_TYPE_OBJECT);
+}
+
+#if 0
+static void
+showdoc_plugins (void)
+{
+  g_print ("\\input texinfo\n"
+	   "@c %%**start of header\n"
+	   "@settitle %s\n"
+	   "@footnotestyle end\n"
+	   "@c %%**end of header\n"
+	   "\n"
+	   "@include texiutils.texi\n"
+	   "\n"
+	   "@docpackage{BEAST-%s}\n"
+	   "@docfont{tech}\n"
+	   "\n"
+	   "@majorheading %s - %s\n"
+	   "\n"
+	   "@revision{Document Revised:}\n"
+	   "\n"
+           "@contents\n"
+	   "\n",
+           _("BSE-Objects"),
+	   BST_VERSION,
+           _("BSE-Objects"), _(" Object Reference"));
+  BseCategorySeq *cseq = bse_categories_match_typed ("*", BSE_TYPE_SOURCE);
+  guint i;
   for (i = 0; i < cseq->n_cats; i++)
     {
       BseCategory *cat = cseq->cats[i];
-      GType btype, type = g_type_from_name (cat->type);
-      BseSource *source = g_object_new (type, NULL);
-      const gchar *string, *pgroup = NULL;
-      g_print ("\n\n@anchor{%s} ", g_type_name (type));
-      g_print ("@unnumbered %s\n", g_type_name (type));
-      string = bse_type_get_authors (type);
-      if (string)
-        g_print ("@* @emph{%s} %s\n", _("Authors:"), string);
-      string = bse_type_get_license (type);
-      if (string)
-        g_print ("@* @emph{%s} %s\n", _("License:"), string);
-      string = bse_type_get_blurb (type);
-      if (string)
-        g_print ("@* %s\n", string);
-      g_print ("@heading %s\n", _("Properties:"));
-      btype = G_TYPE_OBJECT;
-      do
-        {
-          GParamSpec **pspecs;
-          btype = g_type_next_base (type, btype);
-          pspecs = g_object_class_list_properties (g_type_class_peek (btype), NULL);
-          for (j = 0; pspecs[j]; j++)
-            {
-              GParamSpec *pspec = g_object_class_find_property (G_OBJECT_GET_CLASS (source), pspecs[j]->name);
-              const gchar *group = sfi_pspec_get_group (pspec);
-              if (pspec->owner_type != btype || !sfi_pspec_check_option (pspec, "G"))
-                continue;
-              if (!strequals (group, pgroup))
-                {
-                  if (in_itemize)
-                    g_print ("@end itemize\n");
-                  in_itemize = 0;
-                  pgroup = group;
-                  if (group)
-                    g_print ("@strong{%s:}\n", group);
-                }
-              if (!in_itemize++)
-                g_print ("@itemize\n");
-              g_print ("@anchor{%s::%s} ", g_type_name (type), sfi_pspec_get_name (pspec));
-              g_print ("@item @strong{@emph{%s}}\n", sfi_pspec_get_nick (pspec));
-              g_print ("@* @emph{%s} @var{%s}\n", _("Identifier:"), sfi_pspec_get_name (pspec));
-              if (SFI_IS_PSPEC_INT (pspec))
-                {
-                  SfiInt imin, imax;
-                  sfi_pspec_get_int_range (pspec, &imin, &imax, NULL);
-                  g_print ("@* @emph{%s} %d .. %d\n", _("Range:"), imin, imax);
-                }
-              else if (SFI_IS_PSPEC_REAL (pspec))
-                {
-                  SfiReal fmin, fmax;
-                  sfi_pspec_get_real_range (pspec, &fmin, &fmax, NULL);
-                  g_print ("@* @emph{%s} %s .. %s\n", _("Range:"), beauty_float (fmin), beauty_float (fmax));
-                }
-              string = sfi_pspec_get_blurb (pspec);
-              if (string)
-                g_print ("@* @emph{%s} %s\n", _("Description:"), string);
-            }
-          if (in_itemize)
-            {
-              g_print ("@end itemize\n");
-              in_itemize = 0;
-            }
-          g_free (pspecs);
-        }
-      while (btype != type);
-      g_print ("@heading %s\n", _("Input Channels:"));
-      for (j = 0; j < BSE_SOURCE_N_ICHANNELS (source); j++)
-        {
-          if (!in_itemize++)
-            g_print ("@itemize\n");
-          g_print ("@anchor{%s::%s} ", g_type_name (type), BSE_SOURCE_ICHANNEL_IDENT (source, j));
-          g_print ("@item @strong{@emph{%s %s}}\n", BSE_SOURCE_ICHANNEL_NAME (source, j),
-                   BSE_SOURCE_IS_JOINT_ICHANNEL (source, j) ? _("(Joint Input)") : "");
-          g_print ("@* @emph{%s} @var{%s}\n", _("Identifier:"), BSE_SOURCE_ICHANNEL_IDENT (source, j));
-          string = BSE_SOURCE_ICHANNEL_BLURB (source, j);
-          if (string)
-            g_print ("@* @emph{%s} %s\n", _("Description:"), string);
-        }
-      if (in_itemize)
-        {
-          g_print ("@end itemize\n");
-          in_itemize = 0;
-        }
-      g_print ("@heading %s\n", _("Output Channels:"));
-      for (j = 0; j < BSE_SOURCE_N_OCHANNELS (source); j++)
-        {
-          if (!in_itemize++)
-            g_print ("@itemize\n");
-          g_print ("@anchor{%s::%s} ", g_type_name (type), BSE_SOURCE_OCHANNEL_IDENT (source, j));
-          g_print ("@item @strong{@emph{%s}} \n", BSE_SOURCE_OCHANNEL_NAME (source, j));
-          g_print ("@* @emph{%s} @var{%s}\n", _("Identifier:"), BSE_SOURCE_OCHANNEL_IDENT (source, j));
-          string = BSE_SOURCE_OCHANNEL_BLURB (source, j);
-          if (string)
-            g_print ("@* @emph{%s} %s\n", _("Description:"), string);
-        }
-      if (in_itemize)
-        {
-          g_print ("@end itemize\n");
-          in_itemize = 0;
-        }
-      g_print ("\n");
-      g_object_unref (source);
+      GType type = g_type_from_name (cat->type);
+      showdoc_print_type (type, TRUE);
     }
 }
+#endif
 
 static gint
 help (const gchar *name,
@@ -582,7 +679,7 @@ main (gint   argc,
   else if (gen_structs)
     show_structdoc ();
   else if (gen_objects)
-    show_objdoc ();
+    showdoc_alltypes ();
   else
     return help (argv[0], NULL);
 
