@@ -1,5 +1,5 @@
 /* BSE - Bedevilled Sound Engine
- * Copyright (C) 1997-2002 Tim Janik
+ * Copyright (C) 1997-2004 Tim Janik
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,46 +18,35 @@
 #ifndef __BSE_CONST_VALUES_H__
 #define __BSE_CONST_VALUES_H__
 
-#include	<bse/bsedefs.h>
-
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
-
-
-/* BSE wide constant values */
+#include <bse/bsedefs.h>
 
+G_BEGIN_DECLS
 
 /* --- frequencies --- */
 /* kammer frequency, frequency of the note A of the standard piano
  * octave.slightly different values are used in different countries,
  * however, 440Hz is the official value for germany and much of europe.
  */
-#define	BSE_KAMMER_FREQUENCY_f		(440.0)
+#define	BSE_KAMMER_FREQUENCY		(440.0)
 
 /* maximum (audible) frequency represented in synthesis signals.
  * this value shouldn't be changed, to maintain frequency
  * representation in signals.
  */
-#define	BSE_MAX_FREQUENCY_f		(24000.0)
-#define	BSE_MAX_FREQUENCY_d		((gdouble) BSE_MAX_FREQUENCY_f)
+#define	BSE_MAX_FREQUENCY		(24000.0)
 
 /* minimum (needs to be > 0) and maximum audible frequencies supported
  * by oscillators (outer limits for user supplied frequency values)
  */
-#define	BSE_MAX_OSC_FREQUENCY_d		((gdouble) 20000.0)
-#define	BSE_MIN_OSC_FREQUENCY_d		((gdouble) 1.0 / BSE_MAX_OSC_FREQUENCY_d)
-#define	BSE_MAX_OSC_FREQUENCY_f		((gfloat) BSE_MAX_OSC_FREQUENCY_d)
-#define	BSE_MIN_OSC_FREQUENCY_f		((gfloat) BSE_MIN_OSC_FREQUENCY_d)
+#define	BSE_MAX_OSC_FREQUENCY		(20000.0)
+#define	BSE_MIN_OSC_FREQUENCY		(1.0 / BSE_MAX_OSC_FREQUENCY)
 
 /* epsilon used to compare audible frequencies and check for equality */
-#define BSE_FREQUENCY_EPSILON		((gdouble) 0.001)
+#define BSE_FREQUENCY_EPSILON		(0.001)
 
 
 /* --- fine tune --- */
 /* fine tune in cents of a semitone */
-#define	BSE_MAX_FINE_TUNE_f		((float) BSE_MAX_FINE_TUNE)
-#define	BSE_MAX_FINE_TUNE_d		((float) BSE_MAX_FINE_TUNE)
 #define	BSE_MIN_FINE_TUNE		(-BSE_MAX_FINE_TUNE)
 #define	BSE_MAX_FINE_TUNE		(+100)
 #define BSE_FINE_TUNE_IS_VALID(n)	((n) >= BSE_MIN_FINE_TUNE && (n) <= BSE_MAX_FINE_TUNE)
@@ -68,20 +57,19 @@ extern "C" {
  * notes<->sample value: 0 .. 127 (BSE_VALUE_FROM_NOTE)
  * freq<->sample value: 0 .. 24000 (BSE_FREQ_FROM_VALUE)
  */
-#define	BSE_VALUE_FROM_BOUNDED_UINT(k,b) ((gfloat) ((k) * (1.0 / ((gfloat) (b)))))
-#define	BSE_FREQ_FROM_VALUE(value)	 (((gfloat) (value)) * BSE_MAX_FREQUENCY_f)
-#define	BSE_VALUE_FROM_FREQ(freq)	 ((gfloat) ((freq) * (1.0 / BSE_MAX_FREQUENCY_f)))
-#define	BSE_FREQUENCY_EPSILON		 ((gdouble) 0.001)
+#define	BSE_FREQ_FROM_VALUE(value)	 (BSE_MAX_FREQUENCY * (value))
+#define	BSE_VALUE_FROM_FREQ(freq)	 ((1.0 / BSE_MAX_FREQUENCY) * (freq))
+#define	BSE_FREQUENCY_EPSILON		 (0.001)
 
 
 /* --- volume --- */
-#define	BSE_MIN_VOLUME_dB		(-144) /* theoretically: -48.165 */
+#define	BSE_MIN_VOLUME_dB		(-144) /* theoretically: -96.3 */
 #define	BSE_MAX_VOLUME_dB		(+24)
 
 
 /* --- balance (left/right volume) --- */
-#define	BSE_MIN_BALANCE_f		(-100.0)
-#define	BSE_MAX_BALANCE_f		(+100.0)
+#define	BSE_MIN_BALANCE         	(-100.0)
+#define	BSE_MAX_BALANCE 		(+100.0)
 
 /* --- bpm --- */
 #define	BSE_MIN_BPM			(1)
@@ -107,10 +95,6 @@ extern "C" {
 #define	BSE_RATING_FALLBACK		(1)
 #define	BSE_RATING_NO_AUTO		(-1)
 
-
-
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* __BSE_CONST_VALUES_H__ */
