@@ -71,7 +71,7 @@ struct _BseContainerClass
 void		bse_container_forall_items	(BseContainer	*container,
 						 BseForallItemsFunc func,
 						 gpointer	 data);
-BseItemSeq*	bse_container_list_items	(BseContainer	*container);
+BseItemSeq*	bse_container_list_children	(BseContainer	*container);
 guint		bse_container_get_item_seqid	(BseContainer	*container,
 						 BseItem	*item);
 BseItem*	bse_container_get_item		(BseContainer	*container,
@@ -90,10 +90,13 @@ gchar* /*fr*/	bse_container_make_upath	(BseContainer	*container,
 gboolean	bse_container_check_restore	(BseContainer	*container,
 						 const gchar	*child_type);
 /* non-undo functions */
-gpointer        bse_container_new_child         (BseContainer   *container,
+gpointer        bse_container_new_child_bname   (BseContainer   *container,
 						 GType           child_type,
+						 const gchar    *base_name,
 						 const gchar    *first_param_name,
 						 ...);
+#define         bse_container_new_child(         container, child_type, ...) \
+                bse_container_new_child_bname(   container, child_type, NULL, __VA_ARGS__)
 void		bse_container_add_item          (BseContainer	*container,
 						 BseItem	*item);
 void		bse_container_remove_item	(BseContainer	*container,
