@@ -204,7 +204,7 @@ get_osc_freq_exec (BseProcedureClass *proc,
   
 #line 157 "bseeditablesample.proc"
   
-  sfi_value_set_real (out_values++, esample->wchunk ? esample->wchunk->osc_freq : BSE_KAMMER_FREQUENCY_f);
+  sfi_value_set_real (out_values++, esample->wchunk ? esample->wchunk->osc_freq : BSE_KAMMER_FREQUENCY);
   
   return BSE_ERROR_NONE;
 }
