@@ -17,6 +17,28 @@ static GEnumValue bse_export_node_type_values[] = {
   { 0, NULL, NULL }
 };
 
+/* --- gsldatacache.h --- */
+#include	"gsldatacache.h"
+/* GslDataCacheRequest
+ */
+static GEnumValue gsl_data_cache_request_values[] = {
+  { GSL_DATA_CACHE_REQUEST, "GSL_DATA_CACHE_REQUEST", "request" },
+  { GSL_DATA_CACHE_DEMAND_LOAD, "GSL_DATA_CACHE_DEMAND_LOAD", "demand-load" },
+  { GSL_DATA_CACHE_PEEK, "GSL_DATA_CACHE_PEEK", "peek" },
+  { 0, NULL, NULL }
+};
+
+/* --- gslvorbis-cutter.h --- */
+#include	"gslvorbis-cutter.h"
+/* GslVorbisCutterMode
+ */
+static GEnumValue gsl_vorbis_cutter_mode_values[] = {
+  { GSL_VORBIS_CUTTER_NONE, "GSL_VORBIS_CUTTER_NONE", "none" },
+  { GSL_VORBIS_CUTTER_SAMPLE_BOUNDARY, "GSL_VORBIS_CUTTER_SAMPLE_BOUNDARY", "sample-boundary" },
+  { GSL_VORBIS_CUTTER_PACKET_BOUNDARY, "GSL_VORBIS_CUTTER_PACKET_BOUNDARY", "packet-boundary" },
+  { GSL_VORBIS_CUTTER_PAGE_BOUNDARY, "GSL_VORBIS_CUTTER_PAGE_BOUNDARY", "page-boundary" },
+  { 0, NULL, NULL }
+};
 
 /* --- bsebiquadfilter.h --- */
 #include	"bsebiquadfilter.h"
@@ -27,7 +49,6 @@ static GEnumValue bse_biquad_filter_type_values[] = {
   { BSE_BIQUAD_FILTER_RESONANT_HIGHPASS, "BSE_BIQUAD_FILTER_RESONANT_HIGHPASS", "highpass" },
   { 0, NULL, NULL }
 };
-
 /* BseBiquadFilterNorm
  */
 static GEnumValue bse_biquad_filter_norm_values[] = {
@@ -37,7 +58,6 @@ static GEnumValue bse_biquad_filter_norm_values[] = {
   { 0, NULL, NULL }
 };
 
-
 /* --- bseenums.h --- */
 #include	"bseenums.h"
 /* BseRegistrationType
@@ -48,7 +68,6 @@ static GEnumValue bse_registration_type_values[] = {
   { BSE_REGISTER_DONE, "BSE_REGISTER_DONE", "done" },
   { 0, NULL, NULL }
 };
-
 /* BseInterpolType
  */
 static GEnumValue bse_interpol_type_values[] = {
@@ -57,7 +76,6 @@ static GEnumValue bse_interpol_type_values[] = {
   { BSE_INTERPOL_CUBIC, "BSE_INTERPOL_CUBIC", "Cubic" },
   { 0, NULL, NULL }
 };
-
 /* BseLoopType
  */
 static GEnumValue bse_loop_type_values[] = {
@@ -67,7 +85,6 @@ static GEnumValue bse_loop_type_values[] = {
   { BSE_LOOP_SONG, "BSE_LOOP_SONG", "song" },
   { 0, NULL, NULL }
 };
-
 /* BseMagicFlags
  */
 static GFlagsValue bse_magic_flags_values[] = {
@@ -75,7 +92,6 @@ static GFlagsValue bse_magic_flags_values[] = {
   { BSE_MAGIC_BSE_SONG, "BSE_MAGIC_BSE_SONG", "song" },
   { 0, NULL, NULL }
 };
-
 /* BseErrorType
  */
 static GEnumValue bse_error_type_values[] = {
@@ -150,7 +166,6 @@ static GEnumValue bse_error_type_values[] = {
   { 0, NULL, NULL }
 };
 
-
 /* --- bseglobals.h --- */
 #include	"bseglobals.h"
 /* BseTimeRangeType
@@ -162,7 +177,6 @@ static GEnumValue bse_time_range_type_values[] = {
   { 0, NULL, NULL }
 };
 
-
 /* --- bsemidievent.h --- */
 #include	"bsemidievent.h"
 /* BseMidiEventType
@@ -215,7 +229,6 @@ static GEnumValue bse_midi_event_type_values[] = {
   { 0, NULL, NULL }
 };
 
-
 /* --- bseproject.h --- */
 #include	"bseproject.h"
 /* BseProjectState
@@ -227,7 +240,6 @@ static GEnumValue bse_project_state_values[] = {
   { 0, NULL, NULL }
 };
 
-
 /* --- bsestandardosc.h --- */
 #include	"bsestandardosc.h"
 /* BseStandardOscWaveType
@@ -245,7 +257,6 @@ static GEnumValue bse_standard_osc_wave_type_values[] = {
   { 0, NULL, NULL }
 };
 
-
 /* --- bsemididecoder.h --- */
 #include	"bsemididecoder.h"
 /* BseMidiDecoderState
@@ -260,6 +271,5 @@ static GEnumValue bse_midi_decoder_state_values[] = {
   { 0, NULL, NULL }
 };
 
-
 /* Generated data ends here */
 
