@@ -5,6 +5,12 @@
 /* --- bseexports.h --- */
   { "BseExportNodeType", G_TYPE_ENUM, &BSE_TYPE_ID (BseExportNodeType), bse_export_node_type_values },
 
+/* --- gsldatacache.h --- */
+  { "GslDataCacheRequest", G_TYPE_ENUM, &BSE_TYPE_ID (GslDataCacheRequest), gsl_data_cache_request_values },
+
+/* --- gslvorbis-cutter.h --- */
+  { "GslVorbisCutterMode", G_TYPE_ENUM, &BSE_TYPE_ID (GslVorbisCutterMode), gsl_vorbis_cutter_mode_values },
+
 /* --- bsebiquadfilter.h --- */
   { "BseBiquadFilterType", G_TYPE_ENUM, &BSE_TYPE_ID (BseBiquadFilterType), bse_biquad_filter_type_values },
   { "BseBiquadFilterNorm", G_TYPE_ENUM, &BSE_TYPE_ID (BseBiquadFilterNorm), bse_biquad_filter_norm_values },
