@@ -55,40 +55,46 @@ typedef enum
 } BseMagicFlags;
 typedef enum
 {
-  /* GSL errors are mirrored into BSE */
-  BSE_ERROR_NONE		= GSL_ERROR_NONE,	/* 0 */
-  BSE_ERROR_INTERNAL		= GSL_ERROR_INTERNAL,
-  BSE_ERROR_UNKNOWN		= GSL_ERROR_UNKNOWN,
+  BSE_ERROR_NONE		= 0,
+  BSE_ERROR_INTERNAL,
+  BSE_ERROR_UNKNOWN,
+  /* general errors */
+  BSE_ERROR_IO,
+  BSE_ERROR_PERMS,
   /* file errors */
-  BSE_ERROR_FILE_IO		= GSL_ERROR_IO,
-  BSE_ERROR_FILE_PERMS		= GSL_ERROR_PERMS,
-  BSE_ERROR_FILE_BUSY		= GSL_ERROR_BUSY,
-  BSE_ERROR_FILE_EXISTS		= GSL_ERROR_EXISTS,
-  BSE_ERROR_FILE_EOF		= GSL_ERROR_EOF,
-  BSE_ERROR_FILE_NOT_FOUND	= GSL_ERROR_NOT_FOUND,
-  BSE_ERROR_FILE_IS_DIR 	= GSL_ERROR_IS_DIR,
-  BSE_ERROR_FILE_OPEN_FAILED	= GSL_ERROR_OPEN_FAILED,
-  BSE_ERROR_FILE_SEEK_FAILED	= GSL_ERROR_SEEK_FAILED,
-  BSE_ERROR_FILE_READ_FAILED	= GSL_ERROR_READ_FAILED,
-  BSE_ERROR_FILE_WRITE_FAILED	= GSL_ERROR_WRITE_FAILED,
+  BSE_ERROR_FILE_BUSY,
+  BSE_ERROR_FILE_EXISTS,
+  BSE_ERROR_FILE_EOF,
+  BSE_ERROR_FILE_EMPTY,
+  BSE_ERROR_FILE_NOT_FOUND,
+  BSE_ERROR_FILE_IS_DIR,
+  BSE_ERROR_FILE_OPEN_FAILED,
+  BSE_ERROR_FILE_SEEK_FAILED,
+  BSE_ERROR_FILE_READ_FAILED,
+  BSE_ERROR_FILE_WRITE_FAILED,
   /* out of resource conditions */
-  BSE_ERROR_MANY_FILES		= GSL_ERROR_MANY_FILES,
-  BSE_ERROR_NO_FILES		= GSL_ERROR_NO_FILES,
-  BSE_ERROR_NO_SPACE		= GSL_ERROR_NO_SPACE,
-  BSE_ERROR_NO_MEMORY		= GSL_ERROR_NO_MEMORY,
+  BSE_ERROR_MANY_FILES,
+  BSE_ERROR_NO_FILES,
+  BSE_ERROR_NO_SPACE,
+  BSE_ERROR_NO_MEMORY,
   /* content errors */
-  BSE_ERROR_NO_HEADER		= GSL_ERROR_NO_HEADER,
-  BSE_ERROR_NO_SEEK_INFO	= GSL_ERROR_NO_SEEK_INFO,
-  BSE_ERROR_NO_DATA		= GSL_ERROR_NO_DATA,
-  BSE_ERROR_DATA_CORRUPT	= GSL_ERROR_DATA_CORRUPT,
-  BSE_ERROR_FORMAT_INVALID	= GSL_ERROR_FORMAT_INVALID,
-  BSE_ERROR_FORMAT_UNKNOWN	= GSL_ERROR_FORMAT_UNKNOWN,
+  BSE_ERROR_NO_HEADER,
+  BSE_ERROR_NO_SEEK_INFO,
+  BSE_ERROR_NO_DATA,
+  BSE_ERROR_DATA_CORRUPT,
+  BSE_ERROR_WRONG_N_CHANNELS,
+  BSE_ERROR_FORMAT_INVALID,
+  BSE_ERROR_FORMAT_UNKNOWN,
+  BSE_ERROR_DATA_UNMATCHED,
   /* miscellaneous errors */
-  BSE_ERROR_TEMP		= GSL_ERROR_TEMP,
-  BSE_ERROR_WAVE_NOT_FOUND	= GSL_ERROR_WAVE_NOT_FOUND,
-  BSE_ERROR_CODEC_FAILURE	= GSL_ERROR_CODEC_FAILURE,
-  /* BSE errors */
-  BSE_ERROR_UNIMPLEMENTED	= GSL_ERROR_LAST,
+  BSE_ERROR_TEMP,
+  BSE_ERROR_WAVE_NOT_FOUND,
+  BSE_ERROR_CODEC_FAILURE,
+  BSE_ERROR_UNIMPLEMENTED,
+  BSE_ERROR_INVALID_PROPERTY,
+  BSE_ERROR_INVALID_MIDI_CONTROL,
+  BSE_ERROR_PARSE_ERROR,
+  BSE_ERROR_SPAWN,
   /* Device errors */
   BSE_ERROR_DEVICE_NOT_AVAILABLE,
   BSE_ERROR_DEVICE_ASYNC,
@@ -118,11 +124,6 @@ typedef enum
   BSE_ERROR_PROC_PARAM_INVAL,
   BSE_ERROR_PROC_EXECUTION,
   BSE_ERROR_PROC_ABORT,
-  /* miscellaneous errors */
-  BSE_ERROR_INVALID_PROPERTY,
-  BSE_ERROR_INVALID_MIDI_CONTROL,
-  BSE_ERROR_PARSE_ERROR,
-  BSE_ERROR_SPAWN,
   /* various procedure errors */
   BSE_ERROR_NO_ENTRY,
   BSE_ERROR_NO_EVENT,
