@@ -19,25 +19,20 @@
 #define __BSE_GCONFIG_H__
 
 #include	<bse/bseobject.h>
+#include	<bse/bsemain.h>
 
-
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
-
+G_BEGIN_DECLS
 
 /* --- Global Config --- */
 /* extern BseGConfig *bse_global_config; bsetype.h */
-void               _bse_gconfig_init	(void);
-void               bse_gconfig_apply	(SfiRec *rec);
-GParamSpec*        bse_gconfig_pspec	(void);
-void		   bse_gconfig_lock	(void);
-void		   bse_gconfig_unlock	(void);
-gboolean	   bse_gconfig_locked	(void);
+void               _bse_gconfig_init	  (void);
+void               bse_gconfig_apply	  (SfiRec *rec);
+GParamSpec*        bse_gconfig_pspec	  (void);
+void		   bse_gconfig_lock	  (void);
+void		   bse_gconfig_unlock	  (void);
+gboolean	   bse_gconfig_locked	  (void);
+void               bse_gconfig_merge_args (const BseMainArgs *margs);
 
-
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* __BSE_GCONFIG_H__ */
