@@ -4,6 +4,10 @@
 
 GType BSE_TYPE_ID (BseExportNodeType) = 0;
 
+GType BSE_TYPE_ID (GslDataCacheRequest) = 0;
+
+GType BSE_TYPE_ID (GslVorbisCutterMode) = 0;
+
 GType BSE_TYPE_ID (BseBiquadFilterType) = 0;
 
 GType BSE_TYPE_ID (BseBiquadFilterNorm) = 0;
