@@ -6,6 +6,14 @@
 #define BSE_TYPE_EXPORT_NODE_TYPE	    (BSE_TYPE_ID (BseExportNodeType))
 extern GType BSE_TYPE_ID (BseExportNodeType);
 
+/* --- gsldatacache.h --- */
+#define BSE_TYPE_DATA_CACHE_REQUEST	    (BSE_TYPE_ID (GslDataCacheRequest))
+extern GType BSE_TYPE_ID (GslDataCacheRequest);
+
+/* --- gslvorbis-cutter.h --- */
+#define BSE_TYPE_VORBIS_CUTTER_MODE	    (BSE_TYPE_ID (GslVorbisCutterMode))
+extern GType BSE_TYPE_ID (GslVorbisCutterMode);
+
 /* --- bsebiquadfilter.h --- */
 #define BSE_TYPE_BIQUAD_FILTER_TYPE	    (BSE_TYPE_ID (BseBiquadFilterType))
 extern GType BSE_TYPE_ID (BseBiquadFilterType);
@@ -549,11 +557,36 @@ typedef enum {
 } BseMidiControlType;
 
 typedef enum {
-  BSE_USER_MSG_MISC = 0,
-  BSE_USER_MSG_INFO = 1,
-  BSE_USER_MSG_WARNING = 2,
-  BSE_USER_MSG_ERROR = 3,
-} BseUserMsgType;
+  BSE_MIDI_EVENT_NONE = 0,
+  BSE_MIDI_EVENT_NOTE_OFF = 1,
+  BSE_MIDI_EVENT_NOTE_ON = 2,
+  BSE_MIDI_EVENT_KEY_PRESSURE = 3,
+  BSE_MIDI_EVENT_CONTROL_CHANGE = 4,
+  BSE_MIDI_EVENT_PROGRAM_CHANGE = 5,
+  BSE_MIDI_EVENT_CHANNEL_PRESSURE = 6,
+  BSE_MIDI_EVENT_PITCH_BEND = 7,
+  BSE_MIDI_EVENT_SYS_EX = 8,
+  BSE_MIDI_EVENT_SONG_POINTER = 9,
+  BSE_MIDI_EVENT_SONG_SELECT = 10,
+  BSE_MIDI_EVENT_TUNE = 11,
+  BSE_MIDI_EVENT_TIMING_CLOCK = 12,
+  BSE_MIDI_EVENT_SONG_START = 13,
+  BSE_MIDI_EVENT_SONG_CONTINUE = 14,
+  BSE_MIDI_EVENT_SONG_STOP = 15,
+  BSE_MIDI_EVENT_ACTIVE_SENSING = 16,
+  BSE_MIDI_EVENT_SYSTEM_RESET = 17,
+} BseMidiChannelEventType;
+
+typedef enum {
+  BSE_MSG_NONE = 0,
+  BSE_MSG_FATAL = 1,
+  BSE_MSG_ERROR = 2,
+  BSE_MSG_WARNING = 3,
+  BSE_MSG_SCRIPT = 4,
+  BSE_MSG_INFO = 5,
+  BSE_MSG_DIAG = 6,
+  BSE_MSG_DEBUG = 7,
+} BseMsgType;
 
 typedef enum {
   BSE_THREAD_STATE_UNKNOWN = 0,
@@ -568,6 +601,7 @@ typedef enum {
 
 
 /* record typedefs */
+typedef struct _BseMidiChannelEvent BseMidiChannelEvent;
 typedef struct _BsePropertyCandidates BsePropertyCandidates;
 typedef struct _BsePartNote BsePartNote;
 typedef struct _BsePartControl BsePartControl;
@@ -580,7 +614,7 @@ typedef struct _BsePartLink BsePartLink;
 typedef struct _BseTrackPart BseTrackPart;
 typedef struct _BseSongTiming BseSongTiming;
 typedef struct _BseSampleFileInfo BseSampleFileInfo;
-typedef struct _BseUserMsg BseUserMsg;
+typedef struct _BseMessage BseMessage;
 typedef struct _BseThreadInfo BseThreadInfo;
 typedef struct _BseThreadTotals BseThreadTotals;
 typedef struct _BseGConfig BseGConfig;
@@ -588,9 +622,9 @@ typedef struct _BseGConfig BseGConfig;
 
 /* sequence typedefs */
 typedef struct _BseIntSeq BseIntSeq;
-typedef struct _BseNoteSeq BseNoteSeq;
-typedef struct _BseStringSeq BseStringSeq;
 typedef struct _BseTypeSeq BseTypeSeq;
+typedef struct _BseStringSeq BseStringSeq;
+typedef struct _BseNoteSeq BseNoteSeq;
 typedef struct _BseItemSeq BseItemSeq;
 typedef struct _BsePartNoteSeq BsePartNoteSeq;
 typedef struct _BsePartControlSeq BsePartControlSeq;
@@ -606,17 +640,17 @@ struct _BseIntSeq {
   guint n_ints;
   SfiInt* ints;
 };
-struct _BseNoteSeq {
-  guint n_notes;
-  SfiInt* notes;
+struct _BseTypeSeq {
+  guint n_types;
+  gchar** types;
 };
 struct _BseStringSeq {
   guint n_strings;
   gchar** strings;
 };
-struct _BseTypeSeq {
-  guint n_types;
-  gchar** types;
+struct _BseNoteSeq {
+  guint n_notes;
+  SfiInt* notes;
 };
 struct _BseItemSeq {
   guint n_items;
@@ -653,6 +687,20 @@ struct _BseThreadInfoSeq {
 
 
 /* records */
+struct _BseMidiChannelEvent {
+  BseMidiChannelEventType event_type;
+  SfiInt channel;
+  SfiNum tick_stamp;
+  SfiReal frequency;
+  SfiReal velocity;
+  SfiInt control;
+  SfiReal value;
+  SfiInt program;
+  SfiReal intensity;
+  SfiReal pitch_bend;
+  SfiInt song_pointer;
+  SfiInt song_number;
+};
 struct _BsePropertyCandidates {
   gchar* label;
   gchar* tooltip;
@@ -728,6 +776,7 @@ struct _BseSongTiming {
   SfiInt denominator;
   SfiInt tpqn;
   SfiInt tpt;
+  SfiReal stamp_ticks;
 };
 struct _BseSampleFileInfo {
   gchar* file;
@@ -737,13 +786,19 @@ struct _BseSampleFileInfo {
   BseStringSeq* waves;
   SfiInt error;
 };
-struct _BseUserMsg {
+struct _BseMessage {
   gchar* log_domain;
-  BseUserMsgType msg_type;
-  gchar* config_blurb;
-  gchar* message;
-  SfiInt pid;
+  BseMsgType type;
+  gchar* ident;
+  gchar* label;
+  gchar* title;
+  gchar* primary;
+  gchar* secondary;
+  gchar* details;
+  gchar* config_check;
+  BseJanitor* janitor;
   gchar* process;
+  SfiInt pid;
 };
 struct _BseThreadInfo {
   gchar* name;
@@ -778,6 +833,13 @@ struct _BseGConfig {
 
 
 /* record functions */
+SfiRecFields bse_midi_channel_event_get_fields (void);
+BseMidiChannelEvent* bse_midi_channel_event_new (void);
+BseMidiChannelEvent* bse_midi_channel_event_copy_shallow (BseMidiChannelEvent* rec);
+BseMidiChannelEvent* bse_midi_channel_event_from_rec (SfiRec *sfi_rec);
+SfiRec *bse_midi_channel_event_to_rec (BseMidiChannelEvent* rec);
+void bse_midi_channel_event_free (BseMidiChannelEvent* rec);
+
 SfiRecFields bse_property_candidates_get_fields (void);
 BsePropertyCandidates* bse_property_candidates_new (void);
 BsePropertyCandidates* bse_property_candidates_copy_shallow (BsePropertyCandidates* rec);
@@ -862,12 +924,12 @@ BseSampleFileInfo* bse_sample_file_info_from_rec (SfiRec *sfi_rec);
 SfiRec *bse_sample_file_info_to_rec (BseSampleFileInfo* rec);
 void bse_sample_file_info_free (BseSampleFileInfo* rec);
 
-SfiRecFields bse_user_msg_get_fields (void);
-BseUserMsg* bse_user_msg_new (void);
-BseUserMsg* bse_user_msg_copy_shallow (BseUserMsg* rec);
-BseUserMsg* bse_user_msg_from_rec (SfiRec *sfi_rec);
-SfiRec *bse_user_msg_to_rec (BseUserMsg* rec);
-void bse_user_msg_free (BseUserMsg* rec);
+SfiRecFields bse_message_get_fields (void);
+BseMessage* bse_message_new (void);
+BseMessage* bse_message_copy_shallow (BseMessage* rec);
+BseMessage* bse_message_from_rec (SfiRec *sfi_rec);
+SfiRec *bse_message_to_rec (BseMessage* rec);
+void bse_message_free (BseMessage* rec);
 
 SfiRecFields bse_thread_info_get_fields (void);
 BseThreadInfo* bse_thread_info_new (void);
@@ -902,14 +964,14 @@ SfiSeq *bse_int_seq_to_seq (BseIntSeq* seq);
 void bse_int_seq_resize (BseIntSeq* seq, guint new_size);
 void bse_int_seq_free (BseIntSeq* seq);
 
-GParamSpec* bse_note_seq_get_element (void);
-BseNoteSeq* bse_note_seq_new (void);
-void bse_note_seq_append (BseNoteSeq* seq, SfiInt element);
-BseNoteSeq* bse_note_seq_copy_shallow (BseNoteSeq* seq);
-BseNoteSeq* bse_note_seq_from_seq (SfiSeq *sfi_seq);
-SfiSeq *bse_note_seq_to_seq (BseNoteSeq* seq);
-void bse_note_seq_resize (BseNoteSeq* seq, guint new_size);
-void bse_note_seq_free (BseNoteSeq* seq);
+GParamSpec* bse_type_seq_get_element (void);
+BseTypeSeq* bse_type_seq_new (void);
+void bse_type_seq_append (BseTypeSeq* seq, const char* element);
+BseTypeSeq* bse_type_seq_copy_shallow (BseTypeSeq* seq);
+BseTypeSeq* bse_type_seq_from_seq (SfiSeq *sfi_seq);
+SfiSeq *bse_type_seq_to_seq (BseTypeSeq* seq);
+void bse_type_seq_resize (BseTypeSeq* seq, guint new_size);
+void bse_type_seq_free (BseTypeSeq* seq);
 
 GParamSpec* bse_string_seq_get_element (void);
 BseStringSeq* bse_string_seq_new (void);
@@ -920,14 +982,14 @@ SfiSeq *bse_string_seq_to_seq (BseStringSeq* seq);
 void bse_string_seq_resize (BseStringSeq* seq, guint new_size);
 void bse_string_seq_free (BseStringSeq* seq);
 
-GParamSpec* bse_type_seq_get_element (void);
-BseTypeSeq* bse_type_seq_new (void);
-void bse_type_seq_append (BseTypeSeq* seq, const char* element);
-BseTypeSeq* bse_type_seq_copy_shallow (BseTypeSeq* seq);
-BseTypeSeq* bse_type_seq_from_seq (SfiSeq *sfi_seq);
-SfiSeq *bse_type_seq_to_seq (BseTypeSeq* seq);
-void bse_type_seq_resize (BseTypeSeq* seq, guint new_size);
-void bse_type_seq_free (BseTypeSeq* seq);
+GParamSpec* bse_note_seq_get_element (void);
+BseNoteSeq* bse_note_seq_new (void);
+void bse_note_seq_append (BseNoteSeq* seq, SfiInt element);
+BseNoteSeq* bse_note_seq_copy_shallow (BseNoteSeq* seq);
+BseNoteSeq* bse_note_seq_from_seq (SfiSeq *sfi_seq);
+SfiSeq *bse_note_seq_to_seq (BseNoteSeq* seq);
+void bse_note_seq_resize (BseNoteSeq* seq, guint new_size);
+void bse_note_seq_free (BseNoteSeq* seq);
 
 GParamSpec* bse_item_seq_get_element (void);
 BseItemSeq* bse_item_seq_new (void);
@@ -1006,18 +1068,21 @@ void bse_thread_info_seq_free (BseThreadInfoSeq* seq);
 /* enum functions */
 const SfiChoiceValues bse_midi_signal_type_get_values (void);
 const SfiChoiceValues bse_midi_control_type_get_values (void);
-const SfiChoiceValues bse_user_msg_type_get_values (void);
+const SfiChoiceValues bse_midi_channel_event_type_get_values (void);
+const SfiChoiceValues bse_msg_type_get_values (void);
 const SfiChoiceValues bse_thread_state_get_values (void);
 
 
 /* enum type ids */
 extern GType bse__type_id__midi_signal_type;
 extern GType bse__type_id__midi_control_type;
-extern GType bse__type_id__user_msg_type;
+extern GType bse__type_id__midi_channel_event_type;
+extern GType bse__type_id__msg_type;
 extern GType bse__type_id__thread_state;
 
 
 /* record type ids */
+extern GType bse__type_id__midi_channel_event;
 extern GType bse__type_id__property_candidates;
 extern GType bse__type_id__part_note;
 extern GType bse__type_id__part_control;
@@ -1030,7 +1095,7 @@ extern GType bse__type_id__part_link;
 extern GType bse__type_id__track_part;
 extern GType bse__type_id__song_timing;
 extern GType bse__type_id__sample_file_info;
-extern GType bse__type_id__user_msg;
+extern GType bse__type_id__message;
 extern GType bse__type_id__thread_info;
 extern GType bse__type_id__thread_totals;
 extern GType bse__type_id__gconfig;
@@ -1038,9 +1103,9 @@ extern GType bse__type_id__gconfig;
 
 /* sequence type ids */
 extern GType bse__type_id__int_seq;
-extern GType bse__type_id__note_seq;
-extern GType bse__type_id__string_seq;
 extern GType bse__type_id__type_seq;
+extern GType bse__type_id__string_seq;
+extern GType bse__type_id__note_seq;
 extern GType bse__type_id__item_seq;
 extern GType bse__type_id__part_note_seq;
 extern GType bse__type_id__part_control_seq;
@@ -1056,11 +1121,13 @@ extern GType bse__type_id__thread_info_seq;
 /* enum type macros */
 #define BSE_TYPE_MIDI_SIGNAL_TYPE		(bse__type_id__midi_signal_type)
 #define BSE_TYPE_MIDI_CONTROL_TYPE		(bse__type_id__midi_control_type)
-#define BSE_TYPE_USER_MSG_TYPE		(bse__type_id__user_msg_type)
+#define BSE_TYPE_MIDI_CHANNEL_EVENT_TYPE		(bse__type_id__midi_channel_event_type)
+#define BSE_TYPE_MSG_TYPE		(bse__type_id__msg_type)
 #define BSE_TYPE_THREAD_STATE		(bse__type_id__thread_state)
 
 
 /* record type macros */
+#define BSE_TYPE_MIDI_CHANNEL_EVENT		(bse__type_id__midi_channel_event)
 #define BSE_TYPE_PROPERTY_CANDIDATES		(bse__type_id__property_candidates)
 #define BSE_TYPE_PART_NOTE		(bse__type_id__part_note)
 #define BSE_TYPE_PART_CONTROL		(bse__type_id__part_control)
@@ -1073,7 +1140,7 @@ extern GType bse__type_id__thread_info_seq;
 #define BSE_TYPE_TRACK_PART		(bse__type_id__track_part)
 #define BSE_TYPE_SONG_TIMING		(bse__type_id__song_timing)
 #define BSE_TYPE_SAMPLE_FILE_INFO		(bse__type_id__sample_file_info)
-#define BSE_TYPE_USER_MSG		(bse__type_id__user_msg)
+#define BSE_TYPE_MESSAGE		(bse__type_id__message)
 #define BSE_TYPE_THREAD_INFO		(bse__type_id__thread_info)
 #define BSE_TYPE_THREAD_TOTALS		(bse__type_id__thread_totals)
 #define BSE_TYPE_GCONFIG		(bse__type_id__gconfig)
@@ -1081,9 +1148,9 @@ extern GType bse__type_id__thread_info_seq;
 
 /* sequence type macros */
 #define BSE_TYPE_INT_SEQ		(bse__type_id__int_seq)
-#define BSE_TYPE_NOTE_SEQ		(bse__type_id__note_seq)
-#define BSE_TYPE_STRING_SEQ		(bse__type_id__string_seq)
 #define BSE_TYPE_TYPE_SEQ		(bse__type_id__type_seq)
+#define BSE_TYPE_STRING_SEQ		(bse__type_id__string_seq)
+#define BSE_TYPE_NOTE_SEQ		(bse__type_id__note_seq)
 #define BSE_TYPE_ITEM_SEQ		(bse__type_id__item_seq)
 #define BSE_TYPE_PART_NOTE_SEQ		(bse__type_id__part_note_seq)
 #define BSE_TYPE_PART_CONTROL_SEQ		(bse__type_id__part_control_seq)
