@@ -1,5 +1,5 @@
 /* BSE - Bedevilled Sound Engine
- * Copyright (C) 2002 Tim Janik
+ * Copyright (C) 2002, 2003 Tim Janik
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,17 +20,12 @@
 
 #include <bse/bsetype.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
-
+G_BEGIN_DECLS
 
 /* FIXME: creation of a new context source should be done
  * by a janitor constructor
  */
 
-GSource*	bse_glue_context_create	(SfiComPort	*port);
-
 SfiGlueContext*	bse_glue_context_intern	 (const gchar	*user);
 
 typedef SfiRec*	(*BseGlueBoxedToRec)	 (gpointer	    boxed);
@@ -39,14 +34,6 @@ typedef SfiSeq*	(*BseGlueBoxedToSeq)	 (gpointer	    boxed);
 GType			bse_glue_pspec_get_original_enum (GParamSpec *pspec);
 guint			bse_glue_enum_index	 (GType		    enum_type,
 						  gint		    enum_value);
-GType			bse_glue_make_rorecord	 (const gchar	   *rec_name,
-						  GBoxedCopyFunc    copy,
-						  GBoxedFreeFunc    free,
-						  BseGlueBoxedToRec to_record);
-GType			bse_glue_make_rosequence (const gchar	   *seq_name,
-						  GBoxedCopyFunc    copy,
-						  GBoxedFreeFunc    free,
-						  BseGlueBoxedToSeq to_sequence);
 GValue*			bse_glue_boxed_to_value	 (GType		    boxed_type,
 						  gpointer	    boxed);
 
@@ -55,10 +42,7 @@ GValue*	bse_value_to_sfi	(const GValue	*value);
 GValue*	bse_value_from_sfi	(const GValue	*value,
 				 GParamSpec	*pspec);
 
-
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* __BSE_GLUE_H__ */
 
