@@ -1,7 +1,7 @@
 
-/**
- ** Generated data (by mkcproc.pl)
- **/
+/*
+ * Generated data (by mkcproc.pl)
+ */
 #line 1 "bseitem.proc"
 
 #include <bse/bseplugin.h>
@@ -644,9 +644,9 @@ check_is_a_exec (BseProcedureClass *proc,
   return BSE_ERROR_NONE;
 }
 
-/* --- list-items --- */
+/* --- get-property-candidates --- */
 static void
-list_items_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+get_property_candidates_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 456 "bseitem.proc"
  {
 #line 458 "bseitem.proc"
@@ -654,12 +654,12 @@ list_items_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
 				 BSE_TYPE_ITEM, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("property_name", NULL, "Item property name",
 			    NULL, SFI_PARAM_STANDARD);
-  *(out_pspecs++) = bse_param_spec_boxed ("item_list", "Item List", NULL, BSE_TYPE_ITEM_SEQ, SFI_PARAM_STANDARD);
+  *(out_pspecs++) = bse_param_spec_boxed ("candidates", "Candidates", NULL, BSE_TYPE_PROPERTY_CANDIDATES, SFI_PARAM_STANDARD);
 #line 463 "bseitem.proc"
 }  }
 static BseErrorType
 #line 463 "bseitem.proc"
-list_items_exec (BseProcedureClass *proc,
+get_property_candidates_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
 #line 466 "bseitem.proc"
@@ -676,40 +676,83 @@ list_items_exec (BseProcedureClass *proc,
   
 #line 475 "bseitem.proc"
   
-  bse_value_take_boxed (out_values++, bse_item_list_items (self, property));
+  BsePropertyCandidates *pc = bse_property_candidates_new();
+  if (!bse_item_get_candidates (self, property, pc))
+    {
+      bse_property_candidates_free (pc);
+      pc = NULL;
+    }
+  bse_value_take_boxed (out_values++, pc);
+
+  return BSE_ERROR_NONE;
+}
+
+/* --- editable-property --- */
+static void
+editable_property_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 487 "bseitem.proc"
+ {
+#line 489 "bseitem.proc"
+  *(in_pspecs++) = bse_param_spec_object ("item", NULL, NULL,
+				 BSE_TYPE_ITEM, SFI_PARAM_STANDARD);
+  *(in_pspecs++) = sfi_pspec_string ("property_name", NULL, "Item property name",
+			    NULL, SFI_PARAM_STANDARD);
+  *(out_pspecs++) = sfi_pspec_bool ("editable", NULL, NULL, FALSE, SFI_PARAM_STANDARD);
+#line 494 "bseitem.proc"
+}  }
+static BseErrorType
+#line 494 "bseitem.proc"
+editable_property_exec (BseProcedureClass *proc,
+	const GValue      *in_values,
+	GValue            *out_values)
+#line 497 "bseitem.proc"
+{
+#line 498 "bseitem.proc"
   
+  BseItem *self     = bse_value_get_object (in_values++);
+  gchar   *property = sfi_value_get_string (in_values++);
+  
+#line 502 "bseitem.proc"
+  
+  if (!BSE_IS_ITEM (self) || !property)
+    return BSE_ERROR_PROC_PARAM_INVAL;
+  
+#line 506 "bseitem.proc"
+  
+  sfi_value_set_bool (out_values++, bse_object_editable_property (self, property));
+
   return BSE_ERROR_NONE;
 }
 
 /* --- get-icon --- */
 static void
 get_icon_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 481 "bseitem.proc"
+#line 512 "bseitem.proc"
  {
-#line 483 "bseitem.proc"
+#line 514 "bseitem.proc"
   *(in_pspecs++) = bse_param_spec_object ("item", NULL, NULL,
 				 BSE_TYPE_ITEM, SFI_PARAM_STANDARD);
   *(out_pspecs++) = bse_param_spec_boxed ("icon", NULL, NULL,
 				BSE_TYPE_ICON, SFI_PARAM_STANDARD);
-#line 487 "bseitem.proc"
+#line 518 "bseitem.proc"
 }  }
 static BseErrorType
-#line 487 "bseitem.proc"
+#line 518 "bseitem.proc"
 get_icon_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
-#line 490 "bseitem.proc"
+#line 521 "bseitem.proc"
 {
-#line 491 "bseitem.proc"
+#line 522 "bseitem.proc"
   
   BseItem *self     = bse_value_get_object (in_values++);
   
-#line 494 "bseitem.proc"
+#line 525 "bseitem.proc"
   
   if (!BSE_IS_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 498 "bseitem.proc"
+#line 529 "bseitem.proc"
   
   bse_value_set_boxed (out_values++, bse_object_get_icon (BSE_OBJECT (self)));
   
@@ -719,29 +762,29 @@ get_icon_exec (BseProcedureClass *proc,
 /* --- group-undo --- */
 static void
 group_undo_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 504 "bseitem.proc"
+#line 535 "bseitem.proc"
  {
-#line 506 "bseitem.proc"
+#line 537 "bseitem.proc"
   *(in_pspecs++) = bse_param_spec_object ("item", NULL, NULL,
 				 BSE_TYPE_ITEM, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("name", NULL, "A name for the undo group to be created",
                             NULL, SFI_PARAM_STANDARD);
-#line 510 "bseitem.proc"
+#line 541 "bseitem.proc"
 }  }
 static BseErrorType
-#line 510 "bseitem.proc"
+#line 541 "bseitem.proc"
 group_undo_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
-#line 513 "bseitem.proc"
+#line 544 "bseitem.proc"
 {
-#line 514 "bseitem.proc"
+#line 545 "bseitem.proc"
   
   BseItem *self     = bse_value_get_object (in_values++);
   gchar *name       = sfi_value_get_string (in_values++);
   BseUndoStack *ustack;
 
-#line 519 "bseitem.proc"
+#line 550 "bseitem.proc"
   
   if (!BSE_IS_ITEM (self) || !name)
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -756,26 +799,26 @@ group_undo_exec (BseProcedureClass *proc,
 /* --- ungroup-undo --- */
 static void
 ungroup_undo_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 530 "bseitem.proc"
+#line 561 "bseitem.proc"
  {
-#line 532 "bseitem.proc"
+#line 563 "bseitem.proc"
   *(in_pspecs++) = bse_param_spec_object ("item", NULL, NULL,
 				 BSE_TYPE_ITEM, SFI_PARAM_STANDARD);
-#line 534 "bseitem.proc"
+#line 565 "bseitem.proc"
 }  }
 static BseErrorType
-#line 534 "bseitem.proc"
+#line 565 "bseitem.proc"
 ungroup_undo_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
-#line 537 "bseitem.proc"
+#line 568 "bseitem.proc"
 {
-#line 538 "bseitem.proc"
+#line 569 "bseitem.proc"
   
   BseItem *self     = bse_value_get_object (in_values++);
   BseUndoStack *ustack;
 
-#line 542 "bseitem.proc"
+#line 573 "bseitem.proc"
   
   if (!BSE_IS_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -790,26 +833,26 @@ ungroup_undo_exec (BseProcedureClass *proc,
 /* --- undo --- */
 static void
 undo_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 553 "bseitem.proc"
+#line 584 "bseitem.proc"
  {
-#line 555 "bseitem.proc"
+#line 586 "bseitem.proc"
   *(in_pspecs++) = bse_param_spec_object ("item", NULL, NULL,
 				 BSE_TYPE_ITEM, SFI_PARAM_STANDARD);
-#line 557 "bseitem.proc"
+#line 588 "bseitem.proc"
 }  }
 static BseErrorType
-#line 557 "bseitem.proc"
+#line 588 "bseitem.proc"
 undo_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
-#line 560 "bseitem.proc"
+#line 591 "bseitem.proc"
 {
-#line 561 "bseitem.proc"
+#line 592 "bseitem.proc"
   
   BseItem *self     = bse_value_get_object (in_values++);
   BseProject *project;
 
-#line 565 "bseitem.proc"
+#line 596 "bseitem.proc"
   
   if (!BSE_IS_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -824,26 +867,26 @@ undo_exec (BseProcedureClass *proc,
 /* --- redo --- */
 static void
 redo_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 576 "bseitem.proc"
+#line 607 "bseitem.proc"
  {
-#line 578 "bseitem.proc"
+#line 609 "bseitem.proc"
   *(in_pspecs++) = bse_param_spec_object ("item", NULL, NULL,
 				 BSE_TYPE_ITEM, SFI_PARAM_STANDARD);
-#line 580 "bseitem.proc"
+#line 611 "bseitem.proc"
 }  }
 static BseErrorType
-#line 580 "bseitem.proc"
+#line 611 "bseitem.proc"
 redo_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
-#line 583 "bseitem.proc"
+#line 614 "bseitem.proc"
 {
-#line 584 "bseitem.proc"
+#line 615 "bseitem.proc"
   
   BseItem *self     = bse_value_get_object (in_values++);
   BseProject *project;
 
-#line 588 "bseitem.proc"
+#line 619 "bseitem.proc"
   
   if (!BSE_IS_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -858,26 +901,26 @@ redo_exec (BseProcedureClass *proc,
 /* --- clear-undo --- */
 static void
 clear_undo_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 599 "bseitem.proc"
+#line 630 "bseitem.proc"
  {
-#line 601 "bseitem.proc"
+#line 632 "bseitem.proc"
   *(in_pspecs++) = bse_param_spec_object ("item", NULL, NULL,
 				 BSE_TYPE_ITEM, SFI_PARAM_STANDARD);
-#line 603 "bseitem.proc"
+#line 634 "bseitem.proc"
 }  }
 static BseErrorType
-#line 603 "bseitem.proc"
+#line 634 "bseitem.proc"
 clear_undo_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
-#line 606 "bseitem.proc"
+#line 637 "bseitem.proc"
 {
-#line 607 "bseitem.proc"
+#line 638 "bseitem.proc"
   
   BseItem *self     = bse_value_get_object (in_values++);
   BseProject *project;
 
-#line 611 "bseitem.proc"
+#line 642 "bseitem.proc"
   
   if (!BSE_IS_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -892,29 +935,29 @@ clear_undo_exec (BseProcedureClass *proc,
 /* --- undo-depth --- */
 static void
 undo_depth_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 622 "bseitem.proc"
+#line 653 "bseitem.proc"
  {
-#line 624 "bseitem.proc"
+#line 655 "bseitem.proc"
   *(in_pspecs++)    = bse_param_spec_object ("item", NULL, NULL,
                                  BSE_TYPE_ITEM, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_int ("undo_depth", NULL, "Number of times undo can be called",
                          0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
-#line 628 "bseitem.proc"
+#line 659 "bseitem.proc"
 }  }
 static BseErrorType
-#line 628 "bseitem.proc"
+#line 659 "bseitem.proc"
 undo_depth_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 631 "bseitem.proc"
+#line 662 "bseitem.proc"
 {
-#line 632 "bseitem.proc"
+#line 663 "bseitem.proc"
   
   BseItem *self     = bse_value_get_object (in_values++);
   gint depth = 0;
   BseProject *project;
 
-#line 637 "bseitem.proc"
+#line 668 "bseitem.proc"
   
   if (!BSE_IS_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -923,7 +966,7 @@ undo_depth_exec (BseProcedureClass *proc,
   if (project)
     bse_item_exec (project, "undo-depth", &depth);
 
-#line 645 "bseitem.proc"
+#line 676 "bseitem.proc"
   
   sfi_value_set_int (out_values++, depth);
 
@@ -933,29 +976,29 @@ undo_depth_exec (BseProcedureClass *proc,
 /* --- redo-depth --- */
 static void
 redo_depth_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 651 "bseitem.proc"
+#line 682 "bseitem.proc"
  {
-#line 653 "bseitem.proc"
+#line 684 "bseitem.proc"
   *(in_pspecs++)    = bse_param_spec_object ("item", NULL, NULL,
                                  BSE_TYPE_ITEM, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_int ("redo_depth", NULL, "Number of times redo can be called",
                          0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
-#line 657 "bseitem.proc"
+#line 688 "bseitem.proc"
 }  }
 static BseErrorType
-#line 657 "bseitem.proc"
+#line 688 "bseitem.proc"
 redo_depth_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 660 "bseitem.proc"
+#line 691 "bseitem.proc"
 {
-#line 661 "bseitem.proc"
+#line 692 "bseitem.proc"
   
   BseItem *self     = bse_value_get_object (in_values++);
   gint depth = 0;
   BseProject *project;
 
-#line 666 "bseitem.proc"
+#line 697 "bseitem.proc"
   
   if (!BSE_IS_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -964,7 +1007,7 @@ redo_depth_exec (BseProcedureClass *proc,
   if (project)
     bse_item_exec (project, "redo-depth", &depth);
 
-#line 674 "bseitem.proc"
+#line 705 "bseitem.proc"
   
   sfi_value_set_int (out_values++, depth);
 
@@ -974,34 +1017,34 @@ redo_depth_exec (BseProcedureClass *proc,
 /* --- fixme-set-parasite --- */
 static void
 fixme_set_parasite_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 680 "bseitem.proc"
+#line 711 "bseitem.proc"
  {
-#line 681 "bseitem.proc"
+#line 712 "bseitem.proc"
   *(in_pspecs++)    = bse_param_spec_object ("item", NULL, NULL,
 				 BSE_TYPE_ITEM, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_string ("name", NULL, NULL, NULL, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_fblock ("parasite", NULL, NULL, SFI_PARAM_STANDARD);
-#line 685 "bseitem.proc"
+#line 716 "bseitem.proc"
 }  }
 static BseErrorType
-#line 685 "bseitem.proc"
+#line 716 "bseitem.proc"
 fixme_set_parasite_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
-#line 688 "bseitem.proc"
+#line 719 "bseitem.proc"
 {
-#line 689 "bseitem.proc"
+#line 720 "bseitem.proc"
   
   BseItem *self     = bse_value_get_object (in_values++);
   const gchar *name = sfi_value_get_string (in_values++);
   SfiFBlock *fblock = sfi_value_get_fblock (in_values++);
   
-#line 694 "bseitem.proc"
+#line 725 "bseitem.proc"
   
   if (!BSE_IS_ITEM (self) || !name || !fblock)
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 698 "bseitem.proc"
+#line 729 "bseitem.proc"
   
   bse_parasite_set_floats (BSE_OBJECT (self), name, fblock->n_values, fblock->values);
   
@@ -1011,33 +1054,33 @@ fixme_set_parasite_exec (BseProcedureClass *proc,
 /* --- fixme-get-parasite --- */
 static void
 fixme_get_parasite_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 704 "bseitem.proc"
+#line 735 "bseitem.proc"
  {
-#line 705 "bseitem.proc"
+#line 736 "bseitem.proc"
   *(in_pspecs++)    = bse_param_spec_object ("item", NULL, NULL,
 				 BSE_TYPE_ITEM, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_string ("name", NULL, NULL, NULL, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_fblock ("parasite", NULL, NULL, SFI_PARAM_STANDARD);
-#line 709 "bseitem.proc"
+#line 740 "bseitem.proc"
 }  }
 static BseErrorType
-#line 709 "bseitem.proc"
+#line 740 "bseitem.proc"
 fixme_get_parasite_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
-#line 712 "bseitem.proc"
+#line 743 "bseitem.proc"
 {
-#line 713 "bseitem.proc"
+#line 744 "bseitem.proc"
   
   BseItem *self     = bse_value_get_object (in_values++);
   const gchar *name = sfi_value_get_string (in_values++);
   
-#line 717 "bseitem.proc"
+#line 748 "bseitem.proc"
   
   if (!BSE_IS_ITEM (self) || !name)
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 721 "bseitem.proc"
+#line 752 "bseitem.proc"
   
   sfi_value_take_fblock (out_values++, bse_parasite_get_floats (BSE_OBJECT (self), name));
   
@@ -1337,21 +1380,38 @@ static BseExportNodeProc __enode_check_is_a = {
   0, check_is_a_setup, check_is_a_exec, 
 };
 static void
-__enode_list_items__fill_strings (BseExportStrings *es)
+__enode_get_property_candidates__fill_strings (BseExportStrings *es)
 {
-  es->blurb = "List possible values for an item property of an item.";
+  es->blurb = "Retrieve tentative values for an item or item sequence property.";
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU Lesser General Public License";
 }
-static BseExportNodeProc __enode_list_items = {
+static BseExportNodeProc __enode_get_property_candidates = {
   { (BseExportNode*) &__enode_check_is_a, BSE_EXPORT_NODE_PROC,
-    "BseItem+list-items", 
+    "BseItem+get-property-candidates", 
     NULL,
-    "/Methods/BseItem/General/List Items",
+    "/Methods/BseItem/General/Get Property Candidates",
     NULL,
-    __enode_list_items__fill_strings,
+    __enode_get_property_candidates__fill_strings,
   },
-  0, list_items_setup, list_items_exec, 
+  0, get_property_candidates_setup, get_property_candidates_exec, 
+};
+static void
+__enode_editable_property__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Test whether a property is editable according to object state and property options.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
+static BseExportNodeProc __enode_editable_property = {
+  { (BseExportNode*) &__enode_get_property_candidates, BSE_EXPORT_NODE_PROC,
+    "BseItem+editable-property", 
+    NULL,
+    "/Methods/BseItem/General/Editable Property",
+    NULL,
+    __enode_editable_property__fill_strings,
+  },
+  0, editable_property_setup, editable_property_exec, 
 };
 static void
 __enode_get_icon__fill_strings (BseExportStrings *es)
@@ -1361,7 +1421,7 @@ __enode_get_icon__fill_strings (BseExportStrings *es)
   es->license = "GNU Lesser General Public License";
 }
 static BseExportNodeProc __enode_get_icon = {
-  { (BseExportNode*) &__enode_list_items, BSE_EXPORT_NODE_PROC,
+  { (BseExportNode*) &__enode_editable_property, BSE_EXPORT_NODE_PROC,
     "BseItem+get-icon", 
     NULL,
     "/Methods/BseItem/General/Get Icon",
@@ -1529,6 +1589,6 @@ BseExportNode* bse__builtin_init_bseitem_gen_proc_c (void)
   return (BseExportNode*) &__enode_fixme_get_parasite;
 }
 
-/**
- ** Generated data ends here
- **/
+/*
+ * Generated data ends here
+ */
