@@ -60,20 +60,20 @@ struct _BseItemClass
 {
   BseObjectClass parent_class;
   
-  BseProxySeq*  (*list_proxies)  (BseItem       *item,
-                                  guint          param_id,
-                                  GParamSpec    *pspec);
-  
-  void          (*set_parent)    (BseItem       *item,
-                                  BseItem       *parent);
-  gboolean      (*needs_storage) (BseItem       *item,
-                                  BseStorage    *storage);
-  void          (*compat_setup)  (BseItem       *item,
-                                  guint          vmajor,
-                                  guint          vminor,
-                                  guint          vmicro);
-  guint         (*get_seqid)     (BseItem       *item);
-  BseUndoStack* (*get_undo)      (BseItem       *item);
+  void          (*get_candidates) (BseItem               *item,
+                                   guint                  param_id,
+                                   BsePropertyCandidates *pc,
+                                   GParamSpec            *pspec);
+  void          (*set_parent)     (BseItem               *item,
+                                   BseItem               *parent);
+  gboolean      (*needs_storage)  (BseItem               *item,
+                                   BseStorage            *storage);
+  void          (*compat_setup)   (BseItem               *item,
+                                   guint                  vmajor,
+                                   guint                  vminor,
+                                   guint                  vmicro);
+  guint         (*get_seqid)      (BseItem               *item);
+  BseUndoStack* (*get_undo)       (BseItem               *item);
 };
 
 typedef void     (*BseItemUncross)           (BseItem        *owner,
@@ -87,19 +87,20 @@ typedef gboolean (*BseItemCheckProxy)        (BseItem        *proxy,
 
 
 /* --- prototypes --- */
-BseProxySeq*    bse_item_gather_proxies      (BseItem              *item,
-                                              BseProxySeq          *proxies,
-                                              GType                 base_type,
-                                              BseItemCheckContainer ccheck,
-                                              BseItemCheckProxy     pcheck,
-                                              gpointer              data);
-BseProxySeq*    bse_item_gather_proxies_typed(BseItem              *item,
-                                              BseProxySeq          *proxies,
-                                              GType                 proxy_type,
-                                              GType                 container_type,
-                                              gboolean              allow_ancestor);
-BseProxySeq*    bse_item_list_proxies        (BseItem         *item,
-                                              const gchar     *property);
+BseItemSeq*    bse_item_gather_items         (BseItem                *item,
+                                              BseItemSeq             *iseq,
+                                              GType                   base_type,
+                                              BseItemCheckContainer   ccheck,
+                                              BseItemCheckProxy       pcheck,
+                                              gpointer                data);
+BseItemSeq*    bse_item_gather_items_typed   (BseItem                *item,
+                                              BseItemSeq             *iseq,
+                                              GType                   proxy_type,
+                                              GType                   container_type,
+                                              gboolean                allow_ancestor);
+gboolean        bse_item_get_candidates      (BseItem                *item,
+                                              const gchar            *property,
+                                              BsePropertyCandidates  *pc);
 void            bse_item_set_internal        (gpointer         item,
                                               gboolean         internal);
 gboolean        bse_item_needs_storage       (BseItem         *item,
@@ -111,6 +112,7 @@ void            bse_item_compat_setup        (BseItem         *item,
 guint           bse_item_get_seqid           (BseItem         *item);
 void            bse_item_queue_seqid_changed (BseItem         *item);
 BseSuper*       bse_item_get_super           (BseItem         *item);
+BseSNet*        bse_item_get_snet            (BseItem         *item);
 BseProject*     bse_item_get_project         (BseItem         *item);
 BseItem*        bse_item_get_toplevel        (BseItem         *item);
 gboolean        bse_item_has_ancestor        (BseItem         *item,
