@@ -82,7 +82,7 @@ get_script_name_exec (BseProcedureClass *proc,
   
 #line 72 "bsejanitor.proc"
   
-  sfi_value_set_string (out_values++, bse_janitor_get_script (self));
+  sfi_value_set_string (out_values++, self->script_name);
   
   return BSE_ERROR_NONE;
 }
@@ -319,14 +319,44 @@ kill_exec (BseProcedureClass *proc,
   return BSE_ERROR_NONE;
 }
 
-/* --- add-action --- */
+/* --- bse-script-janitor --- */
 static void
-add_action_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+bse_script_janitor_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 238 "bsejanitor.proc"
  {
 #line 240 "bsejanitor.proc"
-  *(in_pspecs++)    = bse_param_spec_object ("janitor", "Janitor", NULL,
+  *(out_pspecs++)   = bse_param_spec_object ("janitor", "Janitor", NULL,
 				 BSE_TYPE_JANITOR, SFI_PARAM_STANDARD);
+}
+#line 243 "bsejanitor.proc"
+ }
+static BseErrorType
+#line 243 "bsejanitor.proc"
+bse_script_janitor_exec (BseProcedureClass *proc,
+      const GValue      *in_values,
+      GValue            *out_values)
+#line 246 "bsejanitor.proc"
+{
+  BseJanitor *self = bse_janitor_get_current ();
+  
+#line 249 "bsejanitor.proc"
+  
+  if (!self || !self->port || self->port_closed)
+    return BSE_ERROR_PROC_EXECUTION;
+
+#line 253 "bsejanitor.proc"
+  
+  bse_value_set_object (out_values++, self);
+  
+  return BSE_ERROR_NONE;
+}
+
+/* --- bse-script-add-action --- */
+static void
+bse_script_add_action_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 259 "bsejanitor.proc"
+ {
+#line 261 "bsejanitor.proc"
   *(in_pspecs++) = sfi_pspec_string ("action", "Action", NULL,
 			    NULL, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("name", "Name", NULL,
@@ -334,250 +364,239 @@ add_action_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
   *(in_pspecs++) = sfi_pspec_string ("blurb", "Blurb", NULL,
 			    NULL, SFI_PARAM_STANDARD);
 }
-#line 249 "bsejanitor.proc"
+#line 268 "bsejanitor.proc"
  }
 static BseErrorType
-#line 249 "bsejanitor.proc"
-add_action_exec (BseProcedureClass *proc,
+#line 268 "bsejanitor.proc"
+bse_script_add_action_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 252 "bsejanitor.proc"
+#line 271 "bsejanitor.proc"
 {
-#line 253 "bsejanitor.proc"
+#line 272 "bsejanitor.proc"
   
-  BseJanitor       *self   = bse_value_get_object (in_values++);
-  const gchar      *action = sfi_value_get_string (in_values++);
-  const gchar      *name   = sfi_value_get_string (in_values++);
-  const gchar      *blurb  = sfi_value_get_string (in_values++);
+  BseJanitor  *self   = bse_janitor_get_current ();
+  const gchar *action = sfi_value_get_string (in_values++);
+  const gchar *name   = sfi_value_get_string (in_values++);
+  const gchar *blurb  = sfi_value_get_string (in_values++);
   
-#line 259 "bsejanitor.proc"
+#line 278 "bsejanitor.proc"
   
   if (!BSE_IS_JANITOR (self) || !action || !name)
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 263 "bsejanitor.proc"
+#line 282 "bsejanitor.proc"
   
-  if (!self->port || self->close_pending)
+  if (!self->port || self->port_closed)
     return BSE_ERROR_PROC_EXECUTION;
   
-#line 267 "bsejanitor.proc"
+#line 286 "bsejanitor.proc"
   
   bse_janitor_add_action (self, action, name, blurb);
   
   return BSE_ERROR_NONE;
 }
 
-/* --- remove-action --- */
+/* --- bse-script-remove-action --- */
 static void
-remove_action_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 273 "bsejanitor.proc"
+bse_script_remove_action_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 292 "bsejanitor.proc"
  {
-#line 275 "bsejanitor.proc"
-  *(in_pspecs++) = bse_param_spec_object ("janitor", "Janitor", NULL,
-				 BSE_TYPE_JANITOR, SFI_PARAM_STANDARD);
+#line 294 "bsejanitor.proc"
   *(in_pspecs++) = sfi_pspec_string ("action", "Action", NULL,
 			    NULL, SFI_PARAM_STANDARD);
 }
-#line 280 "bsejanitor.proc"
+#line 297 "bsejanitor.proc"
  }
 static BseErrorType
-#line 280 "bsejanitor.proc"
-remove_action_exec (BseProcedureClass *proc,
+#line 297 "bsejanitor.proc"
+bse_script_remove_action_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 283 "bsejanitor.proc"
+#line 300 "bsejanitor.proc"
 {
-#line 284 "bsejanitor.proc"
+#line 301 "bsejanitor.proc"
   
-  BseJanitor  *self = bse_value_get_object (in_values++);
+  BseJanitor  *self   = bse_janitor_get_current ();
   const gchar *action = sfi_value_get_string (in_values++);
   
-#line 288 "bsejanitor.proc"
+#line 305 "bsejanitor.proc"
   
   if (!BSE_IS_JANITOR (self) || !action)
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 292 "bsejanitor.proc"
+#line 309 "bsejanitor.proc"
   
-  if (!self->port || self->close_pending)
+  if (!self->port || self->port_closed)
     return BSE_ERROR_PROC_EXECUTION;
   
-#line 296 "bsejanitor.proc"
+#line 313 "bsejanitor.proc"
   
   bse_janitor_remove_action (self, action);
   
   return BSE_ERROR_NONE;
 }
 
-/* --- bse-janitor-get-specific --- */
+/* --- bse-script-set-status --- */
 static void
-bse_janitor_get_specific_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 302 "bsejanitor.proc"
+bse_script_set_status_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 319 "bsejanitor.proc"
  {
-#line 304 "bsejanitor.proc"
-  *(out_pspecs++)   = bse_param_spec_object ("janitor", "Janitor", NULL,
-				 BSE_TYPE_JANITOR, SFI_PARAM_STANDARD);
-}
-#line 307 "bsejanitor.proc"
- }
-static BseErrorType
-#line 307 "bsejanitor.proc"
-bse_janitor_get_specific_exec (BseProcedureClass *proc,
-      const GValue      *in_values,
-      GValue            *out_values)
-#line 310 "bsejanitor.proc"
-{
-  BseJanitor *self = bse_janitor_get_current ();
-  
-#line 313 "bsejanitor.proc"
-  
-  if (!self || !self->port || self->close_pending)
-    return BSE_ERROR_PROC_EXECUTION;
-
-#line 317 "bsejanitor.proc"
-  
-  bse_value_set_object (out_values++, self);
-  
-  return BSE_ERROR_NONE;
-}
-
-/* --- set-msg --- */
-static void
-set_msg_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 323 "bsejanitor.proc"
- {
-#line 325 "bsejanitor.proc"
-  *(in_pspecs++)    = bse_param_spec_object ("janitor", "Janitor", NULL,
-				 BSE_TYPE_JANITOR, SFI_PARAM_STANDARD);
-  *(in_pspecs++)    = bse_param_spec_genum ("msg_type", "Message Type", NULL,
-				BSE_TYPE_USER_MSG_TYPE, BSE_USER_MSG_INFO,
-				SFI_PARAM_STANDARD);
+#line 321 "bsejanitor.proc"
   *(in_pspecs++)    = sfi_pspec_string ("message", "Message", NULL,
 			    NULL, SFI_PARAM_STANDARD);
-#line 332 "bsejanitor.proc"
+#line 323 "bsejanitor.proc"
 }  }
 static BseErrorType
-#line 332 "bsejanitor.proc"
-set_msg_exec (BseProcedureClass *proc,
+#line 323 "bsejanitor.proc"
+bse_script_set_status_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
-#line 335 "bsejanitor.proc"
+#line 326 "bsejanitor.proc"
 {
-#line 336 "bsejanitor.proc"
+#line 327 "bsejanitor.proc"
   
-  BseJanitor    *self = bse_value_get_object (in_values++);
-  BseUserMsgType mtype   = g_value_get_enum (in_values++);
+  BseJanitor    *self    = bse_janitor_get_current ();
   const gchar   *message = sfi_value_get_string (in_values++);
   
+#line 331 "bsejanitor.proc"
+  
+  if (!BSE_IS_JANITOR (self))
+    return BSE_ERROR_PROC_PARAM_INVAL;
+
+#line 335 "bsejanitor.proc"
+  
+  if (!self->port || self->port_closed)
+    return BSE_ERROR_PROC_EXECUTION;
+  if (!message)
+    message = "";
+  
 #line 341 "bsejanitor.proc"
   
-  if (!BSE_IS_JANITOR (self))
-    return BSE_ERROR_PROC_PARAM_INVAL;
-
-#line 345 "bsejanitor.proc"
-  
-  if (!self->port || self->close_pending)
-    return BSE_ERROR_PROC_EXECUTION;
-  if (!message)
-    {
-      message = bse_janitor_get_ident (self);
-      mtype = BSE_USER_MSG_INFO;
-    }
-  
-#line 354 "bsejanitor.proc"
-  
-  bse_item_set (self,
-		"user_msg_type", mtype,
-		"user_msg", message,
-		NULL);
+  bse_item_set (self, "status-message", message, NULL);
   
   return BSE_ERROR_NONE;
 }
 
-/* --- progress --- */
+/* --- bse-script-progress --- */
 static void
-progress_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 363 "bsejanitor.proc"
+bse_script_progress_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 347 "bsejanitor.proc"
  {
-#line 365 "bsejanitor.proc"
-  *(in_pspecs++)    = bse_param_spec_object ("janitor", "Janitor", NULL,
-				 BSE_TYPE_JANITOR, SFI_PARAM_STANDARD);
+#line 349 "bsejanitor.proc"
   *(in_pspecs++)    = sfi_pspec_real ("progress", "Progress", NULL,
 			  -1, -1, 1.0, 0.1,
 			  SFI_PARAM_STANDARD);
-#line 370 "bsejanitor.proc"
+#line 352 "bsejanitor.proc"
 }  }
 static BseErrorType
-#line 370 "bsejanitor.proc"
-progress_exec (BseProcedureClass *proc,
+#line 352 "bsejanitor.proc"
+bse_script_progress_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
-#line 373 "bsejanitor.proc"
+#line 355 "bsejanitor.proc"
 {
-#line 374 "bsejanitor.proc"
+#line 356 "bsejanitor.proc"
   
-  BseJanitor *self = bse_value_get_object (in_values++);
+  BseJanitor *self = bse_janitor_get_current ();
   gfloat progress  = sfi_value_get_real (in_values++);
   
-#line 378 "bsejanitor.proc"
+#line 360 "bsejanitor.proc"
   
   if (!BSE_IS_JANITOR (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
 
-#line 382 "bsejanitor.proc"
+#line 364 "bsejanitor.proc"
   
-  if (!self->port || self->close_pending)
+  if (!self->port || self->port_closed)
     return BSE_ERROR_PROC_EXECUTION;
   
-#line 386 "bsejanitor.proc"
+#line 368 "bsejanitor.proc"
   
   bse_janitor_progress (self, progress);
   
   return BSE_ERROR_NONE;
 }
 
-/* --- exit --- */
+/* --- bse-script-send-message --- */
 static void
-exit_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 392 "bsejanitor.proc"
+bse_script_send_message_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 374 "bsejanitor.proc"
  {
-#line 394 "bsejanitor.proc"
-  *(in_pspecs++)    = bse_param_spec_object ("janitor", "Janitor", NULL,
-				 BSE_TYPE_JANITOR, SFI_PARAM_STANDARD);
-  *(in_pspecs++)    = bse_param_spec_genum ("msg_type", "Message Type", NULL,
-				BSE_TYPE_USER_MSG_TYPE, BSE_USER_MSG_INFO,
-				SFI_PARAM_STANDARD);
-  *(in_pspecs++)    = sfi_pspec_string ("message", "Message", NULL,
-			    NULL, SFI_PARAM_STANDARD);
-#line 401 "bsejanitor.proc"
+#line 376 "bsejanitor.proc"
+  
+  *(in_pspecs++)    = sfi_pspec_string ("domain", NULL, NULL, NULL, SFI_PARAM_STANDARD);
+  *(in_pspecs++)    = sfi_pspec_string ("msg-type", NULL, NULL, NULL, SFI_PARAM_STANDARD);
+  *(in_pspecs++)    = sfi_pspec_string ("title", NULL, NULL, NULL, SFI_PARAM_STANDARD);
+  *(in_pspecs++)    = sfi_pspec_string ("primary", NULL, NULL, NULL, SFI_PARAM_STANDARD);
+  *(in_pspecs++)    = sfi_pspec_string ("secondary", NULL, NULL, NULL, SFI_PARAM_STANDARD);
+  *(in_pspecs++)    = sfi_pspec_string ("details", NULL, NULL, NULL, SFI_PARAM_STANDARD);
+  *(in_pspecs++)    = sfi_pspec_string ("config-check", NULL, NULL, NULL, SFI_PARAM_STANDARD);
+#line 384 "bsejanitor.proc"
 }  }
 static BseErrorType
-#line 401 "bsejanitor.proc"
-exit_exec (BseProcedureClass *proc,
+#line 384 "bsejanitor.proc"
+bse_script_send_message_exec (BseProcedureClass *proc,
+        const GValue      *in_values,
+        GValue            *out_values)
+#line 387 "bsejanitor.proc"
+{
+#line 388 "bsejanitor.proc"
+  
+  BseJanitor *janitor = bse_janitor_get_current();
+  const gchar *domain = sfi_value_get_string (in_values++);
+  const gchar *mtype  = sfi_value_get_string (in_values++);
+  const gchar *text0  = sfi_value_get_string (in_values++);
+  const gchar *text1  = sfi_value_get_string (in_values++);
+  const gchar *text2  = sfi_value_get_string (in_values++);
+  const gchar *text3  = sfi_value_get_string (in_values++);
+  const gchar *check  = sfi_value_get_string (in_values++);
+  SfiMsgType    type  = mtype ? sfi_msg_type_lookup (mtype) : 0;
+
+#line 399 "bsejanitor.proc"
+  
+  if (!mtype || !(text1 || text2))
+    return BSE_ERROR_PROC_PARAM_INVAL;
+
+#line 403 "bsejanitor.proc"
+  
+  if (!BSE_IS_JANITOR (janitor) || !janitor->port || janitor->port_closed)
+    return BSE_ERROR_PROC_EXECUTION;
+
+#line 407 "bsejanitor.proc"
+  
+  bse_server_message (bse_server_get (), domain, type, text0, text1, text2, text3, check, janitor, NULL, janitor->port->remote_pid);
+
+  return BSE_ERROR_NONE;
+}
+
+/* --- bse-script-quit --- */
+static void
+bse_script_quit_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 413 "bsejanitor.proc"
+ {
+#line 415 "bsejanitor.proc"
+}  }
+static BseErrorType
+#line 415 "bsejanitor.proc"
+bse_script_quit_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
-#line 404 "bsejanitor.proc"
+#line 418 "bsejanitor.proc"
 {
-#line 405 "bsejanitor.proc"
+#line 419 "bsejanitor.proc"
   
-  BseJanitor *self       = bse_value_get_object (in_values++);
-  BseUserMsgType mtype   = g_value_get_enum (in_values++);
-  const gchar   *message = sfi_value_get_string (in_values++);
+  BseJanitor *janitor = bse_janitor_get_current();
+
+#line 422 "bsejanitor.proc"
   
-#line 410 "bsejanitor.proc"
-  
-  if (!BSE_IS_JANITOR (self) || !message)
-    return BSE_ERROR_PROC_PARAM_INVAL;
-  
-#line 414 "bsejanitor.proc"
-  
-  if (!BSE_IS_JANITOR (self) || !self->port || self->close_pending)
+  if (!BSE_IS_JANITOR (janitor) || !janitor->port || janitor->port_closed)
     return BSE_ERROR_PROC_EXECUTION;
   
-#line 418 "bsejanitor.proc"
+#line 426 "bsejanitor.proc"
   
-  bse_server_user_message (bse_server_get (), "BSE-SCRIPT", mtype, NULL, message, self->port ? self->port->remote_pid : 0, self->script_name);
-  bse_janitor_close (self);
+  janitor->force_normal_exit = TRUE;
+  bse_janitor_close (janitor);
   
   return BSE_ERROR_NONE;
 }
@@ -720,111 +739,128 @@ static BseExportNodeProc __enode_kill = {
   0, kill_setup, kill_exec, 
 };
 static void
-__enode_add_action__fill_strings (BseExportStrings *es)
-{
-  es->blurb = "Install a user action for script control.";
-  es->authors = "Tim Janik <timj@gtk.org>";
-  es->license = "GNU General Public License";
-}
-static BseExportNodeProc __enode_add_action = {
-  { (BseExportNode*) &__enode_kill, BSE_EXPORT_NODE_PROC,
-    "BseJanitor+add-action", 
-    NULL,
-    "/Methods/BseJanitor/General/Add Action",
-    NULL,
-    __enode_add_action__fill_strings,
-  },
-  0, add_action_setup, add_action_exec, 
-};
-static void
-__enode_remove_action__fill_strings (BseExportStrings *es)
-{
-  es->blurb = "Remove a previously installed user action from script control.";
-  es->authors = "Tim Janik <timj@gtk.org>";
-  es->license = "GNU General Public License";
-}
-static BseExportNodeProc __enode_remove_action = {
-  { (BseExportNode*) &__enode_add_action, BSE_EXPORT_NODE_PROC,
-    "BseJanitor+remove-action", 
-    NULL,
-    "/Methods/BseJanitor/General/Remove Action",
-    NULL,
-    __enode_remove_action__fill_strings,
-  },
-  0, remove_action_setup, remove_action_exec, 
-};
-static void
-__enode_bse_janitor_get_specific__fill_strings (BseExportStrings *es)
+__enode_bse_script_janitor__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Retrieve the connection dependant janitor object.";
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
-static BseExportNodeProc __enode_bse_janitor_get_specific = {
-  { (BseExportNode*) &__enode_remove_action, BSE_EXPORT_NODE_PROC,
-    "bse-janitor-get-specific", 
+static BseExportNodeProc __enode_bse_script_janitor = {
+  { (BseExportNode*) &__enode_kill, BSE_EXPORT_NODE_PROC,
+    "bse-script-janitor", 
     NULL,
-    "/Proc/Janitor/Get Specific",
+    "/Proc/Script/Get Janitor",
     NULL,
-    __enode_bse_janitor_get_specific__fill_strings,
+    __enode_bse_script_janitor__fill_strings,
   },
-  0, bse_janitor_get_specific_setup, bse_janitor_get_specific_exec, 
+  0, bse_script_janitor_setup, bse_script_janitor_exec, 
 };
 static void
-__enode_set_msg__fill_strings (BseExportStrings *es)
+__enode_bse_script_add_action__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Install a user action for script control.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
+static BseExportNodeProc __enode_bse_script_add_action = {
+  { (BseExportNode*) &__enode_bse_script_janitor, BSE_EXPORT_NODE_PROC,
+    "bse-script-add-action", 
+    NULL,
+    "/Proc/Script/Add Action",
+    NULL,
+    __enode_bse_script_add_action__fill_strings,
+  },
+  0, bse_script_add_action_setup, bse_script_add_action_exec, 
+};
+static void
+__enode_bse_script_remove_action__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Remove a previously installed user action from script control.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
+static BseExportNodeProc __enode_bse_script_remove_action = {
+  { (BseExportNode*) &__enode_bse_script_add_action, BSE_EXPORT_NODE_PROC,
+    "bse-script-remove-action", 
+    NULL,
+    "/Proc/Script/Remove Action",
+    NULL,
+    __enode_bse_script_remove_action__fill_strings,
+  },
+  0, bse_script_remove_action_setup, bse_script_remove_action_exec, 
+};
+static void
+__enode_bse_script_set_status__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Alter script status message.";
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
-static BseExportNodeProc __enode_set_msg = {
-  { (BseExportNode*) &__enode_bse_janitor_get_specific, BSE_EXPORT_NODE_PROC,
-    "BseJanitor+set-msg", 
+static BseExportNodeProc __enode_bse_script_set_status = {
+  { (BseExportNode*) &__enode_bse_script_remove_action, BSE_EXPORT_NODE_PROC,
+    "bse-script-set-status", 
     NULL,
-    "/Methods/BseJanitor/General/Set Msg",
+    "/Proc/Script/Set Status",
     NULL,
-    __enode_set_msg__fill_strings,
+    __enode_bse_script_set_status__fill_strings,
   },
-  0, set_msg_setup, set_msg_exec, 
+  0, bse_script_set_status_setup, bse_script_set_status_exec, 
 };
 static void
-__enode_progress__fill_strings (BseExportStrings *es)
+__enode_bse_script_progress__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Indicate progress (from 0.0 to 1.0 or -1 for unknown amount).";
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
-static BseExportNodeProc __enode_progress = {
-  { (BseExportNode*) &__enode_set_msg, BSE_EXPORT_NODE_PROC,
-    "BseJanitor+progress", 
+static BseExportNodeProc __enode_bse_script_progress = {
+  { (BseExportNode*) &__enode_bse_script_set_status, BSE_EXPORT_NODE_PROC,
+    "bse-script-progress", 
     NULL,
-    "/Methods/BseJanitor/General/Progress",
+    "/Proc/Script/Progress",
     NULL,
-    __enode_progress__fill_strings,
+    __enode_bse_script_progress__fill_strings,
   },
-  0, progress_setup, progress_exec, 
+  0, bse_script_progress_setup, bse_script_progress_exec, 
 };
 static void
-__enode_exit__fill_strings (BseExportStrings *es)
+__enode_bse_script_send_message__fill_strings (BseExportStrings *es)
 {
-  es->blurb = "Exit a script, leaving a message.";
+  es->blurb = "Send a message from a script.";
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
-static BseExportNodeProc __enode_exit = {
-  { (BseExportNode*) &__enode_progress, BSE_EXPORT_NODE_PROC,
-    "BseJanitor+exit", 
+static BseExportNodeProc __enode_bse_script_send_message = {
+  { (BseExportNode*) &__enode_bse_script_progress, BSE_EXPORT_NODE_PROC,
+    "bse-script-send-message", 
     NULL,
-    "/Methods/BseJanitor/General/Exit",
+    "/Proc/Script/Message",
     NULL,
-    __enode_exit__fill_strings,
+    __enode_bse_script_send_message__fill_strings,
   },
-  0, exit_setup, exit_exec, 
+  0, bse_script_send_message_setup, bse_script_send_message_exec, 
+};
+static void
+__enode_bse_script_quit__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Exit a script succesfully (server side).";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
+static BseExportNodeProc __enode_bse_script_quit = {
+  { (BseExportNode*) &__enode_bse_script_send_message, BSE_EXPORT_NODE_PROC,
+    "bse-script-quit", 
+    NULL,
+    "/Proc/Script/Quit",
+    NULL,
+    __enode_bse_script_quit__fill_strings,
+  },
+  0, bse_script_quit_setup, bse_script_quit_exec, 
 };
 BseExportNode* bse__builtin_init_bsejanitor_gen_proc_c (void);
 BseExportNode* bse__builtin_init_bsejanitor_gen_proc_c (void)
 {
-  return (BseExportNode*) &__enode_exit;
+  return (BseExportNode*) &__enode_bse_script_quit;
 }
 
 /*
