@@ -17,14 +17,15 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#include "gslloader.h"
+#include "bseloader.h"
 #include <stdio.h>
 #include <errno.h>
 #include <vector>
 #include <string>
 
 #undef  WITH_GUSPATCH_XINFOS
-#define GUS_PATCH_DEBUG(...)         sfi_debug ("guspatch", __VA_ARGS__)
+static SFI_MSG_TYPE_DEFINE (debug_guspatch, "guspatch", SFI_MSG_DEBUG, NULL);
+#define DEBUG(...)      sfi_debug (debug_guspatch, __VA_ARGS__)
 
 using std::vector;
 using std::string;
@@ -299,8 +300,8 @@ namespace {
  */
 struct FileInfo
 {
-  GslWaveFileInfo wfi;
-  GslWaveDsc      wdsc;
+  BseWaveFileInfo wfi;
+  BseWaveDsc      wdsc;
   
   PatHeader          *header;
   PatInstrument      *instrument;
@@ -316,7 +317,7 @@ struct FileInfo
 	  {
 	    if (wave_format & PAT_FORMAT_LOOP_BACKWARDS)
 	      {
-		GUS_PATCH_DEBUG ("unsupported loop type (backwards-pingpong)");
+		DEBUG ("unsupported loop type (backwards-pingpong)");
 		return GSL_WAVE_LOOP_PINGPONG;
 	      }
 	    else
@@ -328,7 +329,7 @@ struct FileInfo
 	  {
 	    if (wave_format & PAT_FORMAT_LOOP_BACKWARDS)
 	      {
-		GUS_PATCH_DEBUG ("unsupported loop type (backwards-jump)");
+		DEBUG ("unsupported loop type (backwards-jump)");
 		return GSL_WAVE_LOOP_JUMP;
 	      }
 	    else
@@ -429,7 +430,7 @@ struct FileInfo
         return;
       }
     
-    /* allocate GslWaveDsc */
+    /* allocate BseWaveDsc */
     wdsc.n_chunks = instrument->sampleCount;
     wdsc.chunks = (typeof (wdsc.chunks)) g_malloc0 (sizeof (wdsc.chunks[0]) * wdsc.n_chunks);
     
@@ -450,16 +451,16 @@ struct FileInfo
 	    fclose (patfile);
 	    return;
 	  }
-	GUS_PATCH_DEBUG (" - read patch, srate = %d (%d bytes)", patch->sampleRate, patch->wavesize);
+	DEBUG (" - read patch, srate = %d (%d bytes)", patch->sampleRate, patch->wavesize);
       }
     fclose (patfile);
     
-    /* allocate and fill GslWaveFileInfo */
+    /* allocate and fill BseWaveFileInfo */
     wfi.n_waves = 1;
     wfi.waves = (typeof (wfi.waves)) g_malloc0 (sizeof (wfi.waves[0]) * wfi.n_waves);
     wfi.waves[0].name = g_strdup (file_name);
     
-    /* fill GslWaveDsc */
+    /* fill BseWaveDsc */
     wdsc.name = g_strdup (file_name);
     /* header->channels means output channels, GUS Patches are mono only */
     wdsc.n_channels = 1;
@@ -473,12 +474,12 @@ struct FileInfo
 	wdsc.chunks[i].mix_freq = patches[i]->sampleRate;
 	wdsc.chunks[i].osc_freq = patches[i]->origFreq / 1000.0;
         
-	GUS_PATCH_DEBUG ("orig_freq = %f (%d)", patches[i]->origFreq / 1000.0, patches[i]->origFreq);
-	GUS_PATCH_DEBUG ("min_freq = %f", patches[i]->minFreq / 1000.0);
-	GUS_PATCH_DEBUG ("max_freq = %f", patches[i]->maxFreq / 1000.0);
-	GUS_PATCH_DEBUG ("fine_tune = %d", patches[i]->fineTune);
-	GUS_PATCH_DEBUG ("scale_freq = %d", patches[i]->freqScale);
-	GUS_PATCH_DEBUG ("scale_factor = %d", patches[i]->freqScaleFactor);
+	DEBUG ("orig_freq = %f (%d)", patches[i]->origFreq / 1000.0, patches[i]->origFreq);
+	DEBUG ("min_freq = %f", patches[i]->minFreq / 1000.0);
+	DEBUG ("max_freq = %f", patches[i]->maxFreq / 1000.0);
+	DEBUG ("fine_tune = %d", patches[i]->fineTune);
+	DEBUG ("scale_freq = %d", patches[i]->freqScale);
+	DEBUG ("scale_factor = %d", patches[i]->freqScaleFactor);
         
 	/* fill xinfos */
 	char**& xinfos = wdsc.chunks[i].xinfos;
@@ -528,7 +529,7 @@ struct FileInfo
     delete instrument;
     delete header;
     
-    /* free GslWaveDsc */
+    /* free BseWaveDsc */
     for (guint i = 0; i < wdsc.n_chunks; i++)
       g_strfreev (wdsc.chunks[i].xinfos);
     
@@ -536,7 +537,7 @@ struct FileInfo
     g_free (wdsc.name);
     g_free (wdsc.chunks);
     
-    /* free GslWaveFileInfo */
+    /* free BseWaveFileInfo */
     if (wfi.waves)
       {
 	g_free (wfi.waves[0].name);
@@ -545,7 +546,7 @@ struct FileInfo
   }
 };
 
-static GslWaveFileInfo*
+static BseWaveFileInfo*
 pat_load_file_info (gpointer      data,
 		    const gchar  *file_name,
 		    BseErrorType *error_p)
@@ -562,15 +563,15 @@ pat_load_file_info (gpointer      data,
 
 static void
 pat_free_file_info (gpointer         data,
-		    GslWaveFileInfo *wave_file_info)
+		    BseWaveFileInfo *wave_file_info)
 {
   FileInfo *file_info = reinterpret_cast<FileInfo*> (wave_file_info);
   delete file_info;
 }
 
-static GslWaveDsc*
+static BseWaveDsc*
 pat_load_wave_dsc (gpointer         data,
-		   GslWaveFileInfo *wave_file_info,
+		   BseWaveFileInfo *wave_file_info,
 		   guint            nth_wave,
 		   BseErrorType    *error_p)
 {
@@ -580,13 +581,13 @@ pat_load_wave_dsc (gpointer         data,
 
 static void
 pat_free_wave_dsc (gpointer    data,
-		   GslWaveDsc *wave_dsc)
+		   BseWaveDsc *wave_dsc)
 {
 }
 
 static GslDataHandle*
 pat_create_chunk_handle (gpointer      data,
-			 GslWaveDsc   *wave_dsc,
+			 BseWaveDsc   *wave_dsc,
 			 guint         nth_chunk,
 			 BseErrorType *error_p)
 {
@@ -594,18 +595,18 @@ pat_create_chunk_handle (gpointer      data,
   
   FileInfo *file_info = reinterpret_cast<FileInfo*> (wave_dsc->file_info);
   const PatPatch *patch = file_info->patches[nth_chunk];
-  const GslWaveChunkDsc *chunk = &wave_dsc->chunks[nth_chunk];
+  const BseWaveChunkDsc *chunk = &wave_dsc->chunks[nth_chunk];
   
-  GUS_PATCH_DEBUG ("pat loader chunk %d: gsl_wave_handle_new %s %d %d %d %f %f %u %d",
-                   nth_chunk,
-                   file_info->wfi.file_name,
-                   wave_dsc->n_channels,
-                   file_info->wave_format (patch->waveFormat),
-                   G_LITTLE_ENDIAN,
-                   chunk->mix_freq,
-                   chunk->osc_freq,
-                   file_info->data_offset (nth_chunk),
-                   patch->wavesize / file_info->bytes_per_frame (patch->waveFormat));
+  DEBUG ("pat loader chunk %d: gsl_wave_handle_new %s %d %d %d %f %f %u %d",
+         nth_chunk,
+         file_info->wfi.file_name,
+         wave_dsc->n_channels,
+         file_info->wave_format (patch->waveFormat),
+         G_LITTLE_ENDIAN,
+         chunk->mix_freq,
+         chunk->osc_freq,
+         file_info->data_offset (nth_chunk),
+         patch->wavesize / file_info->bytes_per_frame (patch->waveFormat));
   
   GslDataHandle *dhandle;
   dhandle = gsl_wave_handle_new (file_info->wfi.file_name,
@@ -632,11 +633,11 @@ bse_init_loader_gus_patch (void)
     "0  string  GF1PATCH100\0ID#000002\0",      // GUS patch V1.0
     NULL,
   };
-  static GslLoader loader = {
+  static BseLoader loader = {
     "GUS Patch",
     file_exts,
     mime_types,
-    GSL_LOADER_NO_FLAGS,
+    BSE_LOADER_NO_FLAGS,
     magics,
     0,  /* priority */
     NULL,
@@ -651,5 +652,5 @@ bse_init_loader_gus_patch (void)
   g_assert (initialized == FALSE);
   initialized = TRUE;
   
-  gsl_loader_register (&loader);
+  bse_loader_register (&loader);
 }
