@@ -24,6 +24,7 @@ G_BEGIN_DECLS
 
 
 /* --- initialization --- */
+void		bse_init_textdomain_only (void);
 #if 0	// prototyped in bse.h */
 void		bse_init_async		(gint		*argc,
 					 gchar	      ***argv,
@@ -42,7 +43,7 @@ void		bse_init_intern		(gint		*argc,
 guint           bse_main_getpid         (void);
 
 /* MT-safe log handler */
-void            bse_log_handler         (SfiLogMessage  *message);
+void            bse_msg_handler         (const SfiMessage *message);
 
 /* --- global macros --- */
 #define	BSE_THREADS_ENTER()			// bse_main_global_lock ()
