@@ -19,7 +19,8 @@
 
 #include	"bseserver.h"
 
-#define MIDI_DEBUG(...) sfi_debug ("midi", __VA_ARGS__)
+static SFI_MSG_TYPE_DEFINE (debug_midi, "midi", SFI_MSG_DEBUG, NULL);
+#define MIDI_DEBUG(...) sfi_debug (debug_midi, __VA_ARGS__)
 
 /* --- structs --- */
 typedef struct
@@ -56,11 +57,7 @@ bse_midi_device_null_open (BseDevice     *device,
   handle->readable = require_readable;
   handle->writable = require_writable;
   
-  BSE_OBJECT_SET_FLAGS (device, BSE_DEVICE_FLAG_OPEN);
-  if (handle->readable)
-    BSE_OBJECT_SET_FLAGS (device, BSE_DEVICE_FLAG_READABLE);
-  if (handle->writable)
-    BSE_OBJECT_SET_FLAGS (device, BSE_DEVICE_FLAG_WRITABLE);
+  bse_device_set_opened (device, "null", handle->readable, handle->writable);
   BSE_MIDI_DEVICE (device)->handle = handle;
   MIDI_DEBUG ("NULL: opening MIDI readable=%d writable=%d: %s", require_readable, require_writable, bse_error_blurb (BSE_ERROR_NONE));
   return BSE_ERROR_NONE;
