@@ -18,7 +18,7 @@
 #include "bsemididevice-oss.h"
 #include "bseserver.h"
 #include "bsemididecoder.h"
-#include "gslcommon.h"
+#include "gslcommon.h" // FIXME: remove
 #include "bsesequencer.h"
 #include "topconfig.h"
 
@@ -39,7 +39,8 @@ BSE_DUMMY_TYPE (BseMidiDeviceOSS);
 #include <string.h>
 #include <fcntl.h>
 
-#define MIDI_DEBUG(...) sfi_debug ("midi", __VA_ARGS__)
+static SFI_MSG_TYPE_DEFINE (debug_midi, "midi", SFI_MSG_DEBUG, NULL);
+#define MIDI_DEBUG(...) sfi_debug (debug_midi, __VA_ARGS__)
 
 
 /* --- structs --- */
@@ -178,11 +179,7 @@ bse_midi_device_oss_open (BseDevice     *device,
   /* setup MIDI handle or shutdown */
   if (!error)
     {
-      BSE_OBJECT_SET_FLAGS (device, BSE_DEVICE_FLAG_OPEN);
-      if (handle->readable)
-	BSE_OBJECT_SET_FLAGS (device, BSE_DEVICE_FLAG_READABLE);
-      if (handle->writable)
-	BSE_OBJECT_SET_FLAGS (device, BSE_DEVICE_FLAG_WRITABLE);
+      bse_device_set_opened (device, dname, handle->readable, handle->writable);
       BSE_MIDI_DEVICE (device)->handle = handle;
       GPollFD pfd = { 0, };
       pfd.fd = oss->fd;
