@@ -22,6 +22,7 @@
 #include "bseengine.h"
 #include "bsemathsignal.h"
 #include "bsecxxutils.hh"
+#include "bsemidinotifier.h"
 #include <string.h>
 #include <sfi/gbsearcharray.h>
 #include <map>
@@ -31,8 +32,10 @@ namespace {
 using namespace Bse;
 using namespace std;
 
-#define	DEBUG(...)              sfi_debug ("midi-receiver", __VA_ARGS__)
-#define	DEBUG_EVENTS(...)       sfi_debug ("midi-events", __VA_ARGS__)
+static SFI_MSG_TYPE_DEFINE (debug_midi_receiver, "midi-receiver", SFI_MSG_DEBUG, NULL);
+#define DEBUG(...)              sfi_debug (debug_midi_receiver, __VA_ARGS__)
+static SFI_MSG_TYPE_DEFINE (debug_midi_events, "midi-events", SFI_MSG_DEBUG, NULL);
+#define DEBUG_EVENTS(...)       sfi_debug (debug_midi_events, __VA_ARGS__)
 
 /* --- variables --- */
 static SfiMutex                         global_midi_mutex = { 0, };
@@ -1366,20 +1369,6 @@ bse_midi_receiver_set_notifier (BseMidiReceiver *self,
   BSE_MIDI_RECEIVER_UNLOCK ();
 }
 
-BseMidiNotifier*
-bse_midi_receiver_get_notifier (BseMidiReceiver *self)
-{
-  BseMidiNotifier *notifier;
-  
-  g_return_val_if_fail (self != NULL, NULL);
-  
-  BSE_MIDI_RECEIVER_LOCK ();
-  notifier = self->notifier;
-  BSE_MIDI_RECEIVER_UNLOCK ();
-  
-  return notifier;
-}
-
 gboolean
 bse_midi_receiver_has_notify_events (BseMidiReceiver *self)
 {
@@ -2067,7 +2056,7 @@ midi_receiver_process_event_L (BseMidiReceiver *self,
 	}
       if (self->notifier)
 	{
-	  self->notifier_events = sfi_ring_prepend (self->notifier_events, event);
+	  self->notifier_events = sfi_ring_append (self->notifier_events, event);
 	  need_wakeup = TRUE;
 	}
       else
@@ -2077,11 +2066,9 @@ midi_receiver_process_event_L (BseMidiReceiver *self,
   else
     return FALSE;
   
-#if 0   /* FIXME: wake up midi notifer if necessary */
   if (need_wakeup)
-    sfi_thread_wakeup (sfi_thread_main ());
-#endif
-  
+    bse_midi_notifiers_wakeup();
+
   return TRUE;
 }
 
