@@ -1101,12 +1101,54 @@ select_controls_exclusive_exec (BseProcedureClass *proc,
   return BSE_ERROR_NONE;
 }
 
-/* --- select-notes --- */
+/* --- select-controls --- */
 static void
-select_notes_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+select_controls_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 847 "bsepart.proc"
  {
 #line 849 "bsepart.proc"
+  *(in_pspecs++) = bse_param_spec_object ("part", "Part", "Part",
+				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
+  *(in_pspecs++) = sfi_pspec_int ("tick", "Tick", "Selection Tick",
+			 0, 0, BSE_PART_MAX_TICK - 1, 384, SFI_PARAM_STANDARD);
+  *(in_pspecs++) = sfi_pspec_int ("duration", "Duration", "Selection Duration",
+			 0, 0, BSE_PART_MAX_TICK, 384, SFI_PARAM_STANDARD);
+  *(in_pspecs++)    = bse_param_spec_genum ("control_type", "Control Type", NULL,
+                                BSE_TYPE_MIDI_SIGNAL_TYPE, BSE_MIDI_SIGNAL_PITCH_BEND,
+                                SFI_PARAM_STANDARD);
+}
+#line 859 "bsepart.proc"
+ }
+static BseErrorType
+#line 859 "bsepart.proc"
+select_controls_exec (BseProcedureClass *proc,
+      const GValue      *in_values,
+      GValue            *out_values)
+#line 862 "bsepart.proc"
+{
+#line 863 "bsepart.proc"
+  
+  BsePart *self   = bse_value_get_object (in_values++);
+  guint tick      = sfi_value_get_int (in_values++);
+  guint duration  = sfi_value_get_int (in_values++);
+  guint ctype     = g_value_get_enum (in_values++);
+  
+#line 869 "bsepart.proc"
+  
+  if (!BSE_IS_PART (self))
+    return BSE_ERROR_PROC_PARAM_INVAL;
+  
+  bse_part_select_controls (self, tick, duration, ctype, TRUE);
+  
+  return BSE_ERROR_NONE;
+}
+
+/* --- select-notes --- */
+static void
+select_notes_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 878 "bsepart.proc"
+ {
+#line 880 "bsepart.proc"
   *(in_pspecs++) = bse_param_spec_object ("part", "Part", "Part",
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("tick", "Tick", "Selection Tick",
@@ -1118,16 +1160,16 @@ select_notes_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
   *(in_pspecs++) = bse_pspec_note_simple ("max_note", "Maximum Selection Note", NULL,
 				 SFI_PARAM_STANDARD);
 }
-#line 860 "bsepart.proc"
+#line 891 "bsepart.proc"
  }
 static BseErrorType
-#line 860 "bsepart.proc"
+#line 891 "bsepart.proc"
 select_notes_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 863 "bsepart.proc"
+#line 894 "bsepart.proc"
 {
-#line 864 "bsepart.proc"
+#line 895 "bsepart.proc"
   
   BsePart *self   = bse_value_get_object (in_values++);
   guint tick      = sfi_value_get_int (in_values++);
@@ -1135,7 +1177,7 @@ select_notes_exec (BseProcedureClass *proc,
   gint  min_note  = sfi_value_get_note (in_values++);
   gint  max_note  = sfi_value_get_note (in_values++);
   
-#line 871 "bsepart.proc"
+#line 902 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -1148,9 +1190,9 @@ select_notes_exec (BseProcedureClass *proc,
 /* --- deselect-notes --- */
 static void
 deselect_notes_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 880 "bsepart.proc"
+#line 911 "bsepart.proc"
  {
-#line 882 "bsepart.proc"
+#line 913 "bsepart.proc"
   *(in_pspecs++) = bse_param_spec_object ("part", "Part", "Part",
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("tick", "Tick", "Selection Tick",
@@ -1162,16 +1204,16 @@ deselect_notes_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
   *(in_pspecs++) = bse_pspec_note_simple ("max_note", "Maximum Selection Note", NULL,
 				 SFI_PARAM_STANDARD);
 }
-#line 893 "bsepart.proc"
+#line 924 "bsepart.proc"
  }
 static BseErrorType
-#line 893 "bsepart.proc"
+#line 924 "bsepart.proc"
 deselect_notes_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 896 "bsepart.proc"
+#line 927 "bsepart.proc"
 {
-#line 897 "bsepart.proc"
+#line 928 "bsepart.proc"
   
   BsePart *self   = bse_value_get_object (in_values++);
   guint tick      = sfi_value_get_int (in_values++);
@@ -1179,7 +1221,7 @@ deselect_notes_exec (BseProcedureClass *proc,
   gint  min_note  = sfi_value_get_note (in_values++);
   gint  max_note  = sfi_value_get_note (in_values++);
   
-#line 904 "bsepart.proc"
+#line 935 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -1192,9 +1234,9 @@ deselect_notes_exec (BseProcedureClass *proc,
 /* --- deselect-controls --- */
 static void
 deselect_controls_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 913 "bsepart.proc"
+#line 944 "bsepart.proc"
  {
-#line 915 "bsepart.proc"
+#line 946 "bsepart.proc"
   *(in_pspecs++) = bse_param_spec_object ("part", "Part", "Part",
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("tick", "Tick", "Selection Tick",
@@ -1205,23 +1247,23 @@ deselect_controls_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParam
                                 BSE_TYPE_MIDI_SIGNAL_TYPE, BSE_MIDI_SIGNAL_PITCH_BEND,
                                 SFI_PARAM_STANDARD);
 }
-#line 925 "bsepart.proc"
+#line 956 "bsepart.proc"
  }
 static BseErrorType
-#line 925 "bsepart.proc"
+#line 956 "bsepart.proc"
 deselect_controls_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 928 "bsepart.proc"
+#line 959 "bsepart.proc"
 {
-#line 929 "bsepart.proc"
+#line 960 "bsepart.proc"
   
   BsePart *self   = bse_value_get_object (in_values++);
   guint tick      = sfi_value_get_int (in_values++);
   guint duration  = sfi_value_get_int (in_values++);
   guint ctype     = g_value_get_enum (in_values++);
   
-#line 935 "bsepart.proc"
+#line 966 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -1234,49 +1276,6 @@ deselect_controls_exec (BseProcedureClass *proc,
 /* --- select-event --- */
 static void
 select_event_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 944 "bsepart.proc"
- {
-#line 946 "bsepart.proc"
-  *(in_pspecs++) = bse_param_spec_object ("part", "Part", NULL,
-				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
-  *(in_pspecs++) = sfi_pspec_int ("id", "ID", NULL,
-			 0, 0, BSE_PART_MAX_TICK, 1, SFI_PARAM_STANDARD);
-}
-#line 951 "bsepart.proc"
- }
-static BseErrorType
-#line 951 "bsepart.proc"
-select_event_exec (BseProcedureClass *proc,
-      const GValue      *in_values,
-      GValue            *out_values)
-#line 954 "bsepart.proc"
-{
-#line 955 "bsepart.proc"
-  
-  BsePart *self     = bse_value_get_object (in_values++);
-  guint    id	    = sfi_value_get_int (in_values++);
-  BsePartQueryEvent equery;
-  
-#line 960 "bsepart.proc"
-  
-  if (!BSE_IS_PART (self))
-    return BSE_ERROR_PROC_PARAM_INVAL;
-  
-#line 964 "bsepart.proc"
-  
-  bse_part_query_event (self, id, &equery);
-  if (equery.event_type == BSE_PART_EVENT_CONTROL)
-    bse_part_set_control_selected (self, id, TRUE);
-  else if (equery.event_type == BSE_PART_EVENT_NOTE)
-    bse_part_set_note_selected (self, id, equery.channel, TRUE);
-  else
-    return BSE_ERROR_PROC_PARAM_INVAL;
-  return BSE_ERROR_NONE;
-}
-
-/* --- deselect-event --- */
-static void
-deselect_event_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 975 "bsepart.proc"
  {
 #line 977 "bsepart.proc"
@@ -1289,7 +1288,7 @@ deselect_event_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
  }
 static BseErrorType
 #line 982 "bsepart.proc"
-deselect_event_exec (BseProcedureClass *proc,
+select_event_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
 #line 985 "bsepart.proc"
@@ -1307,6 +1306,49 @@ deselect_event_exec (BseProcedureClass *proc,
   
 #line 995 "bsepart.proc"
   
+  bse_part_query_event (self, id, &equery);
+  if (equery.event_type == BSE_PART_EVENT_CONTROL)
+    bse_part_set_control_selected (self, id, TRUE);
+  else if (equery.event_type == BSE_PART_EVENT_NOTE)
+    bse_part_set_note_selected (self, id, equery.channel, TRUE);
+  else
+    return BSE_ERROR_PROC_PARAM_INVAL;
+  return BSE_ERROR_NONE;
+}
+
+/* --- deselect-event --- */
+static void
+deselect_event_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 1006 "bsepart.proc"
+ {
+#line 1008 "bsepart.proc"
+  *(in_pspecs++) = bse_param_spec_object ("part", "Part", NULL,
+				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
+  *(in_pspecs++) = sfi_pspec_int ("id", "ID", NULL,
+			 0, 0, BSE_PART_MAX_TICK, 1, SFI_PARAM_STANDARD);
+}
+#line 1013 "bsepart.proc"
+ }
+static BseErrorType
+#line 1013 "bsepart.proc"
+deselect_event_exec (BseProcedureClass *proc,
+      const GValue      *in_values,
+      GValue            *out_values)
+#line 1016 "bsepart.proc"
+{
+#line 1017 "bsepart.proc"
+  
+  BsePart *self     = bse_value_get_object (in_values++);
+  guint    id	    = sfi_value_get_int (in_values++);
+  BsePartQueryEvent equery;
+  
+#line 1022 "bsepart.proc"
+  
+  if (!BSE_IS_PART (self))
+    return BSE_ERROR_PROC_PARAM_INVAL;
+  
+#line 1026 "bsepart.proc"
+  
   bse_part_query_event (self, id, &equery);
   if (equery.event_type == BSE_PART_EVENT_CONTROL)
     bse_part_set_control_selected (self, id, FALSE);
@@ -1320,34 +1362,34 @@ deselect_event_exec (BseProcedureClass *proc,
 /* --- get-timing --- */
 static void
 get_timing_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 1006 "bsepart.proc"
+#line 1037 "bsepart.proc"
  {
-#line 1008 "bsepart.proc"
+#line 1039 "bsepart.proc"
   *(in_pspecs++)    = bse_param_spec_object ("part", "Part", NULL, BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_int ("tick", "Tick", "Tick to retrieve timing info about", 0, 0, G_MAXINT, 384, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_boxed ("timing", "Timing", "Song Timing", BSE_TYPE_SONG_TIMING, SFI_PARAM_STANDARD);
-#line 1011 "bsepart.proc"
+#line 1042 "bsepart.proc"
 }  }
 static BseErrorType
-#line 1011 "bsepart.proc"
+#line 1042 "bsepart.proc"
 get_timing_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
-#line 1014 "bsepart.proc"
+#line 1045 "bsepart.proc"
 {
-#line 1015 "bsepart.proc"
+#line 1046 "bsepart.proc"
   
   BsePart *self = bse_value_get_object (in_values++);
   SfiInt   tick = sfi_value_get_int (in_values++);
   BseItem *parent;
   BseSongTiming timing = { 0, };
 
-#line 1021 "bsepart.proc"
+#line 1052 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
 
-#line 1025 "bsepart.proc"
+#line 1056 "bsepart.proc"
   
   parent = BSE_ITEM (self)->parent;
   if (BSE_IS_SONG (parent))
@@ -1355,13 +1397,48 @@ get_timing_exec (BseProcedureClass *proc,
   else
     bse_song_timing_get_default (&timing);
 
-#line 1032 "bsepart.proc"
+#line 1063 "bsepart.proc"
   
   bse_value_set_boxed (out_values++, &timing);
 
   return BSE_ERROR_NONE;
 }
 
+/* --- list-links --- */
+static void
+list_links_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 1069 "bsepart.proc"
+ {
+#line 1071 "bsepart.proc"
+  *(in_pspecs++)    = bse_param_spec_object ("part", "Part", NULL, BSE_TYPE_PART, SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = bse_param_spec_boxed ("link_list", "Link List", NULL,
+                                BSE_TYPE_PART_LINK_SEQ, SFI_PARAM_STANDARD);
+}
+#line 1075 "bsepart.proc"
+ }
+static BseErrorType
+#line 1075 "bsepart.proc"
+list_links_exec (BseProcedureClass *proc,
+      const GValue      *in_values,
+      GValue            *out_values)
+#line 1078 "bsepart.proc"
+{
+#line 1079 "bsepart.proc"
+  
+  BsePart *self = bse_value_get_object (in_values++);
+
+#line 1082 "bsepart.proc"
+  
+  if (!BSE_IS_PART (self))
+    return BSE_ERROR_PROC_PARAM_INVAL;
+
+#line 1086 "bsepart.proc"
+  
+  bse_value_take_boxed (out_values++, bse_part_list_links (self));
+
+  return BSE_ERROR_NONE;
+}
+
 /* --- Export to BSE --- */
 static void
 __enode_insert_note_auto__fill_strings (BseExportStrings *es)
@@ -1738,6 +1815,23 @@ static BseExportNodeProc __enode_select_controls_exclusive = {
   0, select_controls_exclusive_setup, select_controls_exclusive_exec, 
 };
 static void
+__enode_select_controls__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Select all control events within range.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
+static BseExportNodeProc __enode_select_controls = {
+  { (BseExportNode*) &__enode_select_controls_exclusive, BSE_EXPORT_NODE_PROC,
+    "BsePart+select-controls", 
+    NULL,
+    "/Methods/BsePart/General/Select Controls",
+    NULL,
+    __enode_select_controls__fill_strings,
+  },
+  0, select_controls_setup, select_controls_exec, 
+};
+static void
 __enode_select_notes__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Select all notes within rectangle.";
@@ -1745,7 +1839,7 @@ __enode_select_notes__fill_strings (BseExportStrings *es)
   es->license = "GNU General Public License";
 }
 static BseExportNodeProc __enode_select_notes = {
-  { (BseExportNode*) &__enode_select_controls_exclusive, BSE_EXPORT_NODE_PROC,
+  { (BseExportNode*) &__enode_select_controls, BSE_EXPORT_NODE_PROC,
     "BsePart+select-notes", 
     NULL,
     "/Methods/BsePart/General/Select Notes",
@@ -1839,10 +1933,27 @@ static BseExportNodeProc __enode_get_timing = {
   },
   0, get_timing_setup, get_timing_exec, 
 };
+static void
+__enode_list_links__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "List all places where parts are used (linked) from tracks, sorted by tick.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
+static BseExportNodeProc __enode_list_links = {
+  { (BseExportNode*) &__enode_get_timing, BSE_EXPORT_NODE_PROC,
+    "BsePart+list-links", 
+    NULL,
+    "/Methods/BsePart/General/List Links",
+    NULL,
+    __enode_list_links__fill_strings,
+  },
+  0, list_links_setup, list_links_exec, 
+};
 BseExportNode* bse__builtin_init_bsepart_gen_proc_c (void);
 BseExportNode* bse__builtin_init_bsepart_gen_proc_c (void)
 {
-  return (BseExportNode*) &__enode_get_timing;
+  return (BseExportNode*) &__enode_list_links;
 }
 
 /*
