@@ -20,8 +20,7 @@
 
 #include "bsecategories.h"
 #include "bseserver.h"
-#include "./icons/mic.c"
-#include "gslengine.h"
+#include "bseengine.h"
 
 
 
@@ -50,10 +49,10 @@ static void	 bse_pcm_input_get_property	(GObject                *object,
 static void	 bse_pcm_input_prepare		(BseSource		*source);
 static void	 bse_pcm_input_context_create	(BseSource		*source,
 						 guint			 instance_id,
-						 GslTrans		*trans);
+						 BseTrans		*trans);
 static void	 bse_pcm_input_context_connect	(BseSource		*source,
 						 guint			 instance_id,
-						 GslTrans		*trans);
+						 BseTrans		*trans);
 static void	 bse_pcm_input_reset		(BseSource		*source);
 
 
@@ -77,17 +76,13 @@ BSE_BUILTIN_TYPE (BsePcmInput)
     0 /* n_preallocs */,
     (GInstanceInitFunc) bse_pcm_input_init,
   };
-  static const BsePixdata mic_pixdata = {
-    MIC_BYTES_PER_PIXEL | BSE_PIXDATA_1BYTE_RLE,
-    MIC_WIDTH, MIC_HEIGHT,
-    MIC_RLE_PIXEL_DATA,
-  };
+#include "./icons/mic.c"
   GType type = bse_type_register_static (BSE_TYPE_SOURCE,
                                          "BsePcmInput",
                                          "Stereo PCM sound input module, per default, signals from this "
                                          "module originate from recording on the standard soundcard",
                                          &pcm_input_info);
-  bse_categories_register_icon ("/Modules/Input & Output/PCM Input", type, &mic_pixdata);
+  bse_categories_register_stock_module (N_("/Input & Output/PCM Input"), type, mic_pixstream);
   return type;
 }
 
@@ -112,22 +107,22 @@ bse_pcm_input_class_init (BsePcmInputClass *class)
   bse_object_class_add_param (object_class, "Adjustments",
 			      PARAM_MVOLUME_f,
 			      sfi_pspec_real ("gain_volume_f", "Input Gain [float]", NULL,
-					      bse_dB_to_factor (BSE_DFL_MASTER_VOLUME_dB),
-					      0, bse_dB_to_factor (BSE_MAX_VOLUME_dB),
+					      bse_db_to_factor (0),
+					      0, bse_db_to_factor (BSE_MAX_VOLUME_dB),
 					      0.1,
 					      SFI_PARAM_STORAGE ":skip-default")); // FIXME: don't skip-default
   bse_object_class_add_param (object_class, "Adjustments",
 			      PARAM_MVOLUME_dB,
 			      sfi_pspec_real ("gain_volume_dB", "Input Gain [dB]", NULL,
-					      BSE_DFL_MASTER_VOLUME_dB,
+					      0,
 					      BSE_MIN_VOLUME_dB, BSE_MAX_VOLUME_dB,
 					      BSE_GCONFIG (step_volume_dB),
 					      SFI_PARAM_GUI ":dial"));
   bse_object_class_add_param (object_class, "Adjustments",
 			      PARAM_MVOLUME_PERC,
 			      sfi_pspec_int ("gain_volume_perc", "input Gain [%]", NULL,
-					     bse_dB_to_factor (BSE_DFL_MASTER_VOLUME_dB) * 100,
-					     0, bse_dB_to_factor (BSE_MAX_VOLUME_dB) * 100,
+					     bse_db_to_factor (0) * 100,
+					     0, bse_db_to_factor (BSE_MAX_VOLUME_dB) * 100,
 					     1, SFI_PARAM_GUI ":dial"));
   
   ochannel_id = bse_source_class_add_ochannel (source_class, "left-audio-out", _("Left Audio Out"), _("Left channel output"));
@@ -144,7 +139,7 @@ bse_pcm_input_class_finalize (BsePcmInputClass *class)
 static void
 bse_pcm_input_init (BsePcmInput *iput)
 {
-  iput->volume_factor = bse_dB_to_factor (BSE_DFL_MASTER_VOLUME_dB);
+  iput->volume_factor = bse_db_to_factor (0);
 }
 
 static void
@@ -162,7 +157,7 @@ bse_pcm_input_set_property (GObject      *object,
       g_object_notify (self, "gain_volume_perc");
       break;
     case PARAM_MVOLUME_dB:
-      self->volume_factor = bse_dB_to_factor (sfi_value_get_real (value));
+      self->volume_factor = bse_db_to_factor (sfi_value_get_real (value));
       g_object_notify (self, "gain_volume_f");
       g_object_notify (self, "gain_volume_perc");
       break;
@@ -190,7 +185,7 @@ bse_pcm_input_get_property (GObject    *object,
       sfi_value_set_real (value, self->volume_factor);
       break;
     case PARAM_MVOLUME_dB:
-      sfi_value_set_real (value, bse_dB_from_factor (self->volume_factor, BSE_MIN_VOLUME_dB));
+      sfi_value_set_real (value, bse_db_from_factor (self->volume_factor, BSE_MIN_VOLUME_dB));
       break;
     case PARAM_MVOLUME_PERC:
       sfi_value_set_int (value, self->volume_factor * 100.0 + 0.5);
@@ -218,14 +213,14 @@ typedef struct {
 } ModData;
 
 static void
-pcm_input_process (GslModule *module,
+pcm_input_process (BseModule *module,
 		   guint      n_values)
 {
   ModData *mdata = module->user_data;
-  const gfloat *ls = GSL_MODULE_IBUFFER (module, BSE_PCM_INPUT_OCHANNEL_LEFT);
-  const gfloat *rs = GSL_MODULE_IBUFFER (module, BSE_PCM_INPUT_OCHANNEL_RIGHT);
-  gfloat *ld = GSL_MODULE_OBUFFER (module, BSE_PCM_INPUT_OCHANNEL_LEFT);
-  gfloat *rd = GSL_MODULE_OBUFFER (module, BSE_PCM_INPUT_OCHANNEL_RIGHT);
+  const gfloat *ls = BSE_MODULE_IBUFFER (module, BSE_PCM_INPUT_OCHANNEL_LEFT);
+  const gfloat *rs = BSE_MODULE_IBUFFER (module, BSE_PCM_INPUT_OCHANNEL_RIGHT);
+  gfloat *ld = BSE_MODULE_OBUFFER (module, BSE_PCM_INPUT_OCHANNEL_LEFT);
+  gfloat *rd = BSE_MODULE_OBUFFER (module, BSE_PCM_INPUT_OCHANNEL_RIGHT);
   gfloat v = mdata->volume;
   
   if (mdata->volume_set)
@@ -236,37 +231,37 @@ pcm_input_process (GslModule *module,
       }
   else
     {
-      GSL_MODULE_OBUFFER (module, BSE_PCM_INPUT_OCHANNEL_LEFT) = (gfloat*) GSL_MODULE_IBUFFER (module, BSE_PCM_INPUT_OCHANNEL_LEFT);
-      GSL_MODULE_OBUFFER (module, BSE_PCM_INPUT_OCHANNEL_RIGHT) = (gfloat*) GSL_MODULE_IBUFFER (module, BSE_PCM_INPUT_OCHANNEL_RIGHT);
+      BSE_MODULE_OBUFFER (module, BSE_PCM_INPUT_OCHANNEL_LEFT) = (gfloat*) BSE_MODULE_IBUFFER (module, BSE_PCM_INPUT_OCHANNEL_LEFT);
+      BSE_MODULE_OBUFFER (module, BSE_PCM_INPUT_OCHANNEL_RIGHT) = (gfloat*) BSE_MODULE_IBUFFER (module, BSE_PCM_INPUT_OCHANNEL_RIGHT);
     }
 }
 
 static void
 bse_pcm_input_context_create (BseSource *source,
 			      guint      context_handle,
-			      GslTrans  *trans)
+			      BseTrans  *trans)
 {
-  static const GslClass pcm_input_mclass = {
+  static const BseModuleClass pcm_input_mclass = {
     BSE_PCM_INPUT_N_OCHANNELS,	/* n_istreams */
     0,				/* n_jstreams */
     BSE_PCM_INPUT_N_OCHANNELS,	/* n_ostreams */
     pcm_input_process,		/* process */
     NULL,                       /* process_defer */
     NULL,                       /* reset */
-    (GslModuleFreeFunc) g_free,	/* free */
-    GSL_COST_CHEAP,		/* cost */
+    (BseModuleFreeFunc) g_free,	/* free */
+    BSE_COST_CHEAP,		/* cost */
   };
   ModData *mdata = g_new0 (ModData, 1);
-  GslModule *module = gsl_module_new (&pcm_input_mclass, mdata);
+  BseModule *module = bse_module_new (&pcm_input_mclass, mdata);
   
   mdata->volume = 1.0;
-  mdata->volume_set = BSE_EPSILON_CMP (mdata->volume, 1.0) != 0;
+  mdata->volume_set = mdata->volume != 1.0;
   
   /* setup module i/o streams with BseSource i/o channels */
   bse_source_set_context_omodule (source, context_handle, module);
   
   /* commit module to engine */
-  gsl_trans_add (trans, gsl_job_integrate (module));
+  bse_trans_add (trans, bse_job_integrate (module));
   
   /* chain parent class' handler */
   BSE_SOURCE_CLASS (parent_class)->context_create (source, context_handle, trans);
@@ -275,17 +270,17 @@ bse_pcm_input_context_create (BseSource *source,
 static void
 bse_pcm_input_context_connect (BseSource *source,
 			       guint      context_handle,
-			       GslTrans  *trans)
+			       BseTrans  *trans)
 {
   BsePcmInput *iput = BSE_PCM_INPUT (source);
-  GslModule *module;
+  BseModule *module;
   
   /* get context specific module */
   module = bse_source_get_context_omodule (source, context_handle);
   
   /* connect module to server uplink */
-  gsl_trans_add (trans, gsl_job_connect (iput->uplink, 0, module, 0));
-  gsl_trans_add (trans, gsl_job_connect (iput->uplink, 1, module, 1));
+  bse_trans_add (trans, bse_job_connect (iput->uplink, 0, module, 0));
+  bse_trans_add (trans, bse_job_connect (iput->uplink, 1, module, 1));
   
   /* chain parent class' handler */
   BSE_SOURCE_CLASS (parent_class)->context_connect (source, context_handle, trans);
