@@ -15,7 +15,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
-#include "bseprobe.gen-idl.h"
+#include "bseprobe.genidl.hh"
 #include "bseengine.h"
 #include "gslcommon.h" /* for gsl_tick_stamp() */
 #include "gslfft.h"
