@@ -1,5 +1,5 @@
 /* BSE - Bedevilled Sound Engine
- * Copyright (C) 1998-1999, 2000-2003 Tim Janik
+ * Copyright (C) 1998-1999, 2000-2005 Tim Janik
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #include "bsemain.h"
 #include "bsestandardsynths.h"
 #include "bsemidireceiver.h"
+#include "bsemidinotifier.h"
 #include "gslcommon.h"
 #include "bseengine.h"
 #include <string.h>
@@ -45,11 +46,9 @@ typedef struct {
   GSList  *items;
 } StorageTrap;
 
-
 /* --- macros --- */
 #define parse_or_return         bse_storage_scanner_parse_or_return
 #define peek_or_return          bse_storage_scanner_peek_or_return
-#define	DEBUG			sfi_debug
 
 enum {
   PARAM_0,
@@ -168,7 +167,10 @@ undo_notify (BseProject     *project,
 {
   g_object_notify (project, "dirty");
   if (step_added && !project->in_redo)
-    bse_undo_stack_clear (project->redo_stack);
+    {
+      bse_undo_stack_force_dirty (project->undo_stack);
+      bse_undo_stack_clear (project->redo_stack);
+    }
 }
 
 static void
@@ -233,7 +235,7 @@ bse_project_get_property (GObject                *object,
   switch (param_id)
     {
     case PARAM_DIRTY:
-      sfi_value_set_bool (value, bse_undo_stack_depth (self->undo_stack) > 0);
+      sfi_value_set_bool (value, bse_undo_stack_dirty (self->undo_stack));
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (self, param_id, pspec);
@@ -303,6 +305,15 @@ bse_project_clear_undo (BseProject *self)
     }
 }
 
+void
+bse_project_clean_dirty (BseProject *self)
+{
+  g_return_if_fail (BSE_IS_PROJECT (self));
+  bse_undo_stack_clean_dirty (self->undo_stack);
+  bse_undo_stack_clean_dirty (self->redo_stack);
+  g_object_notify (self, "dirty");
+}
+
 static void
 project_undo_do_deactivate (BseUndoStep  *ustep,
                             BseUndoStack *ustack)
@@ -424,7 +435,7 @@ bse_project_retrieve_child (BseContainer *container,
       for (slist = self->supers; slist; slist = slist->next)
 	if (g_type_is_a (G_OBJECT_TYPE (slist->data), BSE_TYPE_WAVE_REPO))
 	  return slist->data;
-      DEBUG ("%s: eeeeeek! wave-repo not found\n", G_STRLOC);
+      g_warning ("%s: no wave-repo found in project\n", G_STRLOC);
       return NULL;	/* shouldn't happen */
     }
   else
@@ -715,6 +726,20 @@ bse_project_create_intern_csynth (BseProject *self,
   return csynth;
 }
 
+BseMidiNotifier*
+bse_project_get_midi_notifier (BseProject *self)
+{
+  GSList *slist;
+  for (slist = self->items; slist; slist = slist->next)
+    if (BSE_IS_MIDI_NOTIFIER (slist->data))
+      return slist->data;
+
+  BseMidiNotifier *mnot = bse_container_new_child_bname (BSE_CONTAINER (self), BSE_TYPE_MIDI_NOTIFIER, "%bse-intern-midi-notifier", NULL);
+  bse_midi_notifier_set_receiver (mnot, self->midi_receiver);
+  bse_item_set_internal (BSE_ITEM (mnot), TRUE);
+  return mnot;
+}
+
 static void
 bse_project_prepare (BseSource *source)
 {
