@@ -8,7 +8,7 @@
 #include <bse/bseprocedure.h>
 #include <bse/bseserver.h>
 #include <bse/bseproject.h>
-#include <bse/gslloader.h>
+#include <bse/bseloader.h>
 #include <bse/bsemidinotifier.h>
 #include <bse/bsemidievent.h>
 #include <bse/bsejanitor.h>
@@ -80,61 +80,12 @@ use_new_project_exec (BseProcedureClass *proc,
   return BSE_ERROR_NONE;
 }
 
-/* --- get-midi-notifier --- */
-static void
-get_midi_notifier_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 81 "bseserver.proc"
- {
-#line 83 "bseserver.proc"
-  *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
-  *(out_pspecs++) = bse_param_spec_object ("midi_notifier", "Midi Notifier", NULL,
-				 BSE_TYPE_MIDI_NOTIFIER, SFI_PARAM_STANDARD);
-}
-#line 88 "bseserver.proc"
- }
-static BseErrorType
-#line 88 "bseserver.proc"
-get_midi_notifier_exec (BseProcedureClass *proc,
-      const GValue      *in_values,
-      GValue            *out_values)
-#line 91 "bseserver.proc"
-{
-#line 92 "bseserver.proc"
-  
-  BseServer *self = bse_value_get_object (in_values++);
-  BseMidiNotifier *notifier;
-  
-#line 96 "bseserver.proc"
-  
-  if (!BSE_IS_SERVER (self))
-    return BSE_ERROR_PROC_PARAM_INVAL;
-  
-  notifier = NULL;
-#if 0
-  midi_receiver = bse_server_get_midi_receiver (self, "default");
-  notifier = bse_midi_receiver_get_notifier (midi_receiver);
-  if (!notifier)
-    {
-      notifier = g_object_new (BSE_TYPE_MIDI_NOTIFIER, NULL);
-      bse_midi_receiver_set_notifier (midi_receiver, notifier);
-      g_object_unref (notifier);
-    }
-#endif
-  
-#line 112 "bseserver.proc"
-  
-  bse_value_set_object (out_values++, G_OBJECT (notifier));
-  
-  return BSE_ERROR_NONE;
-}
-
 /* --- can-load --- */
 static void
 can_load_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 118 "bseserver.proc"
+#line 81 "bseserver.proc"
  {
-#line 120 "bseserver.proc"
+#line 83 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_string ("file_name", "File Name", "The file to find a loader for",
@@ -142,32 +93,32 @@ can_load_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **ou
   *(out_pspecs++)   = sfi_pspec_bool ("can-load", NULL, NULL,
 			  FALSE, SFI_PARAM_STANDARD);
 }
-#line 127 "bseserver.proc"
+#line 90 "bseserver.proc"
  }
 static BseErrorType
-#line 127 "bseserver.proc"
+#line 90 "bseserver.proc"
 can_load_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 130 "bseserver.proc"
+#line 93 "bseserver.proc"
 {
-#line 131 "bseserver.proc"
+#line 94 "bseserver.proc"
   
   BseServer *server	= bse_value_get_object (in_values++);
   gchar *file_name	= sfi_value_get_string (in_values++);
-  GslWaveFileInfo *finfo;
+  BseWaveFileInfo *finfo;
   
-#line 136 "bseserver.proc"
+#line 99 "bseserver.proc"
   
   if (!BSE_IS_SERVER (server) || !file_name)
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 140 "bseserver.proc"
+#line 103 "bseserver.proc"
   
-  finfo = gsl_wave_file_info_load (file_name, NULL);
+  finfo = bse_wave_file_info_load (file_name, NULL);
   sfi_value_set_bool (out_values++, finfo != NULL);
   if (finfo)
-    gsl_wave_file_info_unref (finfo);
+    bse_wave_file_info_unref (finfo);
   
   return BSE_ERROR_NONE;
 }
@@ -175,9 +126,9 @@ can_load_exec (BseProcedureClass *proc,
 /* --- describe-note --- */
 static void
 describe_note_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 149 "bseserver.proc"
+#line 112 "bseserver.proc"
  {
-#line 151 "bseserver.proc"
+#line 114 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = bse_pspec_note_simple ("note", "Note", NULL, SFI_PARAM_STANDARD);
@@ -185,27 +136,27 @@ describe_note_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
   *(out_pspecs++)   = bse_param_spec_boxed ("note-description", "Note Description", NULL,
                                 BSE_TYPE_NOTE_DESCRIPTION, SFI_PARAM_STANDARD);
 }
-#line 158 "bseserver.proc"
+#line 121 "bseserver.proc"
  }
 static BseErrorType
-#line 158 "bseserver.proc"
+#line 121 "bseserver.proc"
 describe_note_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 161 "bseserver.proc"
+#line 124 "bseserver.proc"
 {
-#line 162 "bseserver.proc"
+#line 125 "bseserver.proc"
   
   BseServer *server	= bse_value_get_object (in_values++);
   gint       note	= sfi_value_get_int (in_values++);
   gint       fine_tune	= sfi_value_get_int (in_values++);
   
-#line 167 "bseserver.proc"
+#line 130 "bseserver.proc"
   
   if (!BSE_IS_SERVER (server))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 171 "bseserver.proc"
+#line 134 "bseserver.proc"
   
   bse_value_take_boxed (out_values++, bse_note_description (note, fine_tune));
   
@@ -215,9 +166,9 @@ describe_note_exec (BseProcedureClass *proc,
 /* --- note-from-freq --- */
 static void
 note_from_freq_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 177 "bseserver.proc"
+#line 140 "bseserver.proc"
  {
-#line 179 "bseserver.proc"
+#line 142 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_real ("freq", "Frequency", NULL,
@@ -227,27 +178,27 @@ note_from_freq_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
   *(out_pspecs++)   = bse_param_spec_boxed ("note-description", "Note Description", NULL,
                                 BSE_TYPE_NOTE_DESCRIPTION, SFI_PARAM_STANDARD);
 }
-#line 188 "bseserver.proc"
+#line 151 "bseserver.proc"
  }
 static BseErrorType
-#line 188 "bseserver.proc"
+#line 151 "bseserver.proc"
 note_from_freq_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 191 "bseserver.proc"
+#line 154 "bseserver.proc"
 {
-#line 192 "bseserver.proc"
+#line 155 "bseserver.proc"
   
   BseServer *server	= bse_value_get_object (in_values++);
   gfloat     freq	= sfi_value_get_real (in_values++);
   gint note;
   
-#line 197 "bseserver.proc"
+#line 160 "bseserver.proc"
   
   if (!BSE_IS_SERVER (server))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 201 "bseserver.proc"
+#line 164 "bseserver.proc"
   
   note = bse_note_from_freq (freq);
   bse_value_take_boxed (out_values++, bse_note_description (note, 0));
@@ -258,9 +209,9 @@ note_from_freq_exec (BseProcedureClass *proc,
 /* --- note-from-string --- */
 static void
 note_from_string_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 208 "bseserver.proc"
+#line 171 "bseserver.proc"
  {
-#line 210 "bseserver.proc"
+#line 173 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_string ("name", "Name", NULL,
@@ -268,27 +219,27 @@ note_from_string_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamS
   *(out_pspecs++)   = bse_param_spec_boxed ("note-description", "Note Description", NULL,
                                 BSE_TYPE_NOTE_DESCRIPTION, SFI_PARAM_STANDARD);
 }
-#line 217 "bseserver.proc"
+#line 180 "bseserver.proc"
  }
 static BseErrorType
-#line 217 "bseserver.proc"
+#line 180 "bseserver.proc"
 note_from_string_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 220 "bseserver.proc"
+#line 183 "bseserver.proc"
 {
-#line 221 "bseserver.proc"
+#line 184 "bseserver.proc"
   
   BseServer *server	= bse_value_get_object (in_values++);
   gchar     *name     	= sfi_value_get_string (in_values++);
   gint note;
   
-#line 226 "bseserver.proc"
+#line 189 "bseserver.proc"
   
   if (!BSE_IS_SERVER (server) || !name)
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 230 "bseserver.proc"
+#line 193 "bseserver.proc"
   
   note = bse_note_from_string (name);
   bse_value_take_boxed (out_values++, bse_note_description (note, 0));
@@ -299,9 +250,9 @@ note_from_string_exec (BseProcedureClass *proc,
 /* --- construct-note --- */
 static void
 construct_note_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 237 "bseserver.proc"
+#line 200 "bseserver.proc"
  {
-#line 239 "bseserver.proc"
+#line 202 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_int ("semitone", NULL, NULL,
@@ -312,16 +263,16 @@ construct_note_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
   *(out_pspecs++)   = bse_param_spec_boxed ("note-description", "Note Description", NULL,
                                 BSE_TYPE_NOTE_DESCRIPTION, SFI_PARAM_STANDARD);
 }
-#line 249 "bseserver.proc"
+#line 212 "bseserver.proc"
  }
 static BseErrorType
-#line 249 "bseserver.proc"
+#line 212 "bseserver.proc"
 construct_note_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 252 "bseserver.proc"
+#line 215 "bseserver.proc"
 {
-#line 253 "bseserver.proc"
+#line 216 "bseserver.proc"
   
   BseServer *server	= bse_value_get_object (in_values++);
   guint      semitone	= sfi_value_get_int (in_values++);
@@ -329,12 +280,12 @@ construct_note_exec (BseProcedureClass *proc,
   gint       fine_tune	= sfi_value_get_int (in_values++);
   gint note;
   
-#line 260 "bseserver.proc"
+#line 223 "bseserver.proc"
   
   if (!BSE_IS_SERVER (server))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 264 "bseserver.proc"
+#line 227 "bseserver.proc"
   
   note = BSE_NOTE_GENERIC (octave, semitone);
   bse_value_take_boxed (out_values++, bse_note_description (note, fine_tune));
@@ -345,42 +296,42 @@ construct_note_exec (BseProcedureClass *proc,
 /* --- n-scripts --- */
 static void
 n_scripts_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 271 "bseserver.proc"
+#line 234 "bseserver.proc"
  {
-#line 273 "bseserver.proc"
+#line 236 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_int ("n_connections", NULL, "Number of Connections",
 			 0, 0, G_MAXINT, 1,
 			 SFI_PARAM_STANDARD);
 }
-#line 279 "bseserver.proc"
+#line 242 "bseserver.proc"
  }
 static BseErrorType
-#line 279 "bseserver.proc"
+#line 242 "bseserver.proc"
 n_scripts_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 282 "bseserver.proc"
+#line 245 "bseserver.proc"
 {
-#line 283 "bseserver.proc"
+#line 246 "bseserver.proc"
   
   BseServer *server	= bse_value_get_object (in_values++);
   GSList *slist;
   guint n_scripts = 0;
   
-#line 288 "bseserver.proc"
+#line 251 "bseserver.proc"
   
   if (!BSE_IS_SERVER (server))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 292 "bseserver.proc"
+#line 255 "bseserver.proc"
   
   for (slist = server->children; slist; slist = slist->next)
     if (BSE_IS_JANITOR (slist->data))
       n_scripts++;
   
-#line 297 "bseserver.proc"
+#line 260 "bseserver.proc"
   
   sfi_value_set_int (out_values++, n_scripts);
   
@@ -390,33 +341,33 @@ n_scripts_exec (BseProcedureClass *proc,
 /* --- preferences-locked --- */
 static void
 preferences_locked_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 303 "bseserver.proc"
+#line 266 "bseserver.proc"
  {
-#line 305 "bseserver.proc"
+#line 268 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_bool ("locked", NULL, NULL,
 			  FALSE, SFI_PARAM_STANDARD);
 }
-#line 310 "bseserver.proc"
+#line 273 "bseserver.proc"
  }
 static BseErrorType
-#line 310 "bseserver.proc"
+#line 273 "bseserver.proc"
 preferences_locked_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 313 "bseserver.proc"
+#line 276 "bseserver.proc"
 {
-#line 314 "bseserver.proc"
+#line 277 "bseserver.proc"
   
   BseServer *server	= bse_value_get_object (in_values++);
   
-#line 317 "bseserver.proc"
+#line 280 "bseserver.proc"
   
   if (!BSE_IS_SERVER (server))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 321 "bseserver.proc"
+#line 284 "bseserver.proc"
   
   sfi_value_set_int (out_values++, bse_gconfig_locked ());
   
@@ -438,7 +389,7 @@ static void
 script_janitor_closed (BseJanitor *janitor,
 		       BseServer  *server)
 {
-  bse_server_registration (server, BSE_REGISTER_SCRIPT, bse_janitor_get_script (janitor), NULL);
+  bse_server_registration (server, BSE_REGISTER_SCRIPT, janitor->script_name, NULL);
   bse_idle_normal (register_scripts, server);
 }
 
@@ -461,7 +412,7 @@ register_scripts (gpointer data)
   if (!janitor)
     bse_server_registration (server, BSE_REGISTER_SCRIPT, scr->script, bse_error_blurb (error));
   else
-    g_object_connect (janitor, "signal::closed", script_janitor_closed, server, NULL);
+    g_object_connect (janitor, "signal::shutdown", script_janitor_closed, server, NULL);
   g_free (scr->script);
   g_free (scr);
   return !janitor;
@@ -470,29 +421,29 @@ register_scripts (gpointer data)
 /* --- register-scripts --- */
 static void
 register_scripts_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 371 "bseserver.proc"
+#line 334 "bseserver.proc"
  {
-#line 373 "bseserver.proc"
+#line 336 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
 }
-#line 376 "bseserver.proc"
+#line 339 "bseserver.proc"
  }
 static BseErrorType
-#line 376 "bseserver.proc"
+#line 339 "bseserver.proc"
 register_scripts_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 379 "bseserver.proc"
+#line 342 "bseserver.proc"
 {
   static gboolean registration_done = FALSE;
-#line 381 "bseserver.proc"
+#line 344 "bseserver.proc"
   
   BseServer *server	       = bse_value_get_object (in_values++);
   ScriptRegistration *scr_list = NULL;
   SfiRing *ring;
   
-#line 386 "bseserver.proc"
+#line 349 "bseserver.proc"
   
   if (!BSE_IS_SERVER (server))
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -546,28 +497,28 @@ register_core_plugins (gpointer data)
 /* --- register-core-plugins --- */
 static void
 register_core_plugins_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 436 "bseserver.proc"
+#line 399 "bseserver.proc"
  {
-#line 438 "bseserver.proc"
+#line 401 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
 }
-#line 441 "bseserver.proc"
+#line 404 "bseserver.proc"
  }
 static BseErrorType
-#line 441 "bseserver.proc"
+#line 404 "bseserver.proc"
 register_core_plugins_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 444 "bseserver.proc"
+#line 407 "bseserver.proc"
 {
   static gboolean registration_done = FALSE;
-#line 446 "bseserver.proc"
+#line 409 "bseserver.proc"
   
   BseServer *server	= bse_value_get_object (in_values++);
   SfiRing *ring;
   
-#line 450 "bseserver.proc"
+#line 413 "bseserver.proc"
   
   if (!BSE_IS_SERVER (server))
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -596,7 +547,7 @@ register_ladspa_plugins (gpointer data)
   
   if (g_object_get_data (server, "plugin-registration-queue"))
     {
-#line 478 "bseserver.proc"
+#line 441 "bseserver.proc"
       
       return TRUE;
     }
@@ -620,28 +571,28 @@ register_ladspa_plugins (gpointer data)
 /* --- register-ladspa-plugins --- */
 static void
 register_ladspa_plugins_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 498 "bseserver.proc"
+#line 461 "bseserver.proc"
  {
-#line 500 "bseserver.proc"
+#line 463 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
 }
-#line 503 "bseserver.proc"
+#line 466 "bseserver.proc"
  }
 static BseErrorType
-#line 503 "bseserver.proc"
+#line 466 "bseserver.proc"
 register_ladspa_plugins_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 506 "bseserver.proc"
+#line 469 "bseserver.proc"
 {
   static gboolean registration_done = FALSE;
-#line 508 "bseserver.proc"
+#line 471 "bseserver.proc"
   
   BseServer *server	= bse_value_get_object (in_values++);
   SfiRing *ring;
   
-#line 512 "bseserver.proc"
+#line 475 "bseserver.proc"
   
   if (!BSE_IS_SERVER (server))
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -669,22 +620,22 @@ register_ladspa_plugins_exec (BseProcedureClass *proc,
 /* --- save-preferences --- */
 static void
 save_preferences_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 536 "bseserver.proc"
+#line 499 "bseserver.proc"
  {
-#line 538 "bseserver.proc"
+#line 501 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
 }
-#line 541 "bseserver.proc"
+#line 504 "bseserver.proc"
  }
 static BseErrorType
-#line 541 "bseserver.proc"
+#line 504 "bseserver.proc"
 save_preferences_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 544 "bseserver.proc"
+#line 507 "bseserver.proc"
 {
-#line 545 "bseserver.proc"
+#line 508 "bseserver.proc"
   
   BseServer *server = bse_value_get_object (in_values++);
   SfiWStore *wstore;
@@ -693,14 +644,14 @@ save_preferences_exec (BseProcedureClass *proc,
   SfiRec *rec;
   gint fd;
   
-#line 553 "bseserver.proc"
+#line 516 "bseserver.proc"
   
   if (!BSE_IS_SERVER (server))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
   file_name = g_strconcat (g_get_home_dir (), "/.bserc", NULL);
   fd = open (file_name,
-#line 559 "bseserver.proc"
+#line 522 "bseserver.proc"
 	     O_WRONLY | O_CREAT | O_TRUNC, 
 	     0666);
   g_free (file_name);
@@ -710,7 +661,7 @@ save_preferences_exec (BseProcedureClass *proc,
   wstore = sfi_wstore_new ();
   sfi_wstore_printf (wstore, "; rc-file for BSE v%s\n", BSE_VERSION);
   
-#line 568 "bseserver.proc"
+#line 531 "bseserver.proc"
   
   sfi_wstore_puts (wstore, "\n; BseGConfig Dump\n");
   rec = bse_gconfig_to_rec (bse_global_config);
@@ -720,7 +671,7 @@ save_preferences_exec (BseProcedureClass *proc,
   sfi_rec_unref (rec);
   sfi_wstore_puts (wstore, "\n");
   
-#line 577 "bseserver.proc"
+#line 540 "bseserver.proc"
   
   sfi_wstore_flush_fd (wstore, fd);
   sfi_wstore_destroy (wstore);
@@ -732,21 +683,21 @@ save_preferences_exec (BseProcedureClass *proc,
 /* --- get-version --- */
 static void
 get_version_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 585 "bseserver.proc"
+#line 548 "bseserver.proc"
  {
-#line 587 "bseserver.proc"
+#line 550 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("version", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 591 "bseserver.proc"
+#line 554 "bseserver.proc"
  }
 static BseErrorType
-#line 591 "bseserver.proc"
+#line 554 "bseserver.proc"
 get_version_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 594 "bseserver.proc"
+#line 557 "bseserver.proc"
 {
   sfi_value_set_string (out_values++, BSE_VERSION);
   return BSE_ERROR_NONE;
@@ -755,21 +706,21 @@ get_version_exec (BseProcedureClass *proc,
 /* --- get-demo-path --- */
 static void
 get_demo_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 599 "bseserver.proc"
+#line 562 "bseserver.proc"
  {
-#line 601 "bseserver.proc"
+#line 564 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 605 "bseserver.proc"
+#line 568 "bseserver.proc"
  }
 static BseErrorType
-#line 605 "bseserver.proc"
+#line 568 "bseserver.proc"
 get_demo_path_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 608 "bseserver.proc"
+#line 571 "bseserver.proc"
 {
   sfi_value_set_string (out_values++, BSE_PATH_DEMOS);
   return BSE_ERROR_NONE;
@@ -778,21 +729,21 @@ get_demo_path_exec (BseProcedureClass *proc,
 /* --- get-sample-path --- */
 static void
 get_sample_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 613 "bseserver.proc"
+#line 576 "bseserver.proc"
  {
-#line 615 "bseserver.proc"
+#line 578 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 619 "bseserver.proc"
+#line 582 "bseserver.proc"
  }
 static BseErrorType
-#line 619 "bseserver.proc"
+#line 582 "bseserver.proc"
 get_sample_path_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 622 "bseserver.proc"
+#line 585 "bseserver.proc"
 {
   sfi_value_take_string (out_values++, g_path_concat (BSE_PATH_SAMPLES, BSE_GCONFIG (sample_path), NULL));
   return BSE_ERROR_NONE;
@@ -801,21 +752,21 @@ get_sample_path_exec (BseProcedureClass *proc,
 /* --- get-custom-effect-dir --- */
 static void
 get_custom_effect_dir_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 627 "bseserver.proc"
+#line 590 "bseserver.proc"
  {
-#line 629 "bseserver.proc"
+#line 592 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("directory", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 633 "bseserver.proc"
+#line 596 "bseserver.proc"
  }
 static BseErrorType
-#line 633 "bseserver.proc"
+#line 596 "bseserver.proc"
 get_custom_effect_dir_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 636 "bseserver.proc"
+#line 599 "bseserver.proc"
 {
   gchar **dirs = g_strsplit (BSE_GCONFIG (effect_path), G_SEARCHPATH_SEPARATOR_S, 2);
   sfi_value_set_string (out_values++, dirs[0]);
@@ -826,21 +777,21 @@ get_custom_effect_dir_exec (BseProcedureClass *proc,
 /* --- get-effect-path --- */
 static void
 get_effect_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 643 "bseserver.proc"
+#line 606 "bseserver.proc"
  {
-#line 645 "bseserver.proc"
+#line 608 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 649 "bseserver.proc"
+#line 612 "bseserver.proc"
  }
 static BseErrorType
-#line 649 "bseserver.proc"
+#line 612 "bseserver.proc"
 get_effect_path_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 652 "bseserver.proc"
+#line 615 "bseserver.proc"
 {
   sfi_value_take_string (out_values++, g_path_concat (BSE_PATH_EFFECTS, BSE_GCONFIG (effect_path), NULL));
   return BSE_ERROR_NONE;
@@ -849,21 +800,21 @@ get_effect_path_exec (BseProcedureClass *proc,
 /* --- get-custom-instrument-dir --- */
 static void
 get_custom_instrument_dir_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 657 "bseserver.proc"
+#line 620 "bseserver.proc"
  {
-#line 659 "bseserver.proc"
+#line 622 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("directory", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 663 "bseserver.proc"
+#line 626 "bseserver.proc"
  }
 static BseErrorType
-#line 663 "bseserver.proc"
+#line 626 "bseserver.proc"
 get_custom_instrument_dir_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 666 "bseserver.proc"
+#line 629 "bseserver.proc"
 {
   gchar **dirs = g_strsplit (BSE_GCONFIG (instrument_path), G_SEARCHPATH_SEPARATOR_S, 2);
   sfi_value_set_string (out_values++, dirs[0]);
@@ -874,21 +825,21 @@ get_custom_instrument_dir_exec (BseProcedureClass *proc,
 /* --- get-instrument-path --- */
 static void
 get_instrument_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 673 "bseserver.proc"
+#line 636 "bseserver.proc"
  {
-#line 675 "bseserver.proc"
+#line 638 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 679 "bseserver.proc"
+#line 642 "bseserver.proc"
  }
 static BseErrorType
-#line 679 "bseserver.proc"
+#line 642 "bseserver.proc"
 get_instrument_path_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 682 "bseserver.proc"
+#line 645 "bseserver.proc"
 {
   sfi_value_take_string (out_values++, g_path_concat (BSE_PATH_INSTRUMENTS, BSE_GCONFIG (instrument_path), NULL));
   return BSE_ERROR_NONE;
@@ -897,21 +848,21 @@ get_instrument_path_exec (BseProcedureClass *proc,
 /* --- get-script-path --- */
 static void
 get_script_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 687 "bseserver.proc"
+#line 650 "bseserver.proc"
  {
-#line 689 "bseserver.proc"
+#line 652 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 693 "bseserver.proc"
+#line 656 "bseserver.proc"
  }
 static BseErrorType
-#line 693 "bseserver.proc"
+#line 656 "bseserver.proc"
 get_script_path_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 696 "bseserver.proc"
+#line 659 "bseserver.proc"
 {
   sfi_value_take_string (out_values++, g_path_concat (BSE_PATH_SCRIPTS, BSE_GCONFIG (script_path), NULL));
   return BSE_ERROR_NONE;
@@ -920,21 +871,21 @@ get_script_path_exec (BseProcedureClass *proc,
 /* --- get-plugin-path --- */
 static void
 get_plugin_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 701 "bseserver.proc"
+#line 664 "bseserver.proc"
  {
-#line 703 "bseserver.proc"
+#line 666 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 707 "bseserver.proc"
+#line 670 "bseserver.proc"
  }
 static BseErrorType
-#line 707 "bseserver.proc"
+#line 670 "bseserver.proc"
 get_plugin_path_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 710 "bseserver.proc"
+#line 673 "bseserver.proc"
 {
   sfi_value_take_string (out_values++, g_path_concat (BSE_PATH_PLUGINS, BSE_GCONFIG (plugin_path), NULL));
   return BSE_ERROR_NONE;
@@ -943,21 +894,21 @@ get_plugin_path_exec (BseProcedureClass *proc,
 /* --- get-ladspa-path --- */
 static void
 get_ladspa_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 715 "bseserver.proc"
+#line 678 "bseserver.proc"
  {
-#line 717 "bseserver.proc"
+#line 680 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 721 "bseserver.proc"
+#line 684 "bseserver.proc"
  }
 static BseErrorType
-#line 721 "bseserver.proc"
+#line 684 "bseserver.proc"
 get_ladspa_path_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 724 "bseserver.proc"
+#line 687 "bseserver.proc"
 {
   sfi_value_take_string (out_values++, g_path_concat (BSE_PATH_LADSPA, BSE_GCONFIG (ladspa_path), NULL));
   return BSE_ERROR_NONE;
@@ -968,21 +919,21 @@ get_ladspa_path_exec (BseProcedureClass *proc,
 /* --- get-mp3-version --- */
 static void
 get_mp3_version_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 731 "bseserver.proc"
+#line 694 "bseserver.proc"
  {
-#line 733 "bseserver.proc"
+#line 696 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("version", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 737 "bseserver.proc"
+#line 700 "bseserver.proc"
  }
 static BseErrorType
-#line 737 "bseserver.proc"
+#line 700 "bseserver.proc"
 get_mp3_version_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 740 "bseserver.proc"
+#line 703 "bseserver.proc"
 {
   const gchar *c = gsl_data_handle_mad_version ();
   if (c)
@@ -1009,23 +960,6 @@ static BseExportNodeProc __enode_use_new_project = {
   0, use_new_project_setup, use_new_project_exec, 
 };
 static void
-__enode_get_midi_notifier__fill_strings (BseExportStrings *es)
-{
-  es->blurb = "Retrieve the global midi notifier object.";
-  es->authors = "Tim Janik <timj@gtk.org>";
-  es->license = "GNU General Public License";
-}
-static BseExportNodeProc __enode_get_midi_notifier = {
-  { (BseExportNode*) &__enode_use_new_project, BSE_EXPORT_NODE_PROC,
-    "BseServer+get-midi-notifier", 
-    NULL,
-    "/Methods/BseServer/General/Get Midi Notifier",
-    NULL,
-    __enode_get_midi_notifier__fill_strings,
-  },
-  0, get_midi_notifier_setup, get_midi_notifier_exec, 
-};
-static void
 __enode_can_load__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Check whether a loader can be found for a wave file";
@@ -1033,7 +967,7 @@ __enode_can_load__fill_strings (BseExportStrings *es)
   es->license = "GNU General Public License";
 }
 static BseExportNodeProc __enode_can_load = {
-  { (BseExportNode*) &__enode_get_midi_notifier, BSE_EXPORT_NODE_PROC,
+  { (BseExportNode*) &__enode_use_new_project, BSE_EXPORT_NODE_PROC,
     "BseServer+can-load", 
     NULL,
     "/Methods/BseServer/General/Can Load",
