@@ -642,7 +642,7 @@ synthesize_note_exec (BseProcedureClass *proc,
   
   if (BSE_SOURCE_PREPARED (self) && self->midi_receiver_SL)
     {
-      gfloat freq = BSE_KAMMER_FREQUENCY_f *
+      gfloat freq = BSE_KAMMER_FREQUENCY *
 		    BSE_SEMITONE_FACTOR (note) *
 		    BSE_FINE_TUNE_FACTOR (fine_tune);
       SfiTime tstamp = gsl_tick_stamp () + bse_engine_block_size () * 2;
