@@ -46,12 +46,11 @@ struct _BseSong
   guint		    numerator;
   guint		    denominator;
   gfloat            bpm;
-  gfloat            volume_factor;      /* 1-based factor */
   
   SfiRing          *parts;              /* of type BsePart* */
-  SfiRing          *busses;             /* of type BseSongBus* */
+  SfiRing          *busses;             /* of type BseBus* */
+  BseBus           *solo_bus;
 
-  BseSource	   *context_merger;
   BseSource	   *postprocess;
   BseSource	   *output;
 
@@ -67,10 +66,12 @@ struct _BseSong
   gdouble	    tpsi_SL;		/* ticks per stamp increment (sample) */
   SfiRing	   *tracks_SL;		/* of type BseTrack* */
   /* sequencer stuff */
-  SfiTime	    start_SL;		/* playback start */
+  guint64           sequencer_start_request_SL;
+  guint64           sequencer_start_SL; /* playback start */
+  guint64           sequencer_done_SL;
   gdouble	    delta_stamp_SL;	/* start + delta_stamp => tick */
   guint		    tick_SL;		/* tick at stamp_SL */
-  guint		    song_done_SL : 1;
+  guint             sequencer_owns_refcount_SL : 1;
   guint		    loop_enabled_SL : 1;
   SfiInt	    loop_left_SL;	/* left loop tick */
   SfiInt	    loop_right_SL;	/* left loop tick */
@@ -89,7 +90,11 @@ void		bse_song_get_timing		(BseSong	*self,
 						 guint		 tick,
 						 BseSongTiming	*timing);
 void		bse_song_timing_get_default	(BseSongTiming	*timing);
-
+BseSource*      bse_song_create_summation       (BseSong        *self);
+BseBus*         bse_song_find_master            (BseSong        *self);
+BseSource*      bse_song_ensure_master          (BseSong        *self);
+void            bse_song_set_solo_bus           (BseSong        *self,
+                                                 BseBus         *bus);
 
 G_END_DECLS
 
