@@ -326,29 +326,29 @@ clear_outputs_exec (BseProcedureClass *proc,
   return BSE_ERROR_NONE;
 }
 
-/* --- has-outputs --- */
+/* --- has-output --- */
 static void
-has_outputs_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+has_output_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 266 "bsesource.proc"
  {
 #line 268 "bsesource.proc"
-  *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
-  *(out_pspecs++)   = sfi_pspec_bool ("has_outputs", "Has Outputs", NULL,
-			  FALSE, SFI_PARAM_STANDARD);
+  *(in_pspecs++) = bse_param_spec_object ("module", NULL, NULL, BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
+  *(in_pspecs++)    = sfi_pspec_int ("ochannel", NULL, NULL, 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = sfi_pspec_bool ("has_outputs", NULL, NULL, FALSE, SFI_PARAM_STANDARD);
 }
-#line 273 "bsesource.proc"
+#line 272 "bsesource.proc"
  }
 static BseErrorType
-#line 273 "bsesource.proc"
-has_outputs_exec (BseProcedureClass *proc,
+#line 272 "bsesource.proc"
+has_output_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 276 "bsesource.proc"
+#line 275 "bsesource.proc"
 {
-#line 277 "bsesource.proc"
+#line 276 "bsesource.proc"
   
   BseSource *source = bse_value_get_object (in_values++);
+  guint ochannel    = sfi_value_get_int (in_values++);
   
 #line 280 "bsesource.proc"
   
@@ -357,27 +357,27 @@ has_outputs_exec (BseProcedureClass *proc,
   
 #line 284 "bsesource.proc"
   
-  sfi_value_set_bool (out_values++, source->outputs != NULL);
+  sfi_value_set_bool (out_values++, bse_source_has_output (source, ochannel));
   
   return BSE_ERROR_NONE;
 }
 
-/* --- n-ichannels --- */
+/* --- has-outputs --- */
 static void
-n_ichannels_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+has_outputs_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 290 "bsesource.proc"
  {
 #line 292 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
-  *(out_pspecs++)   = sfi_pspec_int ("n_channels", "Number of Channels", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = sfi_pspec_bool ("has_outputs", "Has Outputs", NULL,
+			  FALSE, SFI_PARAM_STANDARD);
 }
 #line 297 "bsesource.proc"
  }
 static BseErrorType
 #line 297 "bsesource.proc"
-n_ichannels_exec (BseProcedureClass *proc,
+has_outputs_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
 #line 300 "bsesource.proc"
@@ -393,6 +393,42 @@ n_ichannels_exec (BseProcedureClass *proc,
   
 #line 308 "bsesource.proc"
   
+  sfi_value_set_bool (out_values++, source->outputs != NULL);
+  
+  return BSE_ERROR_NONE;
+}
+
+/* --- n-ichannels --- */
+static void
+n_ichannels_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 314 "bsesource.proc"
+ {
+#line 316 "bsesource.proc"
+  *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = sfi_pspec_int ("n_channels", "Number of Channels", NULL,
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
+}
+#line 321 "bsesource.proc"
+ }
+static BseErrorType
+#line 321 "bsesource.proc"
+n_ichannels_exec (BseProcedureClass *proc,
+      const GValue      *in_values,
+      GValue            *out_values)
+#line 324 "bsesource.proc"
+{
+#line 325 "bsesource.proc"
+  
+  BseSource *source = bse_value_get_object (in_values++);
+  
+#line 328 "bsesource.proc"
+  
+  if (!BSE_IS_SOURCE (source))
+    return BSE_ERROR_PROC_PARAM_INVAL;
+  
+#line 332 "bsesource.proc"
+  
   sfi_value_set_int (out_values++, BSE_SOURCE_N_ICHANNELS (source));
   
   return BSE_ERROR_NONE;
@@ -401,9 +437,9 @@ n_ichannels_exec (BseProcedureClass *proc,
 /* --- ichannel-label --- */
 static void
 ichannel_label_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 314 "bsesource.proc"
+#line 338 "bsesource.proc"
  {
-#line 316 "bsesource.proc"
+#line 340 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
@@ -411,26 +447,26 @@ ichannel_label_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
   *(out_pspecs++)   = sfi_pspec_string ("channel_label", "Channel Name", NULL,
 			    NULL, SFI_PARAM_STANDARD);
 }
-#line 323 "bsesource.proc"
+#line 347 "bsesource.proc"
  }
 static BseErrorType
-#line 323 "bsesource.proc"
+#line 347 "bsesource.proc"
 ichannel_label_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 326 "bsesource.proc"
+#line 350 "bsesource.proc"
 {
-#line 327 "bsesource.proc"
+#line 351 "bsesource.proc"
   
   BseSource *source = bse_value_get_object (in_values++);
   guint ichannel    = sfi_value_get_int (in_values++);
   
-#line 331 "bsesource.proc"
+#line 355 "bsesource.proc"
   
   if (!BSE_IS_SOURCE (source) || ichannel >= BSE_SOURCE_N_ICHANNELS (source))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 335 "bsesource.proc"
+#line 359 "bsesource.proc"
   
   sfi_value_set_string (out_values++, BSE_SOURCE_ICHANNEL_LABEL (source, ichannel));
   
@@ -440,9 +476,9 @@ ichannel_label_exec (BseProcedureClass *proc,
 /* --- ichannel-ident --- */
 static void
 ichannel_ident_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 341 "bsesource.proc"
+#line 365 "bsesource.proc"
  {
-#line 343 "bsesource.proc"
+#line 367 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
@@ -450,26 +486,26 @@ ichannel_ident_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
   *(out_pspecs++)   = sfi_pspec_string ("channel_ident", "Channel Name", NULL,
 			    NULL, SFI_PARAM_STANDARD);
 }
-#line 350 "bsesource.proc"
+#line 374 "bsesource.proc"
  }
 static BseErrorType
-#line 350 "bsesource.proc"
+#line 374 "bsesource.proc"
 ichannel_ident_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 353 "bsesource.proc"
+#line 377 "bsesource.proc"
 {
-#line 354 "bsesource.proc"
+#line 378 "bsesource.proc"
   
   BseSource *source = bse_value_get_object (in_values++);
   guint ichannel    = sfi_value_get_int (in_values++);
   
-#line 358 "bsesource.proc"
+#line 382 "bsesource.proc"
   
   if (!BSE_IS_SOURCE (source) || ichannel >= BSE_SOURCE_N_ICHANNELS (source))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 362 "bsesource.proc"
+#line 386 "bsesource.proc"
   
   sfi_value_set_string (out_values++, BSE_SOURCE_ICHANNEL_IDENT (source, ichannel));
   
@@ -479,9 +515,9 @@ ichannel_ident_exec (BseProcedureClass *proc,
 /* --- ichannel-blurb --- */
 static void
 ichannel_blurb_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 368 "bsesource.proc"
+#line 392 "bsesource.proc"
  {
-#line 370 "bsesource.proc"
+#line 394 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
@@ -489,26 +525,26 @@ ichannel_blurb_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
   *(out_pspecs++)   = sfi_pspec_string ("channel_blurb", "Channel Blurb", NULL,
 			    NULL, SFI_PARAM_STANDARD);
 }
-#line 377 "bsesource.proc"
+#line 401 "bsesource.proc"
  }
 static BseErrorType
-#line 377 "bsesource.proc"
+#line 401 "bsesource.proc"
 ichannel_blurb_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 380 "bsesource.proc"
+#line 404 "bsesource.proc"
 {
-#line 381 "bsesource.proc"
+#line 405 "bsesource.proc"
   
   BseSource *source = bse_value_get_object (in_values++);
   guint ichannel    = sfi_value_get_int (in_values++);
   
-#line 385 "bsesource.proc"
+#line 409 "bsesource.proc"
   
   if (!BSE_IS_SOURCE (source) || ichannel >= BSE_SOURCE_N_ICHANNELS (source))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 389 "bsesource.proc"
+#line 413 "bsesource.proc"
   
   sfi_value_set_string (out_values++, BSE_SOURCE_ICHANNEL_BLURB (source, ichannel));
   
@@ -518,9 +554,9 @@ ichannel_blurb_exec (BseProcedureClass *proc,
 /* --- is-joint-ichannel-by-id --- */
 static void
 is_joint_ichannel_by_id_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 395 "bsesource.proc"
+#line 419 "bsesource.proc"
  {
-#line 397 "bsesource.proc"
+#line 421 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
@@ -528,26 +564,26 @@ is_joint_ichannel_by_id_setup (BseProcedureClass *proc, GParamSpec **in_pspecs,
   *(out_pspecs++)   = sfi_pspec_bool ("is_jchannel", "Is Joint Channel", NULL,
 			  FALSE, SFI_PARAM_STANDARD);
 }
-#line 404 "bsesource.proc"
+#line 428 "bsesource.proc"
  }
 static BseErrorType
-#line 404 "bsesource.proc"
+#line 428 "bsesource.proc"
 is_joint_ichannel_by_id_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 407 "bsesource.proc"
+#line 431 "bsesource.proc"
 {
-#line 408 "bsesource.proc"
+#line 432 "bsesource.proc"
   
   BseSource *source = bse_value_get_object (in_values++);
   guint ichannel    = sfi_value_get_int (in_values++);
   
-#line 412 "bsesource.proc"
+#line 436 "bsesource.proc"
   
   if (!BSE_IS_SOURCE (source) || ichannel >= BSE_SOURCE_N_ICHANNELS (source))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 416 "bsesource.proc"
+#line 440 "bsesource.proc"
   
   sfi_value_set_bool (out_values++, BSE_SOURCE_IS_JOINT_ICHANNEL (source, ichannel));
   
@@ -557,9 +593,9 @@ is_joint_ichannel_by_id_exec (BseProcedureClass *proc,
 /* --- is-joint-ichannel --- */
 static void
 is_joint_ichannel_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 422 "bsesource.proc"
+#line 446 "bsesource.proc"
  {
-#line 424 "bsesource.proc"
+#line 448 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_string ("input-channel", "Input Channel", NULL,
@@ -567,27 +603,27 @@ is_joint_ichannel_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParam
   *(out_pspecs++)   = sfi_pspec_bool ("is_jchannel", "Is Joint Channel", NULL,
 			  FALSE, SFI_PARAM_STANDARD);
 }
-#line 431 "bsesource.proc"
+#line 455 "bsesource.proc"
  }
 static BseErrorType
-#line 431 "bsesource.proc"
+#line 455 "bsesource.proc"
 is_joint_ichannel_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 434 "bsesource.proc"
+#line 458 "bsesource.proc"
 {
-#line 435 "bsesource.proc"
+#line 459 "bsesource.proc"
   
   BseSource *source = bse_value_get_object (in_values++);
   gchar *ichannel   = sfi_value_get_string (in_values++);
   guint id;
   
-#line 440 "bsesource.proc"
+#line 464 "bsesource.proc"
   
   if (!BSE_IS_SOURCE (source) || !ichannel)
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 444 "bsesource.proc"
+#line 468 "bsesource.proc"
   
   id = bse_source_find_ichannel (source, ichannel);
   sfi_value_set_bool (out_values++,
@@ -599,9 +635,9 @@ is_joint_ichannel_exec (BseProcedureClass *proc,
 /* --- ichannel-get-n-joints --- */
 static void
 ichannel_get_n_joints_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 452 "bsesource.proc"
+#line 476 "bsesource.proc"
  {
-#line 454 "bsesource.proc"
+#line 478 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
@@ -609,27 +645,27 @@ ichannel_get_n_joints_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GP
   *(out_pspecs++)   = sfi_pspec_int ("n_joints", "Number of Connections", NULL,
 			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
 }
-#line 461 "bsesource.proc"
+#line 485 "bsesource.proc"
  }
 static BseErrorType
-#line 461 "bsesource.proc"
+#line 485 "bsesource.proc"
 ichannel_get_n_joints_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 464 "bsesource.proc"
+#line 488 "bsesource.proc"
 {
-#line 465 "bsesource.proc"
+#line 489 "bsesource.proc"
   
   BseSource *source = bse_value_get_object (in_values++);
   guint ichannel    = sfi_value_get_int (in_values++);
   BseSourceInput *input;
   
-#line 470 "bsesource.proc"
+#line 494 "bsesource.proc"
   
   if (!BSE_IS_SOURCE (source) || ichannel >= BSE_SOURCE_N_ICHANNELS (source))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 474 "bsesource.proc"
+#line 498 "bsesource.proc"
   
   input = BSE_SOURCE_INPUT (source, ichannel);
   if (BSE_SOURCE_IS_JOINT_ICHANNEL (source, ichannel))
@@ -643,9 +679,9 @@ ichannel_get_n_joints_exec (BseProcedureClass *proc,
 /* --- ichannel-get-osource --- */
 static void
 ichannel_get_osource_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 484 "bsesource.proc"
+#line 508 "bsesource.proc"
  {
-#line 486 "bsesource.proc"
+#line 510 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
@@ -655,28 +691,28 @@ ichannel_get_osource_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GPa
   *(out_pspecs++)   = bse_param_spec_object ("osource", "Output Source", NULL,
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
 }
-#line 495 "bsesource.proc"
+#line 519 "bsesource.proc"
  }
 static BseErrorType
-#line 495 "bsesource.proc"
+#line 519 "bsesource.proc"
 ichannel_get_osource_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 498 "bsesource.proc"
+#line 522 "bsesource.proc"
 {
-#line 499 "bsesource.proc"
+#line 523 "bsesource.proc"
   
   BseSource *source = bse_value_get_object (in_values++);
   guint ichannel    = sfi_value_get_int (in_values++);
   guint joint       = sfi_value_get_int (in_values++);
   BseSourceInput *input;
   
-#line 505 "bsesource.proc"
+#line 529 "bsesource.proc"
   
   if (!BSE_IS_SOURCE (source) || ichannel >= BSE_SOURCE_N_ICHANNELS (source))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 509 "bsesource.proc"
+#line 533 "bsesource.proc"
   
   input = BSE_SOURCE_INPUT (source, ichannel);
   if (BSE_SOURCE_IS_JOINT_ICHANNEL (source, ichannel) && joint < input->jdata.n_joints)
@@ -692,9 +728,9 @@ ichannel_get_osource_exec (BseProcedureClass *proc,
 /* --- ichannel-get-ochannel --- */
 static void
 ichannel_get_ochannel_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 521 "bsesource.proc"
+#line 545 "bsesource.proc"
  {
-#line 523 "bsesource.proc"
+#line 547 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
@@ -704,28 +740,28 @@ ichannel_get_ochannel_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GP
   *(out_pspecs++)   = sfi_pspec_int ("ochannel", "Output Channel", NULL,
 			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
 }
-#line 532 "bsesource.proc"
+#line 556 "bsesource.proc"
  }
 static BseErrorType
-#line 532 "bsesource.proc"
+#line 556 "bsesource.proc"
 ichannel_get_ochannel_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 535 "bsesource.proc"
+#line 559 "bsesource.proc"
 {
-#line 536 "bsesource.proc"
+#line 560 "bsesource.proc"
   
   BseSource *source = bse_value_get_object (in_values++);
   guint ichannel    = sfi_value_get_int (in_values++);
   guint joint       = sfi_value_get_int (in_values++);
   BseSourceInput *input;
   
-#line 542 "bsesource.proc"
+#line 566 "bsesource.proc"
   
   if (!BSE_IS_SOURCE (source) || ichannel >= BSE_SOURCE_N_ICHANNELS (source))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 546 "bsesource.proc"
+#line 570 "bsesource.proc"
   
   input = BSE_SOURCE_INPUT (source, ichannel);
   if (BSE_SOURCE_IS_JOINT_ICHANNEL (source, ichannel) && joint < input->jdata.n_joints)
@@ -741,33 +777,33 @@ ichannel_get_ochannel_exec (BseProcedureClass *proc,
 /* --- n-ochannels --- */
 static void
 n_ochannels_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 558 "bsesource.proc"
+#line 582 "bsesource.proc"
  {
-#line 560 "bsesource.proc"
+#line 584 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_int ("n_channels", "Number of Channels", NULL,
 			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
 }
-#line 565 "bsesource.proc"
+#line 589 "bsesource.proc"
  }
 static BseErrorType
-#line 565 "bsesource.proc"
+#line 589 "bsesource.proc"
 n_ochannels_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 568 "bsesource.proc"
+#line 592 "bsesource.proc"
 {
-#line 569 "bsesource.proc"
+#line 593 "bsesource.proc"
   
   BseSource *source = bse_value_get_object (in_values++);
   
-#line 572 "bsesource.proc"
+#line 596 "bsesource.proc"
   
   if (!BSE_IS_SOURCE (source))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 576 "bsesource.proc"
+#line 600 "bsesource.proc"
   
   sfi_value_set_int (out_values++, BSE_SOURCE_N_OCHANNELS (source));
   
@@ -777,36 +813,36 @@ n_ochannels_exec (BseProcedureClass *proc,
 /* --- ochannel-label --- */
 static void
 ochannel_label_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 582 "bsesource.proc"
+#line 606 "bsesource.proc"
  {
-#line 584 "bsesource.proc"
+#line 608 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
-  *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
+  *(in_pspecs++) = sfi_pspec_int ("output-channel", "Input Channel", NULL,
 			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_string ("channel_label", "Channel Name", NULL,
 			    NULL, SFI_PARAM_STANDARD);
 }
-#line 591 "bsesource.proc"
+#line 615 "bsesource.proc"
  }
 static BseErrorType
-#line 591 "bsesource.proc"
+#line 615 "bsesource.proc"
 ochannel_label_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 594 "bsesource.proc"
+#line 618 "bsesource.proc"
 {
-#line 595 "bsesource.proc"
+#line 619 "bsesource.proc"
   
   BseSource *source = bse_value_get_object (in_values++);
   guint ochannel    = sfi_value_get_int (in_values++);
   
-#line 599 "bsesource.proc"
+#line 623 "bsesource.proc"
   
   if (!BSE_IS_SOURCE (source) || ochannel >= BSE_SOURCE_N_OCHANNELS (source))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 603 "bsesource.proc"
+#line 627 "bsesource.proc"
   
   sfi_value_set_string (out_values++, BSE_SOURCE_OCHANNEL_LABEL (source, ochannel));
   
@@ -816,36 +852,36 @@ ochannel_label_exec (BseProcedureClass *proc,
 /* --- ochannel-ident --- */
 static void
 ochannel_ident_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 609 "bsesource.proc"
+#line 633 "bsesource.proc"
  {
-#line 611 "bsesource.proc"
+#line 635 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
-  *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
+  *(in_pspecs++) = sfi_pspec_int ("output-channel", "Input Channel", NULL,
 			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_string ("channel_ident", "Channel Name", NULL,
 			    NULL, SFI_PARAM_STANDARD);
 }
-#line 618 "bsesource.proc"
+#line 642 "bsesource.proc"
  }
 static BseErrorType
-#line 618 "bsesource.proc"
+#line 642 "bsesource.proc"
 ochannel_ident_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 621 "bsesource.proc"
+#line 645 "bsesource.proc"
 {
-#line 622 "bsesource.proc"
+#line 646 "bsesource.proc"
   
   BseSource *source = bse_value_get_object (in_values++);
   guint ochannel    = sfi_value_get_int (in_values++);
   
-#line 626 "bsesource.proc"
+#line 650 "bsesource.proc"
   
   if (!BSE_IS_SOURCE (source) || ochannel >= BSE_SOURCE_N_OCHANNELS (source))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 630 "bsesource.proc"
+#line 654 "bsesource.proc"
   
   sfi_value_set_string (out_values++, BSE_SOURCE_OCHANNEL_IDENT (source, ochannel));
   
@@ -855,36 +891,36 @@ ochannel_ident_exec (BseProcedureClass *proc,
 /* --- ochannel-blurb --- */
 static void
 ochannel_blurb_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 636 "bsesource.proc"
+#line 660 "bsesource.proc"
  {
-#line 638 "bsesource.proc"
+#line 662 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
-  *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
+  *(in_pspecs++) = sfi_pspec_int ("output-channel", "Input Channel", NULL,
 			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_string ("channel_blurb", "Channel Blurb", NULL,
 			    NULL, SFI_PARAM_STANDARD);
 }
-#line 645 "bsesource.proc"
+#line 669 "bsesource.proc"
  }
 static BseErrorType
-#line 645 "bsesource.proc"
+#line 669 "bsesource.proc"
 ochannel_blurb_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 648 "bsesource.proc"
+#line 672 "bsesource.proc"
 {
-#line 649 "bsesource.proc"
+#line 673 "bsesource.proc"
   
   BseSource *source = bse_value_get_object (in_values++);
   guint ochannel    = sfi_value_get_int (in_values++);
   
-#line 653 "bsesource.proc"
+#line 677 "bsesource.proc"
   
   if (!BSE_IS_SOURCE (source) || ochannel >= BSE_SOURCE_N_OCHANNELS (source))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 657 "bsesource.proc"
+#line 681 "bsesource.proc"
   
   sfi_value_set_string (out_values++, BSE_SOURCE_OCHANNEL_BLURB (source, ochannel));
   
@@ -894,9 +930,9 @@ ochannel_blurb_exec (BseProcedureClass *proc,
 /* --- set-pos --- */
 static void
 set_pos_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 663 "bsesource.proc"
+#line 687 "bsesource.proc"
  {
-#line 670 "bsesource.proc"
+#line 694 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_real ("x-pos", "X Position", NULL,
@@ -904,28 +940,28 @@ set_pos_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out
   *(in_pspecs++) = sfi_pspec_real ("y-pos", "Y Position", NULL,
                           0, -SFI_MAXREAL, SFI_MAXREAL, 1, SFI_PARAM_STANDARD);
 }
-#line 677 "bsesource.proc"
+#line 701 "bsesource.proc"
  }
 static BseErrorType
-#line 677 "bsesource.proc"
+#line 701 "bsesource.proc"
 set_pos_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 680 "bsesource.proc"
+#line 704 "bsesource.proc"
 {
-#line 681 "bsesource.proc"
+#line 705 "bsesource.proc"
   
   BseSource *source = bse_value_get_object (in_values++);
   SfiReal xpos      = sfi_value_get_real (in_values++);
   SfiReal ypos      = sfi_value_get_real (in_values++);
   SfiReal epsilon = 1e-5;
 
-#line 687 "bsesource.proc"
+#line 711 "bsesource.proc"
   
   if (!BSE_IS_SOURCE (source) || BSE_DOUBLE_IS_NANINF (xpos) || BSE_DOUBLE_IS_NANINF (ypos))
     return BSE_ERROR_PROC_PARAM_INVAL;
 
-#line 691 "bsesource.proc"
+#line 715 "bsesource.proc"
   
   if (fabs (xpos - source->pos_x) > epsilon ||
       fabs (ypos - source->pos_y) > epsilon)
@@ -944,9 +980,9 @@ set_pos_exec (BseProcedureClass *proc,
 /* --- set-automation --- */
 static void
 set_automation_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 706 "bsesource.proc"
+#line 730 "bsesource.proc"
  {
-#line 708 "bsesource.proc"
+#line 732 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("source", NULL, NULL,
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_string ("property_name", NULL, "Item property name",
@@ -957,16 +993,16 @@ set_automation_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
                                 BSE_TYPE_MIDI_CONTROL_TYPE, BSE_MIDI_CONTROL_CONTINUOUS_16, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_genum ("error", "Error", NULL, BSE_TYPE_ERROR_TYPE, BSE_ERROR_NONE, SFI_PARAM_STANDARD);
 }
-#line 718 "bsesource.proc"
+#line 742 "bsesource.proc"
  }
 static BseErrorType
-#line 718 "bsesource.proc"
+#line 742 "bsesource.proc"
 set_automation_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 721 "bsesource.proc"
+#line 745 "bsesource.proc"
 {
-#line 722 "bsesource.proc"
+#line 746 "bsesource.proc"
   
   BseSource *source       = bse_value_get_object (in_values++);
   gchar     *property     = sfi_value_get_string (in_values++);
@@ -974,12 +1010,12 @@ set_automation_exec (BseProcedureClass *proc,
   guint      control_type = g_value_get_enum (in_values++);
   BseErrorType error = BSE_ERROR_NONE;
 
-#line 729 "bsesource.proc"
+#line 753 "bsesource.proc"
   
   if (!BSE_IS_SOURCE (source) || !property)
     return BSE_ERROR_PROC_PARAM_INVAL;
 
-#line 733 "bsesource.proc"
+#line 757 "bsesource.proc"
   
   guint old_midi_channel = 0;
   guint old_control_type = 0;
@@ -991,7 +1027,7 @@ set_automation_exec (BseProcedureClass *proc,
         bse_item_push_undo_proc (source, "set-automation", property, old_midi_channel, old_control_type);
     }
 
-#line 744 "bsesource.proc"
+#line 768 "bsesource.proc"
   
   g_value_set_enum (out_values++, error);
   
@@ -1001,39 +1037,39 @@ set_automation_exec (BseProcedureClass *proc,
 /* --- get-automation-channel --- */
 static void
 get_automation_channel_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 750 "bsesource.proc"
+#line 774 "bsesource.proc"
  {
-#line 752 "bsesource.proc"
+#line 776 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("source", NULL, NULL,
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_string ("property_name", NULL, "Item property name",
                             NULL, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_int ("midi_channel", NULL, NULL, 0, 0, BSE_MIDI_MAX_CHANNELS, 1, SFI_PARAM_STANDARD ":scale:unprepared");
 }
-#line 758 "bsesource.proc"
+#line 782 "bsesource.proc"
  }
 static BseErrorType
-#line 758 "bsesource.proc"
+#line 782 "bsesource.proc"
 get_automation_channel_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 761 "bsesource.proc"
+#line 785 "bsesource.proc"
 {
-#line 762 "bsesource.proc"
+#line 786 "bsesource.proc"
   
   BseSource *source       = bse_value_get_object (in_values++);
   gchar     *property     = sfi_value_get_string (in_values++);
 
-#line 766 "bsesource.proc"
+#line 790 "bsesource.proc"
   
   if (!BSE_IS_SOURCE (source) || !property)
     return BSE_ERROR_PROC_PARAM_INVAL;
 
-#line 770 "bsesource.proc"
+#line 794 "bsesource.proc"
   
   guint midi_channel = 0;
   bse_source_get_automation_property (source, property, &midi_channel, NULL);
-#line 773 "bsesource.proc"
+#line 797 "bsesource.proc"
   
   g_value_set_int (out_values++, midi_channel);
   
@@ -1043,39 +1079,39 @@ get_automation_channel_exec (BseProcedureClass *proc,
 /* --- get-automation-control --- */
 static void
 get_automation_control_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 779 "bsesource.proc"
+#line 803 "bsesource.proc"
  {
-#line 781 "bsesource.proc"
+#line 805 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("source", NULL, NULL,
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_string ("property_name", NULL, "Item property name",
                             NULL, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_genum ("control_type", NULL, NULL, BSE_TYPE_MIDI_CONTROL_TYPE, BSE_MIDI_CONTROL_CONTINUOUS_16, SFI_PARAM_STANDARD);
 }
-#line 787 "bsesource.proc"
+#line 811 "bsesource.proc"
  }
 static BseErrorType
-#line 787 "bsesource.proc"
+#line 811 "bsesource.proc"
 get_automation_control_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 790 "bsesource.proc"
+#line 814 "bsesource.proc"
 {
-#line 791 "bsesource.proc"
+#line 815 "bsesource.proc"
   
   BseSource *source       = bse_value_get_object (in_values++);
   gchar     *property     = sfi_value_get_string (in_values++);
 
-#line 795 "bsesource.proc"
+#line 819 "bsesource.proc"
   
   if (!BSE_IS_SOURCE (source) || !property)
     return BSE_ERROR_PROC_PARAM_INVAL;
 
-#line 799 "bsesource.proc"
+#line 823 "bsesource.proc"
   
   guint control_type = 0;
   bse_source_get_automation_property (source, property, NULL, &control_type);
-#line 802 "bsesource.proc"
+#line 826 "bsesource.proc"
   
   g_value_set_enum (out_values++, control_type);
   
@@ -1085,31 +1121,31 @@ get_automation_control_exec (BseProcedureClass *proc,
 /* --- is-prepared --- */
 static void
 is_prepared_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 808 "bsesource.proc"
+#line 832 "bsesource.proc"
  {
-#line 810 "bsesource.proc"
+#line 834 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("source", NULL, NULL,
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_bool ("is_prepared", NULL, NULL, FALSE, SFI_PARAM_STANDARD);
-#line 813 "bsesource.proc"
+#line 837 "bsesource.proc"
 }  }
 static BseErrorType
-#line 813 "bsesource.proc"
+#line 837 "bsesource.proc"
 is_prepared_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 816 "bsesource.proc"
+#line 840 "bsesource.proc"
 {
-#line 817 "bsesource.proc"
+#line 841 "bsesource.proc"
   
   BseSource *source       = bse_value_get_object (in_values++);
 
-#line 820 "bsesource.proc"
+#line 844 "bsesource.proc"
   
   if (!BSE_IS_SOURCE (source))
     return BSE_ERROR_PROC_PARAM_INVAL;
 
-#line 824 "bsesource.proc"
+#line 848 "bsesource.proc"
   
   sfi_value_set_bool (out_values++, BSE_SOURCE_PREPARED (source));
 
@@ -1220,6 +1256,23 @@ static BseExportNodeProc __enode_clear_outputs = {
   0, clear_outputs_setup, clear_outputs_exec, 
 };
 static void
+__enode_has_output__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Check whether a module's output channel is connected.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
+static BseExportNodeProc __enode_has_output = {
+  { (BseExportNode*) &__enode_clear_outputs, BSE_EXPORT_NODE_PROC,
+    "BseSource+has-output", 
+    NULL,
+    "/Methods/BseSource/General/Has Output",
+    NULL,
+    __enode_has_output__fill_strings,
+  },
+  0, has_output_setup, has_output_exec, 
+};
+static void
 __enode_has_outputs__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Check whether a module has output channel connections.";
@@ -1227,7 +1280,7 @@ __enode_has_outputs__fill_strings (BseExportStrings *es)
   es->license = "GNU Lesser General Public License";
 }
 static BseExportNodeProc __enode_has_outputs = {
-  { (BseExportNode*) &__enode_clear_outputs, BSE_EXPORT_NODE_PROC,
+  { (BseExportNode*) &__enode_has_output, BSE_EXPORT_NODE_PROC,
     "BseSource+has-outputs", 
     NULL,
     "/Methods/BseSource/General/Has Outputs",
