@@ -64,27 +64,27 @@ typedef void (*BseStorageRestoreLink)   (gpointer        data,
                                          const gchar    *error);
 struct _BseStorage
 {
-  BseObject           parent_instance;
+  BseObject              parent_instance;
   /* writing */
-  SfiWStore          *wstore;
-  SfiUPool           *stored_items2;
-  SfiPPool           *stored_items;
-  SfiPPool           *referenced_items;
+  SfiWStore             *wstore;
+  SfiPPool              *stored_items;
+  SfiPPool              *referenced_items;
   /* parsing */
-  SfiRStore          *rstore;
-  guint               major_version;
-  guint               minor_version;
-  guint               micro_version;
-  GHashTable         *path_table;
-  SfiRing            *item_links;
+  SfiRStore             *rstore;
+  guint                  major_version;
+  guint                  minor_version;
+  guint                  micro_version;
+  GHashTable            *path_table;
+  SfiRing               *item_links;
+  SfiPPool              *restorable_objects;
   /* internal data */
-  guint               n_dblocks;
-  BseStorageDBlock   *dblocks;
-  gchar              *free_me;
-  /* compat */ // VERSION-FIXME: remove after 0.5.2
-  gfloat          mix_freq;
-  gfloat          osc_freq;
-  guint           n_channels;
+  guint                  n_dblocks;
+  BseStorageDBlock      *dblocks;
+  gchar                 *free_me;
+  /* compat */ // VERSION-FIXME: needed only for <= 0.5.1
+  gfloat                 mix_freq;
+  gfloat                 osc_freq;
+  guint                  n_channels;
 };
 struct _BseStorageClass
 {
@@ -142,7 +142,9 @@ void         bse_storage_put_item_link          (BseStorage             *self,
 void         bse_storage_put_data_handle        (BseStorage             *self,
                                                  guint                   significant_bits,
                                                  GslDataHandle          *dhandle);
-void         bse_storage_flush_fd               (BseStorage             *self,
+void         bse_storage_put_xinfos             (BseStorage             *self,
+                                                 gchar                 **xinfos);
+BseErrorType bse_storage_flush_fd               (BseStorage             *self,
                                                  gint                    fd);
 
 
@@ -163,7 +165,9 @@ GTokenType   bse_storage_parse_item_link        (BseStorage             *self,
                                                  BseItem                *from_item,
                                                  BseStorageRestoreLink   restore_link,
                                                  gpointer                data);
-void         bse_storage_resolve_item_links     (BseStorage             *self);
+void         bse_storage_add_restorable         (BseStorage             *self,
+                                                 BseObject              *object);
+void         bse_storage_finish_parsing         (BseStorage             *self);
 GTokenType   bse_storage_parse_data_handle      (BseStorage             *self,
                                                  GslDataHandle         **data_handle_p,
                                                  guint                  *n_channels_p,
@@ -176,6 +180,8 @@ GTokenType   bse_storage_parse_data_handle_rest (BseStorage             *self,
                                                  guint                  *n_channels_p,
                                                  gfloat                 *mix_freq_p,
                                                  gfloat                 *osc_freq_p);
+GTokenType   bse_storage_parse_xinfos           (BseStorage             *self,
+                                                 gchar                ***xinfosp);
 GTokenType   bse_storage_parse_rest             (BseStorage             *self,
                                                  gpointer                context_data,
                                                  BseTryStatement         try_statement,
