@@ -22,10 +22,11 @@
 #include "bsecsynth.h"
 #include "bseproject.h"
 #include "bsemidireceiver.h"
-#include "gslengine.h"
+#include "bseengine.h"
 
 #include <string.h>
 
+
 /* --- parameters --- */
 enum
 {
@@ -48,19 +49,17 @@ static void	 bse_sub_synth_get_property	(GObject                *object,
 						 guint                   param_id,
 						 GValue                 *value,
 						 GParamSpec             *pspec);
-static BseItemSeq* bse_sub_synth_list_items	(BseItem		*item,
-						 guint			 param_id,
-						 GParamSpec		*pspec);
-static void	 bse_sub_synth_do_dispose	(GObject		*object);
+static void	 bse_sub_synth_dispose	        (GObject		*object);
+static void	 bse_sub_synth_finalize	        (GObject		*object);
 static void	 bse_sub_synth_context_create	(BseSource		*source,
 						 guint			 instance_id,
-						 GslTrans		*trans);
+						 BseTrans		*trans);
 static void	 bse_sub_synth_context_connect	(BseSource		*source,
 						 guint			 instance_id,
-						 GslTrans		*trans);
+						 BseTrans		*trans);
 static void	 bse_sub_synth_context_dismiss	(BseSource		*source,
 						 guint			 instance_id,
-						 GslTrans		*trans);
+						 BseTrans		*trans);
 static void  bse_sub_synth_update_port_contexts (BseSubSynth		*self,
 						 const gchar		*old_name,
 						 const gchar		*new_name,
@@ -99,126 +98,69 @@ BSE_BUILTIN_TYPE (BseSubSynth)
 }
 
 static void
-bse_sub_synth_class_init (BseSubSynthClass *class)
-{
-  GObjectClass *gobject_class = G_OBJECT_CLASS (class);
-  BseObjectClass *object_class = BSE_OBJECT_CLASS (class);
-  BseItemClass *item_class = BSE_ITEM_CLASS (class);
-  BseSourceClass *source_class = BSE_SOURCE_CLASS (class);
-  guint channel_id, i;
-  
-  parent_class = g_type_class_peek_parent (class);
-  
-  gobject_class->set_property = bse_sub_synth_set_property;
-  gobject_class->get_property = bse_sub_synth_get_property;
-  gobject_class->dispose = bse_sub_synth_do_dispose;
-  
-  item_class->list_items = bse_sub_synth_list_items;
-  
-  source_class->context_create = bse_sub_synth_context_create;
-  source_class->context_connect = bse_sub_synth_context_connect;
-  source_class->context_dismiss = bse_sub_synth_context_dismiss;
-  
-  bse_object_class_add_param (object_class, _("Assignments"),
-			      PARAM_SNET,
-			      bse_param_spec_object ("snet", _("Synthesis Network"),
-                                                     _("The synthesis network to interface to"),
-						     BSE_TYPE_CSYNTH, SFI_PARAM_STANDARD));
-  for (i = 0; i < BSE_SUB_SYNTH_N_IOPORTS; i++)
-    {
-      gchar *ident, *label, *value;
-      
-      ident = g_strdup_printf ("in_port_%u", i + 1);
-      label = g_strdup_printf (_("Input Port %u"), i + 1);
-      value = g_strdup_printf ("synth_in_%u", i + 1);
-      bse_object_class_add_param (object_class, _("Input Assignments"), PARAM_IPORT_NAME + i * 2,
-				  sfi_pspec_string (ident, label, _("Output port name to interface from"),
-						    value, SFI_PARAM_STANDARD ":skip-default"));
-      g_free (ident);
-      g_free (label);
-      g_free (value);
-      
-      ident = g_strdup_printf ("out_port_%u", i + 1);
-      label = g_strdup_printf (_("Output Port %u"), i + 1);
-      value = g_strdup_printf ("synth_out_%u", i + 1);
-      bse_object_class_add_param (object_class, _("Output Assignments"), PARAM_OPORT_NAME + i * 2,
-				  sfi_pspec_string (ident, label, _("Input port name to interface to"),
-						    value, SFI_PARAM_STANDARD ":skip-default"));
-      g_free (ident);
-      g_free (label);
-      g_free (value);
-      
-      ident = g_strdup_printf ("input-%u", i + 1);
-      label = g_strdup_printf (_("Virtual input %u"), i + 1);
-      channel_id = bse_source_class_add_ichannel (source_class, ident, label, NULL);
-      g_assert (channel_id == i);
-      g_free (ident);
-      g_free (label);
-      
-      ident = g_strdup_printf ("output-%u", i + 1);
-      label = g_strdup_printf (_("Virtual output %u"), i + 1);
-      channel_id = bse_source_class_add_ochannel (source_class, ident, label, NULL);
-      g_assert (channel_id == i);
-      g_free (ident);
-      g_free (label);
-    }
-}
-
-static void
-bse_sub_synth_init (BseSubSynth *synth)
+bse_sub_synth_init (BseSubSynth *self)
 {
   guint i;
   
-  synth->snet = NULL;
-  synth->null_shortcut = FALSE;
-  
-  for (i = 0; i < BSE_SUB_SYNTH_N_IOPORTS; i++)
-    {
-      synth->input_ports[i] = g_strdup_printf ("synth_in_%u", i + 1);
-      synth->output_ports[i] = g_strdup_printf ("synth_out_%u", i + 1);
-    }
+  self->snet = NULL;
+  self->null_shortcut = FALSE;
+
+  self->input_ports = g_new (gchar*, BSE_SOURCE_N_ICHANNELS (self));
+  for (i = 0; i < BSE_SOURCE_N_ICHANNELS (self); i++)
+    self->input_ports[i] = g_strdup_printf ("synth_in_%u", i + 1);
+
+  self->output_ports = g_new (gchar*, BSE_SOURCE_N_OCHANNELS (self));
+  for (i = 0; i < BSE_SOURCE_N_OCHANNELS (self); i++)
+    self->output_ports[i] = g_strdup_printf ("synth_out_%u", i + 1);
 }
 
 static void
-bse_sub_synth_do_dispose (GObject *object)
+bse_sub_synth_dispose (GObject *object)
 {
   BseSubSynth *self = BSE_SUB_SYNTH (object);
-  guint i;
   
   if (self->snet)
     {
       g_object_unref (self->snet);
       self->snet = NULL;
     }
-  for (i = 0; i < BSE_SUB_SYNTH_N_IOPORTS; i++)
-    {
-      g_free (self->input_ports[i]);
-      self->input_ports[i] = NULL;
-      g_free (self->output_ports[i]);
-      self->output_ports[i] = NULL;
-    }
   
   /* chain parent class' handler */
   G_OBJECT_CLASS (parent_class)->dispose (object);
 }
 
-static BseItemSeq*
-bse_sub_synth_list_items (BseItem    *item,
-                          guint       param_id,
-                          GParamSpec *pspec)
+static void
+bse_sub_synth_finalize (GObject *object)
+{
+  BseSubSynth *self = BSE_SUB_SYNTH (object);
+  guint i;
+  for (i = 0; i < BSE_SOURCE_N_ICHANNELS (self); i++)
+    g_free (self->input_ports[i]);
+  g_free (self->input_ports);
+  for (i = 0; i < BSE_SOURCE_N_OCHANNELS (self); i++)
+    g_free (self->output_ports[i]);
+  g_free (self->output_ports);
+  /* chain parent class' handler */
+  G_OBJECT_CLASS (parent_class)->finalize (object);
+}
+
+static void
+bse_sub_synth_get_candidates (BseItem               *item,
+                              guint                  param_id,
+                              BsePropertyCandidates *pc,
+                              GParamSpec            *pspec)
 {
   BseSubSynth *self = BSE_SUB_SYNTH (item);
-  BseItemSeq *iseq = bse_item_seq_new ();
   switch (param_id)
     {
     case PARAM_SNET:
-      bse_item_gather_items_typed (item, iseq, BSE_TYPE_CSYNTH, BSE_TYPE_PROJECT, FALSE);
+      bse_property_candidate_relabel (pc, _("Available Synthesizers"), _("List of available synthesis networks to choose a sub network from"));
+      bse_item_gather_items_typed (item, pc->items, BSE_TYPE_CSYNTH, BSE_TYPE_PROJECT, FALSE);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (self, param_id, pspec);
       break;
     }
-  return iseq;
 }
 
 static gboolean
@@ -228,7 +170,7 @@ find_name (BseSubSynth *self,
 {
   guint i;
   
-  for (i = 0; i < BSE_SUB_SYNTH_N_IOPORTS; i++)
+  for (i = 0; i < (is_input ? BSE_SOURCE_N_ICHANNELS (self) : BSE_SOURCE_N_OCHANNELS (self)); i++)
     {
       gchar *test = is_input ? self->input_ports[i] : self->output_ports[i];
       
@@ -295,22 +237,27 @@ bse_sub_synth_set_property (GObject      *object,
       n = (param_id - PARAM_IPORT_NAME) / 2;
       switch (indx)
 	{
-	  gchar *old_name;
 	case PARAM_IPORT_NAME:
-	  old_name = self->input_ports[n];
-	  self->input_ports[n] = NULL;	/* exempt from checks */
-	  self->input_ports[n] = dup_name_unique (self, g_value_get_string (value), TRUE);
-	  if (BSE_SOURCE_PREPARED (self))
-	    bse_sub_synth_update_port_contexts (self, old_name, self->input_ports[n], TRUE, n);
-	  g_free (old_name);
+          if (n < BSE_SOURCE_N_ICHANNELS (self))
+            {
+              gchar *old_name = self->input_ports[n];
+              self->input_ports[n] = NULL;	/* exempt from checks */
+              self->input_ports[n] = dup_name_unique (self, g_value_get_string (value), TRUE);
+              if (BSE_SOURCE_PREPARED (self))
+                bse_sub_synth_update_port_contexts (self, old_name, self->input_ports[n], TRUE, n);
+              g_free (old_name);
+            }
 	  break;
 	case PARAM_OPORT_NAME:
-	  old_name = self->output_ports[n];
-	  self->output_ports[n] = NULL; /* exempt from checks */
-	  self->output_ports[n] = dup_name_unique (self, g_value_get_string (value), TRUE);
-	  if (BSE_SOURCE_PREPARED (self))
-	    bse_sub_synth_update_port_contexts (self, old_name, self->output_ports[n], FALSE, n);
-	  g_free (old_name);
+          if (n < BSE_SOURCE_N_OCHANNELS (self))
+            {
+              gchar *old_name = self->output_ports[n];
+              self->output_ports[n] = NULL; /* exempt from checks */
+              self->output_ports[n] = dup_name_unique (self, g_value_get_string (value), TRUE);
+              if (BSE_SOURCE_PREPARED (self))
+                bse_sub_synth_update_port_contexts (self, old_name, self->output_ports[n], FALSE, n);
+              g_free (old_name);
+            }
 	  break;
 	default:
 	  G_OBJECT_WARN_INVALID_PROPERTY_ID (self, param_id, pspec);
@@ -339,10 +286,16 @@ bse_sub_synth_get_property (GObject    *object,
       switch (indx)
 	{
 	case PARAM_IPORT_NAME:
-	  g_value_set_string (value, self->input_ports[n]);
+          if (n < BSE_SOURCE_N_ICHANNELS (self))
+            g_value_set_string (value, self->input_ports[n]);
+          else
+            g_value_take_string (value, g_strdup_printf ("synth_in_%u", n + 1)); /* return default */
 	  break;
 	case PARAM_OPORT_NAME:
-	  g_value_set_string (value, self->output_ports[n]);
+          if (n < BSE_SOURCE_N_OCHANNELS (self))
+            g_value_set_string (value, self->output_ports[n]);
+          else
+            g_value_take_string (value, g_strdup_printf ("synth_out_%u", n + 1)); /* return default */
 	  break;
 	default:
 	  G_OBJECT_WARN_INVALID_PROPERTY_ID (self, param_id, pspec);
@@ -377,15 +330,15 @@ typedef struct {
 static void
 bse_sub_synth_context_create (BseSource *source,
 			      guint      context_handle,
-			      GslTrans  *trans)
+			      BseTrans  *trans)
 {
   static GSList *recursion_stack = NULL;
   BseSubSynth *self = BSE_SUB_SYNTH (source);
   BseSNet *snet = self->snet;
   ModData *mdata_in = g_new0 (ModData, 1);
   ModData *mdata_out = g_new0 (ModData, 1);
-  GslModule *imodule = gsl_module_new_virtual (BSE_SUB_SYNTH_N_IOPORTS, mdata_in, g_free);
-  GslModule *omodule = gsl_module_new_virtual (BSE_SUB_SYNTH_N_IOPORTS, mdata_out, g_free);
+  BseModule *imodule = bse_module_new_virtual (BSE_SOURCE_N_ICHANNELS (self), mdata_in, g_free);
+  BseModule *omodule = bse_module_new_virtual (BSE_SOURCE_N_OCHANNELS (self), mdata_out, g_free);
   guint foreign_context_handle = 0, shortcut = FALSE;
 
   /* create new context for foreign synth */
@@ -416,14 +369,14 @@ bse_sub_synth_context_create (BseSource *source,
   bse_source_set_context_omodule (source, context_handle, omodule);
   
   /* commit modules to engine */
-  gsl_trans_add (trans, gsl_job_integrate (imodule));
-  gsl_trans_add (trans, gsl_job_integrate (omodule));
+  bse_trans_add (trans, bse_job_integrate (imodule));
+  bse_trans_add (trans, bse_job_integrate (omodule));
   
   if (shortcut)
     {
       guint i;
-      for (i = 0; i < BSE_SUB_SYNTH_N_IOPORTS; i++)
-        gsl_trans_add (trans, gsl_job_connect (imodule, i, omodule, i));
+      for (i = 0; i < MIN (BSE_SOURCE_N_ICHANNELS (self), BSE_SOURCE_N_OCHANNELS (self)); i++)
+        bse_trans_add (trans, bse_job_connect (imodule, i, omodule, i));
     }
 
   /* chain parent class' handler */
@@ -433,7 +386,7 @@ bse_sub_synth_context_create (BseSource *source,
 static void
 bse_sub_synth_context_connect (BseSource *source,
 			       guint      context_handle,
-			       GslTrans  *trans)
+			       BseTrans  *trans)
 {
   BseSubSynth *self = BSE_SUB_SYNTH (source);
   BseSNet *snet = self->snet;
@@ -442,21 +395,18 @@ bse_sub_synth_context_connect (BseSource *source,
   /* connect module to sub synthesizer */
   if (snet)
     {
-      GslModule *imodule = bse_source_get_context_imodule (source, context_handle);
-      GslModule *omodule = bse_source_get_context_omodule (source, context_handle);
+      BseModule *imodule = bse_source_get_context_imodule (source, context_handle);
+      BseModule *omodule = bse_source_get_context_omodule (source, context_handle);
       ModData *mdata_in = imodule->user_data;
       guint foreign_context_handle = mdata_in->synth_context_handle;
       
       if (foreign_context_handle)
 	{
 	  bse_source_connect_context (BSE_SOURCE (snet), foreign_context_handle, trans);
-	  for (i = 0; i < BSE_SUB_SYNTH_N_IOPORTS; i++)
-	    {
-	      bse_snet_set_iport_src (snet, self->input_ports[i], foreign_context_handle,
-				      imodule, i, trans);
-	      bse_snet_set_oport_dest (snet, self->output_ports[i], foreign_context_handle,
-				       omodule, i, trans);
-	    }
+	  for (i = 0; i < BSE_SOURCE_N_ICHANNELS (self); i++)
+            bse_snet_set_iport_src (snet, self->input_ports[i], foreign_context_handle, imodule, i, trans);
+	  for (i = 0; i < BSE_SOURCE_N_OCHANNELS (self); i++)
+            bse_snet_set_oport_dest (snet, self->output_ports[i], foreign_context_handle, omodule, i, trans);
 	}
     }
   
@@ -467,24 +417,23 @@ bse_sub_synth_context_connect (BseSource *source,
 static void
 bse_sub_synth_context_dismiss (BseSource *source,
 			       guint      context_handle,
-			       GslTrans  *trans)
+			       BseTrans  *trans)
 {
   BseSubSynth *self = BSE_SUB_SYNTH (source);
   BseSNet *snet = self->snet;
   
   if (snet)
     {
-      GslModule *imodule = bse_source_get_context_imodule (source, context_handle);
+      BseModule *imodule = bse_source_get_context_imodule (source, context_handle);
       ModData *mdata_in = imodule->user_data;
       guint i, foreign_context_handle = mdata_in->synth_context_handle;
       
       if (foreign_context_handle)
 	{
-	  for (i = 0; i < BSE_SUB_SYNTH_N_IOPORTS; i++)
-	    {
-	      bse_snet_set_iport_src (snet, self->input_ports[i], foreign_context_handle, NULL, i, trans);
-	      bse_snet_set_oport_dest (snet, self->output_ports[i], foreign_context_handle, NULL, i, trans);
-	    }
+	  for (i = 0; i < BSE_SOURCE_N_ICHANNELS (self); i++)
+            bse_snet_set_iport_src (snet, self->input_ports[i], foreign_context_handle, NULL, i, trans);
+	  for (i = 0; i < BSE_SOURCE_N_OCHANNELS (self); i++)
+            bse_snet_set_oport_dest (snet, self->output_ports[i], foreign_context_handle, NULL, i, trans);
 	  bse_source_dismiss_context (BSE_SOURCE (snet), foreign_context_handle, trans);
 	}
     }
@@ -502,7 +451,7 @@ bse_sub_synth_update_port_contexts (BseSubSynth *self,
 {
   BseSNet *snet = self->snet;
   BseSource *source = BSE_SOURCE (self);
-  GslTrans *trans = gsl_trans_open ();
+  BseTrans *trans = bse_trans_open ();
   guint *cids, n, i;
   
   g_return_if_fail (BSE_SOURCE_PREPARED (self));
@@ -511,7 +460,7 @@ bse_sub_synth_update_port_contexts (BseSubSynth *self,
   for (i = 0; i < n; i++)
     if (is_input)
       {
-	GslModule *imodule = bse_source_get_context_imodule (source, cids[i]);
+	BseModule *imodule = bse_source_get_context_imodule (source, cids[i]);
 	ModData *mdata_in = imodule->user_data;
 	guint foreign_context_handle = mdata_in->synth_context_handle;
 	
@@ -523,7 +472,7 @@ bse_sub_synth_update_port_contexts (BseSubSynth *self,
       }
     else
       {
-	GslModule *omodule = bse_source_get_context_omodule (source, cids[i]);
+	BseModule *omodule = bse_source_get_context_omodule (source, cids[i]);
 	ModData *mdata_in = omodule->user_data;
         guint foreign_context_handle = mdata_in->synth_context_handle;
 	
@@ -534,5 +483,72 @@ bse_sub_synth_update_port_contexts (BseSubSynth *self,
 	  }
       }
   g_free (cids);
-  gsl_trans_commit (trans);
+  bse_trans_commit (trans);
+}
+
+static void
+bse_sub_synth_class_init (BseSubSynthClass *class)
+{
+  GObjectClass *gobject_class = G_OBJECT_CLASS (class);
+  BseObjectClass *object_class = BSE_OBJECT_CLASS (class);
+  BseItemClass *item_class = BSE_ITEM_CLASS (class);
+  BseSourceClass *source_class = BSE_SOURCE_CLASS (class);
+  guint channel_id, i;
+  
+  parent_class = g_type_class_peek_parent (class);
+  
+  gobject_class->set_property = bse_sub_synth_set_property;
+  gobject_class->get_property = bse_sub_synth_get_property;
+  gobject_class->dispose = bse_sub_synth_dispose;
+  gobject_class->finalize = bse_sub_synth_finalize;
+  
+  item_class->get_candidates = bse_sub_synth_get_candidates;
+  
+  source_class->context_create = bse_sub_synth_context_create;
+  source_class->context_connect = bse_sub_synth_context_connect;
+  source_class->context_dismiss = bse_sub_synth_context_dismiss;
+  
+  bse_object_class_add_param (object_class, _("Assignments"),
+			      PARAM_SNET,
+			      bse_param_spec_object ("snet", _("Synthesizer"),
+                                                     _("Synthesis network to use as embedded sub network"),
+						     BSE_TYPE_CSYNTH, SFI_PARAM_STANDARD ":unprepared"));
+  for (i = 0; i < 8; i++)
+    {
+      gchar *ident, *label, *value;
+      
+      ident = g_strdup_printf ("in_port_%u", i + 1);
+      label = g_strdup_printf (_("Input Port %u"), i + 1);
+      value = g_strdup_printf ("synth_in_%u", i + 1);
+      bse_object_class_add_param (object_class, _("Input Assignments"), PARAM_IPORT_NAME + i * 2,
+				  sfi_pspec_string (ident, label, _("Output port name to interface from"),
+						    value, SFI_PARAM_STANDARD ":skip-default"));
+      g_free (ident);
+      g_free (label);
+      g_free (value);
+      
+      ident = g_strdup_printf ("out_port_%u", i + 1);
+      label = g_strdup_printf (_("Output Port %u"), i + 1);
+      value = g_strdup_printf ("synth_out_%u", i + 1);
+      bse_object_class_add_param (object_class, _("Output Assignments"), PARAM_OPORT_NAME + i * 2,
+				  sfi_pspec_string (ident, label, _("Input port name to interface to"),
+						    value, SFI_PARAM_STANDARD ":skip-default"));
+      g_free (ident);
+      g_free (label);
+      g_free (value);
+      
+      ident = g_strdup_printf ("input-%u", i + 1);
+      label = g_strdup_printf (_("Virtual input %u"), i + 1);
+      channel_id = bse_source_class_add_ichannel (source_class, ident, label, NULL);
+      g_assert (channel_id == i);
+      g_free (ident);
+      g_free (label);
+      
+      ident = g_strdup_printf ("output-%u", i + 1);
+      label = g_strdup_printf (_("Virtual output %u"), i + 1);
+      channel_id = bse_source_class_add_ochannel (source_class, ident, label, NULL);
+      g_assert (channel_id == i);
+      g_free (ident);
+      g_free (label);
+    }
 }
