@@ -20,7 +20,8 @@
 #include "bsecontainer.h"
 #include <string.h>
 
-#define UNDO_DEBUG(...) sfi_debug ("undo", __VA_ARGS__)
+static SFI_MSG_TYPE_DEFINE (debug_undo, "undo", SFI_MSG_DEBUG, NULL);
+#define DEBUG(...)      sfi_debug (debug_undo, __VA_ARGS__)
 
 /* --- variables --- */
 static BseUndoStack *dummy_ustack = NULL;
@@ -42,6 +43,7 @@ bse_undo_stack_dummy (void)
       dummy_ustack->debug_names = NULL;
       dummy_ustack->n_undo_groups = 0;
       dummy_ustack->undo_groups = NULL;
+      dummy_ustack->dirt_counter = 0;
       dummy_ustack->n_merge_requests = 0;
       dummy_ustack->merge_name = NULL;
       dummy_ustack->merge_next = FALSE;
@@ -89,6 +91,28 @@ bse_undo_stack_clear (BseUndoStack *self)
   self->max_steps = max_steps;
 }
 
+gboolean
+bse_undo_stack_dirty (BseUndoStack *self)
+{
+  return self->dirt_counter || (self->group && self->group->undo_steps);
+}
+
+void
+bse_undo_stack_clean_dirty (BseUndoStack *self)
+{
+  self->dirt_counter = 0;
+}
+
+void
+bse_undo_stack_force_dirty (BseUndoStack *self)
+{
+  if (self->dirt_counter <= 0)
+    {
+      /* make unrecoverably dirty */
+      self->dirt_counter = self->n_undo_groups + 1;
+    }
+}
+
 void
 bse_undo_stack_destroy (BseUndoStack *self)
 {
@@ -112,7 +136,7 @@ bse_undo_group_open (BseUndoStack   *self,
       self->group->stamp = 0;
       self->group->name = g_strdup (name);
       self->group->undo_steps = NULL;
-      UNDO_DEBUG ("undo open: { // %s", name);
+      DEBUG ("undo open: { // %s", name);
     }
   self->n_open_groups++;
   self->debug_names = g_slist_prepend (self->debug_names, g_strdup (name));
@@ -135,12 +159,12 @@ bse_undo_stack_push (BseUndoStack *self,
 
   if (self->ignore_steps)
     {
-      UNDO_DEBUG ("undo step:  -    ignored: ((BseUndoFunc) %p) (%s)", ustep->undo_func, debug_name);
+      DEBUG ("undo step:  -    ignored: ((BseUndoFunc) %p) (%s)", ustep->undo_func, debug_name);
       bse_undo_step_free (ustep);
     }
   else
     {
-      UNDO_DEBUG ("undo step:  *    ((BseUndoFunc) %p) (%s)", ustep->undo_func, debug_name);
+      DEBUG ("undo step:  *    ((BseUndoFunc) %p) (%s)", ustep->undo_func, debug_name);
       ustep->debug_name = g_strdup (debug_name);
       self->group->undo_steps = sfi_ring_push_head (self->group->undo_steps, ustep);
     }
@@ -152,10 +176,15 @@ bse_undo_stack_push_add_on (BseUndoStack *self,
 {
   g_return_if_fail (ustep != NULL);
 
+  /* add-ons are generally used as state-guards. that is, if a an already added
+   * undo-steps requires the object to be in a certain state, an add-on step
+   * can be queued after the fact, to ensure the required object state.
+   */
+
   /* add this step to the last undo step if we have one */
   if (self->group && self->group->undo_steps)
     {
-      UNDO_DEBUG ("undo step:  *    ((BseUndoFunc) %p) [AddOn to current group]", ustep->undo_func);
+      DEBUG ("undo step:  *    ((BseUndoFunc) %p) [AddOn to current group]", ustep->undo_func);
       ustep->debug_name = g_strdup ("AddOn");
       self->group->undo_steps = sfi_ring_push_head (self->group->undo_steps, ustep);
     }
@@ -163,13 +192,13 @@ bse_undo_stack_push_add_on (BseUndoStack *self,
     {
       BseUndoGroup *group = self->undo_groups->data;    /* fetch last group */
       g_return_if_fail (group->undo_steps != NULL);     /* empty groups are not allowed */
-      UNDO_DEBUG ("undo step:  *    ((BseUndoFunc) %p) [AddOn to last group]", ustep->undo_func);
+      DEBUG ("undo step:  *    ((BseUndoFunc) %p) [AddOn to last group]", ustep->undo_func);
       ustep->debug_name = g_strdup ("AddOn");
       group->undo_steps = sfi_ring_push_head (group->undo_steps, ustep);
     }
   else
     {
-      UNDO_DEBUG ("undo step:  -    ignored: ((BseUndoFunc) %p) [AddOn]", ustep->undo_func);
+      DEBUG ("undo step:  -    ignored: ((BseUndoFunc) %p) [AddOn]", ustep->undo_func);
       bse_undo_step_free (ustep);
     }
 }
@@ -196,7 +225,7 @@ bse_undo_group_close (BseUndoStack *self)
           step_added = FALSE;
           g_free (self->group->name);
           g_free (self->group);
-          UNDO_DEBUG ("undo skip  }");
+          DEBUG ("undo skip  }");
         }
       else
         {
@@ -210,15 +239,18 @@ bse_undo_group_close (BseUndoStack *self)
                                                     mgroup->undo_steps);
               g_free (self->group->name);
               g_free (self->group);
+              if (!self->dirt_counter)  /* ensure dirty */
+                bse_undo_stack_force_dirty (self);
             }
           else
             {
               self->n_undo_groups++;
               self->undo_groups = sfi_ring_push_head (self->undo_groups, self->group);
               self->merge_next = self->n_merge_requests > 0;
+              self->dirt_counter++;
             }
           bse_undo_stack_limit (self, self->max_steps);
-          UNDO_DEBUG ("undo close }");
+          DEBUG ("undo close }");
         }
       self->group = NULL;
       if (self->notify && step_added)
@@ -297,28 +329,27 @@ bse_undo_stack_undo (BseUndoStack *self)
   group = sfi_ring_pop_head (&self->undo_groups);
   if (group)
     {
-      gboolean step_removed = FALSE;
       self->n_undo_groups--;
-      UNDO_DEBUG ("EXECUTE UNDO: %s", group->name);
-      if (sfi_debug_check ("undo"))
+      self->dirt_counter--;
+      DEBUG ("EXECUTE UNDO: %s", group->name);
+      if (sfi_msg_check (debug_undo))
         {
           SfiRing *ring = group->undo_steps;
           for (ring = group->undo_steps; ring; ring = sfi_ring_walk (ring, group->undo_steps))
             {
               BseUndoStep *ustep = ring->data;
-              UNDO_DEBUG ("   STEP UNDO: %s", ustep->debug_name);
+              DEBUG ("   STEP UNDO: %s", ustep->debug_name);
             }
         }
       while (group->undo_steps)
         {
           BseUndoStep *ustep = sfi_ring_pop_head (&group->undo_steps);
-          step_removed = TRUE;
           bse_undo_step_exec (ustep, self);
           bse_undo_step_free (ustep);
         }
       g_free (group->name);
       g_free (group);
-      if (self->notify && step_removed)
+      if (self->notify)
         self->notify (self->project, self, FALSE);
     }
 
