@@ -87,6 +87,32 @@ gulong	bse_id_alloc	(void);
 void	bse_id_free	(gulong	id);
 
 
+/* --- string array manipulation --- */
+gchar**       bse_xinfos_add_value              (gchar          **xinfos,
+                                                 const gchar     *key,
+                                                 const gchar     *value);
+gchar**       bse_xinfos_add_float              (gchar          **xinfos,
+                                                 const gchar     *key,
+                                                 gfloat           fvalue);
+gchar**       bse_xinfos_add_num                (gchar          **xinfos,
+                                                 const gchar     *key,
+                                                 SfiNum           num);
+gchar**       bse_xinfos_parse_assignment       (gchar          **xinfos,
+                                                 const gchar     *assignment);
+gchar**       bse_xinfos_del_value              (gchar          **xinfos,
+                                                 const gchar     *key);
+const gchar*  bse_xinfos_get_value              (gchar          **xinfos,
+                                                 const gchar     *key);
+gfloat        bse_xinfos_get_float              (gchar          **xinfos,
+                                                 const gchar     *key);
+SfiNum        bse_xinfos_get_num                (gchar          **xinfos,
+                                                 const gchar     *key);
+gchar**       bse_xinfos_dup_consolidated       (gchar          **xinfos,
+                                                 gboolean         copy_interns);
+gint          bse_xinfo_stub_compare            (const gchar     *xinfo1,  /* must contain '=' */
+                                                 const gchar     *xinfo2); /* must contain '=' */
+
+
 /* --- miscellaeous --- */
 guint		bse_string_hash			(gconstpointer   string);
 gint		bse_string_equals		(gconstpointer	 string1,
@@ -95,6 +121,7 @@ const gchar*    bse_intern_path_user_data       (const gchar    *dir);
 
 
 /* --- bbuffer utils --- */
+#define BSE_BBUFFER_SIZE        (128)
 void	bse_bbuffer_puts	(gchar       	 bbuffer[BSE_BBUFFER_SIZE],
 				 const gchar	*string);
 guint	bse_bbuffer_printf	(gchar		 bbuffer[BSE_BBUFFER_SIZE],
