@@ -129,7 +129,7 @@ use_editable_exec (BseProcedureClass *proc,
   if (!BSE_IS_WAVE (wave))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-  wchunk = g_slist_nth_data (wave->wave_chunks, chunk_index);
+  wchunk = sfi_ring_nth_data (wave->wave_chunks, chunk_index);
   if (wchunk)
     {
       esample = g_object_new (BSE_TYPE_EDITABLE_SAMPLE, NULL);
@@ -156,7 +156,7 @@ chunk_get_osc_freq_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GPara
   *(in_pspecs++)    = sfi_pspec_int ("chunk_index", "Chunk Index", "Index of chunk",
 			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_real ("osc_freq", NULL, NULL,
-			  BSE_KAMMER_FREQUENCY_f, BSE_MIN_OSC_FREQUENCY_f, BSE_MAX_OSC_FREQUENCY_f, 10.0,
+			  BSE_KAMMER_FREQUENCY, BSE_MIN_OSC_FREQUENCY, BSE_MAX_OSC_FREQUENCY, 10.0,
 			  SFI_PARAM_STANDARD);
 }
 #line 134 "bsewave.proc"
@@ -179,7 +179,7 @@ chunk_get_osc_freq_exec (BseProcedureClass *proc,
   if (!BSE_IS_WAVE (wave))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-  wchunk = g_slist_nth_data (wave->wave_chunks, chunk_index);
+  wchunk = sfi_ring_nth_data (wave->wave_chunks, chunk_index);
   if (wchunk)
     sfi_value_set_real (out_values++, wchunk->osc_freq);
 
@@ -221,7 +221,7 @@ chunk_get_mix_freq_exec (BseProcedureClass *proc,
   if (!BSE_IS_WAVE (wave))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-  wchunk = g_slist_nth_data (wave->wave_chunks, chunk_index);
+  wchunk = sfi_ring_nth_data (wave->wave_chunks, chunk_index);
   if (wchunk)
     sfi_value_set_real (out_values++, wchunk->mix_freq);
 
