@@ -1,7 +1,7 @@
 
-/**
- ** Generated data (by mkcproc.pl)
- **/
+/*
+ * Generated data (by mkcproc.pl)
+ */
 #line 1 "bsewaveosc.proc"
 
 #include <bse/bseplugin.h>
@@ -38,42 +38,44 @@ request_pcm_position_exec (BseProcedureClass *proc,
   if (!BSE_IS_WAVE_OSC (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-  bse_wave_osc_request_pcm_position (self, -1);
+  bse_wave_osc_request_pcm_position (self);
   
   return BSE_ERROR_NONE;
 }
 
-/* --- pcm-seek-perc --- */
+/* --- bse-wave-osc-mass-seek-perc --- */
 static void
-pcm_seek_perc_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+bse_wave_osc_mass_seek_perc_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 47 "bsewaveosc.proc"
  {
 #line 49 "bsewaveosc.proc"
-  *(in_pspecs++) = bse_param_spec_object ("wosc", NULL, "Wave Oscilator",
-				 BSE_TYPE_WAVE_OSC, SFI_PARAM_STANDARD);
+  *(in_pspecs++)    = bse_param_spec_boxed ("wosc-seq", "Wave Oscilators", NULL, BSE_TYPE_ITEM_SEQ, SFI_PARAM_STANDARD); // FIXME: using BseItemSeq because BseWaveOscSeq requires idl+C++
   *(in_pspecs++) = sfi_pspec_real ("pos_perc", NULL, NULL,
 			  0, 0, 100, 1,
 			  SFI_PARAM_STANDARD);
-#line 54 "bsewaveosc.proc"
+#line 53 "bsewaveosc.proc"
 }  }
 static BseErrorType
-#line 54 "bsewaveosc.proc"
-pcm_seek_perc_exec (BseProcedureClass *proc,
+#line 53 "bsewaveosc.proc"
+bse_wave_osc_mass_seek_perc_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
-#line 57 "bsewaveosc.proc"
+#line 56 "bsewaveosc.proc"
 {
-#line 58 "bsewaveosc.proc"
+#line 57 "bsewaveosc.proc"
   
-  BseWaveOsc *self = bse_value_get_object (in_values++);
+  BseItemSeq *iseq = bse_value_get_boxed (in_values++);
   gfloat      pos  = sfi_value_get_real (in_values++);
-  
-#line 62 "bsewaveosc.proc"
-  
-  if (!BSE_IS_WAVE_OSC (self))
-    return BSE_ERROR_PROC_PARAM_INVAL;
-  
-  bse_wave_osc_request_pcm_position (self, CLAMP (pos, 0, 100));
+  guint i, n = iseq ? iseq->n_items : 0;
+  BseWaveOsc **woscs = g_alloca (sizeof (BseWaveOsc*) * n);
+  for (i = 0; i < n; i++)
+#line 63 "bsewaveosc.proc"
+    if (!BSE_IS_WAVE_OSC (iseq->items[i]))      
+      return BSE_ERROR_PROC_PARAM_INVAL;
+    else
+      woscs[i] = (BseWaveOsc*) iseq->items[i];
+  if (n)
+    bse_wave_osc_mass_seek (n, woscs, pos);
   
   return BSE_ERROR_NONE;
 }
@@ -81,28 +83,28 @@ pcm_seek_perc_exec (BseProcedureClass *proc,
 /* --- set-from-editable-sample --- */
 static void
 set_from_editable_sample_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 71 "bsewaveosc.proc"
- {
 #line 73 "bsewaveosc.proc"
+ {
+#line 75 "bsewaveosc.proc"
   *(in_pspecs++) = bse_param_spec_object ("wosc", NULL, "Wave Oscilator",
 				 BSE_TYPE_WAVE_OSC, SFI_PARAM_STANDARD);
   *(in_pspecs++) = bse_param_spec_object ("esample", NULL, "Editable Sample",
 				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_STANDARD);
-#line 77 "bsewaveosc.proc"
+#line 79 "bsewaveosc.proc"
 }  }
 static BseErrorType
-#line 77 "bsewaveosc.proc"
+#line 79 "bsewaveosc.proc"
 set_from_editable_sample_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
-#line 80 "bsewaveosc.proc"
+#line 82 "bsewaveosc.proc"
 {
-#line 81 "bsewaveosc.proc"
+#line 83 "bsewaveosc.proc"
   
   BseWaveOsc *self           = bse_value_get_object (in_values++);
   BseEditableSample *esample = bse_value_get_object (in_values++);
 
-#line 85 "bsewaveosc.proc"
+#line 87 "bsewaveosc.proc"
   
   if (!BSE_IS_WAVE_OSC (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -131,21 +133,21 @@ static BseExportNodeProc __enode_request_pcm_position = {
   0, request_pcm_position_setup, request_pcm_position_exec, 
 };
 static void
-__enode_pcm_seek_perc__fill_strings (BseExportStrings *es)
+__enode_bse_wave_osc_mass_seek_perc__fill_strings (BseExportStrings *es)
 {
-  es->blurb = "Seek oscillator to a given pcm percentage during playback.";
+  es->blurb = "Seek a list of wave oscillators to a pcm position given in percentage. The oscillators will seek to the given position syncronously.";
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
-static BseExportNodeProc __enode_pcm_seek_perc = {
+static BseExportNodeProc __enode_bse_wave_osc_mass_seek_perc = {
   { (BseExportNode*) &__enode_request_pcm_position, BSE_EXPORT_NODE_PROC,
-    "BseWaveOsc+pcm-seek-perc", 
+    "bse-wave-osc-mass-seek-perc", 
     NULL,
-    "/Methods/BseWaveOsc/General/Pcm Seek Perc",
+    "/Proc/Seek Wave Oscillators",
     NULL,
-    __enode_pcm_seek_perc__fill_strings,
+    __enode_bse_wave_osc_mass_seek_perc__fill_strings,
   },
-  0, pcm_seek_perc_setup, pcm_seek_perc_exec, 
+  0, bse_wave_osc_mass_seek_perc_setup, bse_wave_osc_mass_seek_perc_exec, 
 };
 static void
 __enode_set_from_editable_sample__fill_strings (BseExportStrings *es)
@@ -155,7 +157,7 @@ __enode_set_from_editable_sample__fill_strings (BseExportStrings *es)
   es->license = "GNU General Public License";
 }
 static BseExportNodeProc __enode_set_from_editable_sample = {
-  { (BseExportNode*) &__enode_pcm_seek_perc, BSE_EXPORT_NODE_PROC,
+  { (BseExportNode*) &__enode_bse_wave_osc_mass_seek_perc, BSE_EXPORT_NODE_PROC,
     "BseWaveOsc+set-from-editable-sample", 
     NULL,
     "/Methods/BseWaveOsc/General/Set From Editable Sample",
@@ -170,6 +172,6 @@ BseExportNode* bse__builtin_init_bsewaveosc_gen_proc_c (void)
   return (BseExportNode*) &__enode_set_from_editable_sample;
 }
 
-/**
- ** Generated data ends here
- **/
+/*
+ * Generated data ends here
+ */
