@@ -141,22 +141,22 @@ bse_iir_filter_class_init (BseIIRFilterClass *class)
   bse_object_class_add_param (object_class, _("Cutoff Frequency (All Filters)"),
 			      PARAM_CUT_OFF_FREQ1,
 			      bse_param_spec_freq ("cut_off_freq", _("Cutoff [Hz]"), NULL,
-						   BSE_KAMMER_FREQUENCY_f / 2,
+						   BSE_KAMMER_FREQUENCY / 2, BSE_MIN_OSC_FREQUENCY, BSE_MAX_OSC_FREQUENCY,
 						   SFI_PARAM_STANDARD ":f:dial"));
   bse_object_class_add_param (object_class, _("Cutoff Frequency (All Filters)"),
 			      PARAM_CUT_OFF_NOTE1,
 			      bse_pspec_note ("cut_off_note", _("Note"), NULL,
-					      bse_note_from_freq (BSE_KAMMER_FREQUENCY_f / 2),
+					      bse_note_from_freq (BSE_KAMMER_FREQUENCY / 2),
 					      SFI_PARAM_GUI));
   bse_object_class_add_param (object_class, _("Cutoff Frequency 2 (Band Pass/Stop)"),
 			      PARAM_CUT_OFF_FREQ2,
 			      bse_param_spec_freq ("cut_off_freq_2", _("Cutoff [Hz]"), NULL,
-						   BSE_KAMMER_FREQUENCY_f / 2 + FREQ_DELTA,
+						   BSE_KAMMER_FREQUENCY / 2 + FREQ_DELTA, BSE_MIN_OSC_FREQUENCY, BSE_MAX_OSC_FREQUENCY,
 						   SFI_PARAM_STANDARD ":f:dial"));
   bse_object_class_add_param (object_class, _("Cutoff Frequency 2 (Band Pass/Stop)"),
 			      PARAM_CUT_OFF_NOTE2,
 			      bse_pspec_note ("cut_off_note_2", _("Note"), NULL,
-					      bse_note_from_freq (BSE_KAMMER_FREQUENCY_f / 2 + FREQ_DELTA),
+					      bse_note_from_freq (BSE_KAMMER_FREQUENCY / 2 + FREQ_DELTA),
 					      SFI_PARAM_GUI));
   
   ichannel_id = bse_source_class_add_ichannel (source_class, "audio-in", _("Audio In"), _("Unfiltered Input"));
@@ -172,7 +172,7 @@ bse_iir_filter_init (BseIIRFilter *filt)
   filt->filter_type = BSE_IIR_FILTER_LOW_PASS;
   filt->order = 6;
   filt->epsilon = 0.1;
-  filt->cut_off_freq1 = BSE_KAMMER_FREQUENCY_f / 2;
+  filt->cut_off_freq1 = BSE_KAMMER_FREQUENCY / 2;
   filt->cut_off_freq2 = filt->cut_off_freq1 + FREQ_DELTA;
   filt->filter_type = BSE_IIR_FILTER_BUTTERWORTH;
   bse_iir_filter_update_modules (filt);
@@ -219,7 +219,7 @@ bse_iir_filter_set_property (GObject	  *object,
       break;
     case PARAM_CUT_OFF_NOTE1:
       filt->cut_off_freq1 = bse_note_to_freq (sfi_value_get_note (value));
-      filt->cut_off_freq1 = MAX (filt->cut_off_freq1, BSE_MIN_OSC_FREQUENCY_d);
+      filt->cut_off_freq1 = MAX (filt->cut_off_freq1, BSE_MIN_OSC_FREQUENCY);
       if (filt->cut_off_freq1 + FREQ_DELTA > filt->cut_off_freq2)
 	{
 	  filt->cut_off_freq2 = filt->cut_off_freq1 + FREQ_DELTA;
@@ -242,7 +242,7 @@ bse_iir_filter_set_property (GObject	  *object,
       break;
     case PARAM_CUT_OFF_NOTE2:
       filt->cut_off_freq2 = bse_note_to_freq (sfi_value_get_note (value));
-      filt->cut_off_freq2 = MAX (filt->cut_off_freq2, BSE_MIN_OSC_FREQUENCY_d);
+      filt->cut_off_freq2 = MAX (filt->cut_off_freq2, BSE_MIN_OSC_FREQUENCY);
       if (filt->cut_off_freq1 + FREQ_DELTA > filt->cut_off_freq2)
 	{
 	  filt->cut_off_freq1 = filt->cut_off_freq2 - FREQ_DELTA;
