@@ -18,7 +18,7 @@
  */
 #include "bsemult.h"
 
-#include <bse/gslengine.h>
+#include <bse/bseengine.h>
 
 #include <string.h>
 
@@ -27,7 +27,7 @@ static void	 bse_mult_init			(BseMult	*mult);
 static void	 bse_mult_class_init		(BseMultClass	*class);
 static void	 bse_mult_context_create	(BseSource	*source,
 						 guint		 context_handle,
-						 GslTrans	*trans);
+						 BseTrans	*trans);
 
 
 /* --- Export to BSE --- */
@@ -75,32 +75,32 @@ bse_mult_init (BseMult *mult)
 }
 
 static void
-multiply_process (GslModule *module,
+multiply_process (BseModule *module,
 		  guint      n_values)
 {
   // = module->user_data;
-  gfloat *wave_out = GSL_MODULE_OBUFFER (module, 0);
+  gfloat *wave_out = BSE_MODULE_OBUFFER (module, 0);
   gfloat *bound = wave_out + n_values;
   guint i;
   
   if (!module->ostreams[0].connected)
     return;	/* nothing to process */
-  for (i = 0; i < GSL_MODULE_N_ISTREAMS (module); i++)
+  for (i = 0; i < BSE_MODULE_N_ISTREAMS (module); i++)
     if (module->istreams[i].connected)
       {
 	/* found first channel */
-	memcpy (wave_out, GSL_MODULE_IBUFFER (module, i), n_values * sizeof (wave_out[0]));
+	memcpy (wave_out, BSE_MODULE_IBUFFER (module, i), n_values * sizeof (wave_out[0]));
 	break;
       }
-  if (i >= GSL_MODULE_N_ISTREAMS (module))
+  if (i >= BSE_MODULE_N_ISTREAMS (module))
     {
       /* no input, FIXME: should set static-0 here */
       memset (wave_out, 0, n_values * sizeof (wave_out[0]));
     }
-  for (i += 1; i < GSL_MODULE_N_ISTREAMS (module); i++)
+  for (i += 1; i < BSE_MODULE_N_ISTREAMS (module); i++)
     if (module->istreams[i].connected)
       {
-	const gfloat *in = GSL_MODULE_IBUFFER (module, i);
+	const gfloat *in = BSE_MODULE_IBUFFER (module, i);
 	gfloat *out = wave_out;
 	
 	/* found 1+nth channel to multiply with */
@@ -113,9 +113,9 @@ multiply_process (GslModule *module,
 static void
 bse_mult_context_create (BseSource *source,
 			 guint      context_handle,
-			 GslTrans  *trans)
+			 BseTrans  *trans)
 {
-  static const GslClass multiply_class = {
+  static const BseModuleClass multiply_class = {
     4,                          /* n_istreams */
     0,                          /* n_jstreams */
     1,                          /* n_ostreams */
@@ -123,18 +123,18 @@ bse_mult_context_create (BseSource *source,
     NULL,                       /* process_defer */
     NULL,                       /* reset */
     NULL,                       /* free */
-    GSL_COST_CHEAP,             /* cost */
+    BSE_COST_CHEAP,             /* cost */
   };
   // BseMult *mult = BSE_MULT (source);
-  GslModule *module;
+  BseModule *module;
   
-  module = gsl_module_new (&multiply_class, NULL);
+  module = bse_module_new (&multiply_class, NULL);
   
   /* setup module i/o streams with BseSource i/o channels */
   bse_source_set_context_module (source, context_handle, module);
   
   /* commit module to engine */
-  gsl_trans_add (trans, gsl_job_integrate (module));
+  bse_trans_add (trans, bse_job_integrate (module));
   
   /* chain parent class' handler */
   BSE_SOURCE_CLASS (parent_class)->context_create (source, context_handle, trans);
