@@ -1,5 +1,5 @@
-/* BseMult - BSE Mult
- * Copyright (C) 1999 Tim Janik
+/* BseMult - BSE Multiplier
+ * Copyright (C) 1999, 2000-2002 Tim Janik
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Library General Public License as
@@ -35,12 +35,12 @@ extern "C" {
 
 
 /* --- object type macros --- */
-#define BSE_TYPE_MULT              (type_id_mult)
-#define BSE_MULT(object)           (BSE_CHECK_STRUCT_CAST ((object), BSE_TYPE_MULT, BseMult))
-#define BSE_MULT_CLASS(class)      (BSE_CHECK_CLASS_CAST ((class), BSE_TYPE_MULT, BseMultClass))
-#define BSE_IS_MULT(object)        (BSE_CHECK_STRUCT_TYPE ((object), BSE_TYPE_MULT))
-#define BSE_IS_MULT_CLASS(class)   (BSE_CHECK_CLASS_TYPE ((class), BSE_TYPE_MULT))
-#define BSE_MULT_GET_CLASS(object) ((BseMultClass*) (((BseObject*) (object))->bse_struct.bse_class))
+#define BSE_TYPE_MULT              (BSE_EXPORT_TYPE_ID (BseMult))
+#define BSE_MULT(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), BSE_TYPE_MULT, BseMult))
+#define BSE_MULT_CLASS(class)      (G_TYPE_CHECK_CLASS_CAST ((class), BSE_TYPE_MULT, BseMultClass))
+#define BSE_IS_MULT(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), BSE_TYPE_MULT))
+#define BSE_IS_MULT_CLASS(class)   (G_TYPE_CHECK_CLASS_TYPE ((class), BSE_TYPE_MULT))
+#define BSE_MULT_GET_CLASS(object) (G_TYPE_INSTANCE_GET_CLASS ((object), BSE_TYPE_MULT, BseMultClass))
 
 
 /* --- BseMult source --- */
@@ -59,7 +59,6 @@ struct _BseMultClass
 /* --- channels --- */
 enum
 {
-  BSE_MULT_ICHANNEL_NONE,
   BSE_MULT_ICHANNEL_MONO1,
   BSE_MULT_ICHANNEL_MONO2,
   BSE_MULT_ICHANNEL_MONO3,
@@ -67,7 +66,6 @@ enum
 };
 enum
 {
-  BSE_MULT_OCHANNEL_NONE,
   BSE_MULT_OCHANNEL_MONO
 };
 
