@@ -18,8 +18,9 @@
 
     */
 
-#include "compiler.h"
+#include "compiler.hh"
 #include <assert.h>
+#include <ctype.h>
 
 using std::vector;
 using std::string;
