@@ -16,8 +16,8 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#include "sfidl-corec.h"
-#include "sfidl-factory.h"
+#include "sfidl-corec.hh"
+#include "sfidl-factory.hh"
 #include <fcntl.h>
 #include <stdio.h>
 #include <unistd.h>
