@@ -21,7 +21,7 @@
 #include <list>
 #include <string>
 #include <map>
-#include "sfidl-namespace.h"
+#include "sfidl-namespace.hh"
 #include <sfi/glib-extra.h>
 
 using namespace std;
@@ -65,56 +65,6 @@ static string listToSymbol(list<string>& symlist)
   return s;
 }
 
-/* ModuleHelper */
-static list<string> modulePath;
-static map<string,bool> moduleDefinitions;
-
-void ModuleHelper::enter(const char *name)
-{
-  modulePath.push_back(name);
-}
-
-void ModuleHelper::leave()
-{
-  g_assert (!modulePath.empty());
-  modulePath.pop_back();
-}
-
-string prependModulePath(string s)
-{
-  if(modulePath.empty())
-    return s;
-  else
-    return listToSymbol(modulePath)+"::"+s;
-}
-
-string ModuleHelper::define(const char *name)
-{
-  string s = prependModulePath(name);
-  moduleDefinitions[s] = true;
-  return s;
-}
-
-string ModuleHelper::qualify(const char *name)
-{
-  string result;
-  
-  // TODO: nested namespaces
-  
-  string inCurrentModule = prependModulePath(name);
-  if(moduleDefinitions[inCurrentModule])
-    {
-      result = inCurrentModule.c_str();
-    }
-  else if(moduleDefinitions[name])
-    {
-      result = name;
-    }
-  
-  return result;
-}
-
-
 /* NamespaceHelper */
 NamespaceHelper::NamespaceHelper(FILE *outputfile) : out(outputfile)
 {
@@ -125,29 +75,30 @@ NamespaceHelper::~NamespaceHelper()
   leaveAll();
 }
 
-void NamespaceHelper::setFromSymbol(string symbol)
+void
+NamespaceHelper::setFromSymbol(string symbol)
 {
-  list<string> symlist = symbolToList(symbol);
+  list<string> symlist = symbolToList (symbol);
   symlist.pop_back();
   
   /* check that the current namespace doesn't contain wrong parts at end */
   list<string>::iterator ni,si;
   ni = currentNamespace.begin();
   si = symlist.begin();
-  long wrong = currentNamespace.size();
-  while(ni != currentNamespace.end() && si != symlist.end() && *ni == *si)
+  while (ni != currentNamespace.end() && si != symlist.end() && *ni == *si)
     {
       ni++;
       si++;
-      wrong--;
     }
-  while(wrong--)
+  /* close unwanted namespaces */
+  reverse (ni, currentNamespace.end()); /* close inner namespaces first */
+  while (ni != currentNamespace.end())
     {
-      fprintf(out,"};\n");
+      fprintf (out,"} // %s\n", (*ni++).c_str());
     }
   
   /* enter new components at the end */
-  while(si != symlist.end())
+  while (si != symlist.end())
     {
       fprintf(out,"namespace %s {\n",(*si++).c_str());
     }
@@ -182,6 +133,11 @@ string NamespaceHelper::printableForm(string symbol)
   
   return listToSymbol(symlist);
 }
+const char*
+NamespaceHelper::printable_form (std::string symbol)
+{
+  return g_intern_string (printableForm (symbol).c_str());
+}
 
 string NamespaceHelper::nameOf(string symbol)
 {
