@@ -1533,6 +1533,23 @@ sfi_ring_split (SfiRing *head1,
   return head2;
 }
 
+static inline SfiRing*
+sfi_ring_unlink_node_dangling (SfiRing *head,
+                               SfiRing *node)
+{
+  g_assert (head && node);
+  /* special case one item ring */
+  if (head->prev == head)
+    return NULL;
+  /* unlink */
+  node->next->prev = node->prev;
+  node->prev->next = node->next;
+  if (head == node)
+    head = node->next;
+  /* node->prev and node->next are dangling now */
+  return head;
+}
+
 SfiRing*
 sfi_ring_remove_node (SfiRing *head,
 		      SfiRing *node)
@@ -1763,6 +1780,8 @@ sfi_ring_insert_sorted (SfiRing	      *head,
   if (!head)
     return sfi_ring_prepend (head, insertion_data);
 
+  /* implement stable sorting by inserting insertion_data *after* equal nodes */
+
   if (cmp (insertion_data, head->data, cmp_data) >= 0)  /* insert after head */
     {
       SfiRing *tmp, *tail = head->prev;
@@ -1790,6 +1809,8 @@ sfi_ring_merge_sorted (SfiRing        *head1,
                        SfiCompareFunc  cmp,
                        gpointer        data)
 {
+  /* implement stable sorting by inserting head2 members *after* equal nodes from head1 */
+
   if (head1 && head2)
     {
       SfiRing *tail1 = head1->prev;
@@ -1839,6 +1860,8 @@ sfi_ring_sort (SfiRing        *head,
 {
   g_return_val_if_fail (cmp != NULL, head);
 
+  /* stable sorting guaranteed by sfi_ring_merge_sorted() */
+
   if (head && head->next != head)
     {
       SfiRing *ring, *tmp, *tail = head->prev;
@@ -1862,9 +1885,89 @@ sfi_ring_uniq (SfiRing        *sorted_ring1,
                SfiCompareFunc  cmp,
                gpointer        data)
 {
-  SfiRing *ring = sfi_ring_copy_uniq (sorted_ring1, cmp, data);
-  sfi_ring_free (sorted_ring1);
-  return ring;
+  /* always preserves the first of a sublist of consequtive equal elements */
+  SfiRing *r1 = sorted_ring1;
+  SfiRing *r2 = NULL;
+  if (r1)
+    {
+      SfiRing *last = r1;
+      r1 = sfi_ring_unlink_node_dangling (r1, last);
+      r2 = last->next = last->prev = last; /* form new ring */
+      while (r1)
+        {
+          SfiRing *node = r1;
+          r1 = sfi_ring_unlink_node_dangling (r1, node);
+          if (cmp (last->data, node->data, data))
+            {
+              last = node;
+              r2 = sfi_ring_append_link_i (r2, last);
+            }
+          else
+            sfi_delete_struct (SfiRing, node);
+        }
+    }
+  return r2;
+}
+
+SfiRing* /* eliminates duplicate nodes */
+sfi_ring_uniq_free_deep (SfiRing        *sorted_ring1,
+                         SfiCompareFunc  cmp,
+                         gpointer        data,
+                         GDestroyNotify  data_destroy)
+{
+  /* always preserves the first of a sublist of consequtive equal elements */
+  if (!data_destroy)
+    return sfi_ring_uniq (sorted_ring1, cmp, data);
+  SfiRing *r1 = sorted_ring1;
+  SfiRing *r2 = NULL;
+  if (r1)
+    {
+      SfiRing *last = r1;
+      r1 = sfi_ring_unlink_node_dangling (r1, last);
+      r2 = last->next = last->prev = last; /* form new ring */
+      while (r1)
+        {
+          SfiRing *node = r1;
+          r1 = sfi_ring_unlink_node_dangling (r1, node);
+          if (cmp (last->data, node->data, data))
+            {
+              last = node;
+              r2 = sfi_ring_append_link_i (r2, last);
+            }
+          else
+            {
+              data_destroy (node->data);
+              sfi_delete_struct (SfiRing, node);
+            }
+        }
+    }
+  return r2;
+}
+
+SfiRing* /* eliminates duplicate nodes */
+sfi_ring_copy_deep_uniq (const SfiRing  *sorted_ring1,
+                         SfiRingDataFunc copy,
+                         gpointer        copy_data,
+                         SfiCompareFunc  cmp,
+                         gpointer        cmp_data)
+{
+  /* always preserves the first of a sublist of consequtive equal elements */
+  if (!copy)
+    return sfi_ring_copy_uniq (sorted_ring1, cmp, cmp_data);
+  const SfiRing *r1 = sorted_ring1;
+  SfiRing *r2 = NULL;
+  if (r1)
+    {
+      gpointer last_data = r1->data;
+      r2 = sfi_ring_append (r2, copy (last_data, copy_data));
+      for (r1 = sfi_ring_walk (r1, sorted_ring1); r1; r1 = sfi_ring_walk (r1, sorted_ring1))
+        if (cmp (last_data, r1->data, cmp_data))
+          {
+            last_data = r1->data;
+            r2 = sfi_ring_append (r2, copy (last_data, copy_data));
+          }
+    }
+  return r2;
 }
 
 SfiRing* /* eliminates duplicate nodes */
@@ -1872,6 +1975,7 @@ sfi_ring_copy_uniq (const SfiRing  *sorted_ring1,
                     SfiCompareFunc  cmp,
                     gpointer        data)
 {
+  /* always preserves the first of a sublist of consequtive equal elements */
   const SfiRing *r1 = sorted_ring1;
   SfiRing *r2 = NULL;
   if (r1)
@@ -1894,6 +1998,7 @@ sfi_ring_union (const SfiRing  *sorted_set1,
                 SfiCompareFunc  cmp,
                 gpointer        data)
 {
+  /* for two equal elements from both sets, the element from sorted_set1 is picked, the one from sorted_set2 discarded */
   const SfiRing *r1 = sorted_set1, *r2 = sorted_set2;
   SfiRing *d = NULL;
   while (r1 && r2)
@@ -1925,6 +2030,7 @@ sfi_ring_intersection (const SfiRing  *sorted_set1,
                        SfiCompareFunc  cmp,
                        gpointer        data)
 {
+  /* for two equal elements from both sets, only elements from sorted_set1 are picked */
   const SfiRing *r1 = sorted_set1, *r2 = sorted_set2;
   SfiRing *d = NULL;
   while (r1 && r2)
