@@ -141,7 +141,11 @@ sfi_wstore_printf (SfiWStore   *wstore,
   va_list args;
   
   g_return_if_fail (wstore != NULL);
-  
+
+  const gchar *ldir = g_printf_find_localised_directive (format);
+  if (ldir)
+    g_warning ("%s: encountered localised directive \"%s\" in format string: \"%s\"", G_STRFUNC, ldir, format);
+
   va_start (args, format);
   buffer = g_strdup_vprintf (format, args);
   va_end (args);
@@ -152,6 +156,32 @@ sfi_wstore_printf (SfiWStore   *wstore,
   g_free (buffer);
 }
 
+void
+sfi_wstore_putf (SfiWStore      *wstore,
+                 gfloat          vfloat)
+{
+  gchar numbuf[G_ASCII_DTOSTR_BUF_SIZE + 1] = "";
+
+  g_return_if_fail (wstore != NULL);
+
+  g_ascii_formatd (numbuf, G_ASCII_DTOSTR_BUF_SIZE, "%.7g", vfloat);
+
+  sfi_wstore_puts (wstore, numbuf);
+}
+
+void
+sfi_wstore_putd (SfiWStore      *wstore,
+                 gdouble         vdouble)
+{
+  gchar numbuf[G_ASCII_DTOSTR_BUF_SIZE + 1] = "";
+
+  g_return_if_fail (wstore != NULL);
+
+  g_ascii_formatd (numbuf, G_ASCII_DTOSTR_BUF_SIZE, "%.17g", vdouble);
+
+  sfi_wstore_puts (wstore, numbuf);
+}
+
 void
 sfi_wstore_put_value (SfiWStore	   *wstore,
 		      const GValue *value)
@@ -246,7 +276,7 @@ sfi_wstore_peek_text (SfiWStore      *wstore,
   return wstore->text->str;
 }
 
-void
+gint /* -errno */
 sfi_wstore_flush_fd (SfiWStore *wstore,
 		     gint      fd)
 {
@@ -256,9 +286,9 @@ sfi_wstore_flush_fd (SfiWStore *wstore,
   off_t text_offset, binary_offset;
   guint l;
   
-  g_return_if_fail (wstore != NULL);
-  g_return_if_fail (wstore->flushed == FALSE);
-  g_return_if_fail (fd >= 0);
+  g_return_val_if_fail (wstore != NULL, -EINVAL);
+  g_return_val_if_fail (wstore->flushed == FALSE, -EINVAL);
+  g_return_val_if_fail (fd >= 0, -EINVAL);
 
   wstore->flushed = TRUE;
 
@@ -268,11 +298,15 @@ sfi_wstore_flush_fd (SfiWStore *wstore,
   do
     text_offset = lseek (fd, 0, SEEK_CUR);
   while (text_offset < 0 && errno == EINTR);
-  
+  if (text_offset < 0 && errno)
+    return -errno;
+
   /* dump text */
   do
     l = write (fd, wstore->text->str, wstore->text->len);
   while (l < 0 && errno == EINTR);
+  if (l < 0 && errno)
+    return -errno;
   
   /* binary data header */
   if (wstore->bblocks)
@@ -283,6 +317,8 @@ sfi_wstore_flush_fd (SfiWStore *wstore,
       do
 	l = write (fd, term, n);
       while (l < 0 && errno == EINTR);
+      if (l < 0 && errno)
+        return -errno;
     }
   
   /* save binary offset */
@@ -290,6 +326,8 @@ sfi_wstore_flush_fd (SfiWStore *wstore,
     binary_offset = lseek (fd, 0, SEEK_CUR);
   while (binary_offset < 0 && errno == EINTR);
   /* binary_offset is position of the first byte *after* \000 */
+  if (binary_offset < 0 && errno)
+    return -errno;
 
   /* store binary data */
   for (ring = wstore->bblocks; ring; ring = sfi_ring_walk (ring, wstore->bblocks))
@@ -302,11 +340,13 @@ sfi_wstore_flush_fd (SfiWStore *wstore,
 	bblock->offset = lseek (fd, 0, SEEK_CUR);
       while (bblock->offset < 0 && errno == EINTR);
       bblock->length = 0;
+      if (bblock->offset < 0 && errno)
+        return -errno;
       
       /* dump binary */
       do
 	{
-	  n = bblock->reader (bblock->data, bblock->length, buffer, bsize);
+	  n = bblock->reader (bblock->data, buffer, bsize);
 	  if (n < 0)
 	    break;	// FIXME: error handling
 	  g_assert (n <= bsize);
@@ -314,6 +354,8 @@ sfi_wstore_flush_fd (SfiWStore *wstore,
 	    l = write (fd, buffer, n);
 	  while (l < 0 && errno == EINTR);
 	  bblock->length += n;
+          if (l < 0 && errno)
+            return -errno;
 	}
       while (n);
     }
@@ -329,13 +371,20 @@ sfi_wstore_flush_fd (SfiWStore *wstore,
       do
 	foff = lseek (fd, text_offset + bblock->patch_offset, SEEK_SET);
       while (foff < 0 && errno == EINTR);
+      if (foff < 0 && errno)
+        return -errno;
       g_snprintf (ptext, sizeof (ptext), "0x%08x 0x%08x",
 		  (guint32) (bblock->offset - binary_offset),
 		  (guint32) bblock->length);
       do
 	l = write (fd, ptext, sizeof (ptext) - 1);
       while (l < 0 && errno == EINTR);
+      if (l < 0 && errno)
+        return -errno;
     }
+
+  /* finished successfully */
+  return 0;
 }
 
 
@@ -706,13 +755,10 @@ sfi_rstore_get_bin_offset (SfiRStore *rstore)
 }
 
 GTokenType
-sfi_rstore_parse_binary (SfiRStore *rstore,
-			 SfiNum    *offset_p,
-			 SfiNum    *length_p)
+sfi_rstore_parse_zbinary (SfiRStore *rstore,
+                          SfiNum    *offset_p,
+                          SfiNum    *length_p)
 {
-  SfiNum offset, length;
-  GTokenType token;
-
   g_return_val_if_fail (rstore != NULL, G_TOKEN_ERROR);
   g_return_val_if_fail (offset_p && length_p, G_TOKEN_ERROR);
 
@@ -723,17 +769,29 @@ sfi_rstore_parse_binary (SfiRStore *rstore,
     return G_TOKEN_IDENTIFIER;
   if (g_scanner_get_next_token (rstore->scanner) != G_TOKEN_INT)
     return G_TOKEN_INT;
-  offset = rstore->scanner->value.v_int64;
+  SfiNum offset = rstore->scanner->value.v_int64;
   if (g_scanner_get_next_token (rstore->scanner) != G_TOKEN_INT)
     return G_TOKEN_INT;
-  length = rstore->scanner->value.v_int64;
+  SfiNum length = rstore->scanner->value.v_int64;
   if (g_scanner_get_next_token (rstore->scanner) != ')')
     return ')';
-  token = sfi_rstore_ensure_bin_offset (rstore);
+  *offset_p = offset;
+  *length_p = length;
+  return G_TOKEN_NONE;
+}
+
+GTokenType
+sfi_rstore_parse_binary (SfiRStore *rstore,
+			 SfiNum    *offset_p,
+			 SfiNum    *length_p)
+{
+  GTokenType token = sfi_rstore_ensure_bin_offset (rstore);
   if (token != G_TOKEN_NONE)
     return token;
-  *offset_p = rstore->bin_offset + offset;
-  *length_p = length;
+  token = sfi_rstore_parse_zbinary (rstore, offset_p, length_p);
+  if (token != G_TOKEN_NONE)
+    return token;
+  *offset_p += rstore->bin_offset;
   return G_TOKEN_NONE;
 }
 
