@@ -26,7 +26,6 @@ G_BEGIN_DECLS
 
 /* --- typedefs and structures --- */
 typedef gint /* -errno || length */ (*SfiStoreReadBin)  (gpointer        data,
-                                                         SfiNum          pos,
                                                          void           *buffer,
                                                          guint           blength);
 typedef struct
@@ -63,6 +62,7 @@ SfiWStore*      sfi_wstore_new                (void);
 void            sfi_wstore_destroy            (SfiWStore      *wstore);
 void            sfi_wstore_push_level         (SfiWStore      *wstore);
 void            sfi_wstore_pop_level          (SfiWStore      *wstore);
+void            sfi_wstore_break              (SfiWStore      *wstore);
 void            sfi_wstore_puts               (SfiWStore      *wstore,
                                                const gchar    *string);
 void            sfi_wstore_putc               (SfiWStore      *wstore,
@@ -70,7 +70,10 @@ void            sfi_wstore_putc               (SfiWStore      *wstore,
 void            sfi_wstore_printf             (SfiWStore      *wstore,
                                                const gchar    *format,
                                                ...) G_GNUC_PRINTF (2, 3);
-void            sfi_wstore_break              (SfiWStore      *wstore);
+void            sfi_wstore_putf               (SfiWStore      *wstore,
+                                               gfloat          vfloat);
+void            sfi_wstore_putd               (SfiWStore      *wstore,
+                                               gdouble         vdouble);
 void            sfi_wstore_put_value          (SfiWStore      *wstore,
                                                const GValue   *value);
 void            sfi_wstore_put_param          (SfiWStore      *wstore,
@@ -80,7 +83,7 @@ void            sfi_wstore_put_binary         (SfiWStore      *wstore,
                                                SfiStoreReadBin reader,
                                                gpointer        data,
                                                GDestroyNotify  destroy);
-void            sfi_wstore_flush_fd           (SfiWStore      *wstore,
+gint /*-errno*/ sfi_wstore_flush_fd           (SfiWStore      *wstore,
                                                gint            fd);
 const gchar*    sfi_wstore_peek_text          (SfiWStore      *wstore,
                                                guint          *length);
@@ -105,6 +108,9 @@ guint64         sfi_rstore_get_bin_offset     (SfiRStore      *rstore);
 GTokenType      sfi_rstore_parse_binary       (SfiRStore      *rstore,
                                                SfiNum         *offset_p,
                                                SfiNum         *length_p);
+GTokenType      sfi_rstore_parse_zbinary      (SfiRStore      *rstore,
+                                               SfiNum         *offset_p,
+                                               SfiNum         *length_p);
 GTokenType      sfi_rstore_parse_until        (SfiRStore      *rstore,
                                                GTokenType      closing_token,
                                                gpointer        context_data,
