@@ -16,6 +16,7 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307, USA.
  */
+#define _GNU_SOURCE     /* syscall() */
 #include <sfi/sficonfig.h>
 #if	(SFI_HAVE_MUTEXATTR_SETTYPE > 0)
 #define	_XOPEN_SOURCE   600	/* for full pthread facilities */
@@ -53,6 +54,7 @@ struct _SfiThread
   guint64	  awake_stamp;
   GData		 *qdata;
   gint            tid;
+  gpointer        guard_cache;
   /* accounting */
   struct {
     struct timeval stamp;
@@ -68,6 +70,9 @@ struct _SfiThread
   }                info;
 };
 
+/* --- prototypes --- */
+static void     sfi_guard_deregister_all        (SfiThread      *thread);
+static void	sfi_thread_handle_deleted	(SfiThread	*thread);
 
 /* --- variables --- */
 static SfiMutex global_thread_mutex = { 0, };
@@ -82,7 +87,6 @@ static SfiThread*
 sfi_thread_handle_new (const gchar *name)
 {
   SfiThread *thread;
-  gint error = 0;
   
   thread = sfi_new_struct0 (SfiThread, 1);
   thread->func = NULL;
@@ -93,26 +97,18 @@ sfi_thread_handle_new (const gchar *name)
   thread->wakeup_func = NULL;
   thread->wakeup_destroy = NULL;
   thread->tid = -1;
-  if (!error)
+  if (!name)
     {
-      if (!name)
-	{
-	  static guint anon_count = 1;
-	  guint id;
-	  SFI_SYNC_LOCK (&global_thread_mutex);
-	  id = anon_count++;
-	  SFI_SYNC_UNLOCK (&global_thread_mutex);
-	  thread->name = g_strdup_printf ("Foreign%u", id);
-	}
-      else
-	thread->name = g_strdup (name);
-      g_datalist_init (&thread->qdata);
+      static guint anon_count = 1;
+      guint id;
+      SFI_SYNC_LOCK (&global_thread_mutex);
+      id = anon_count++;
+      SFI_SYNC_UNLOCK (&global_thread_mutex);
+      thread->name = g_strdup_printf ("Foreign%u", id);
     }
   else
-    {
-      sfi_delete_struct (SfiThread, thread);
-      thread = NULL;
-    }
+    thread->name = g_strdup (name);
+  g_datalist_init (&thread->qdata);
   return thread;
 }
 
@@ -120,9 +116,6 @@ sfi_thread_handle_new (const gchar *name)
 #include <sys/types.h>
 #include <sys/syscall.h>
 #include <linux/unistd.h>
-#ifdef  __NR_gettid                     /* present on linux >= 2.4.20 */
-static inline _syscall0(pid_t,gettid);  /* declares gettid(); */
-#endif
 #endif
 static void
 thread_get_tid (SfiThread *thread)
@@ -131,7 +124,7 @@ thread_get_tid (SfiThread *thread)
   gint tid = -1;
   
 #if     defined (__linux__) && defined (__NR_gettid)    /* present on linux >= 2.4.20 */
-  tid = gettid ();
+  tid = syscall (__NR_gettid);
 #endif
   if (tid < 0)
     tid = getpid();
@@ -142,29 +135,6 @@ thread_get_tid (SfiThread *thread)
     thread->tid = 0;            /* failed to figure id */
 }
 
-static gpointer
-sfi_thread_exec (gpointer thread)
-{
-  SfiThread *self;
-  sfi_thread_table.thread_set_handle (thread);
-  
-  self = sfi_thread_self ();
-  g_assert (self == thread);
-  
-  thread_get_tid (thread);
-  
-  SFI_SYNC_LOCK (&global_thread_mutex);
-  global_thread_list = sfi_ring_append (global_thread_list, self);
-  sfi_cond_broadcast (&global_thread_cond);
-  SFI_SYNC_UNLOCK (&global_thread_mutex);
-  
-  self->func (self->data);
-  
-  g_datalist_clear (&self->qdata);
-  /* sfi_thread_handle_deleted() does final destruction */
-  return NULL;
-}
-
 static inline unsigned long long int
 timeval_usecs (const struct timeval *tv)
 {
@@ -188,14 +158,14 @@ thread_info_from_stat_L (SfiThread *self,
   char state = 0, command[8192 + 1] = { 0 };
   FILE *file = NULL;
   int n = 0;
-  static int success = 1;
-  if (success)
+  static int have_stat = 1;
+  if (have_stat)
     {
       gchar *filename = g_strdup_printf ("/proc/%u/stat", self->tid);
       file = fopen (filename, "r");
       g_free (filename);
       if (!file)
-        success = 0;    /* reading /proc/self/stat should _always_ succeed */
+        have_stat = 0;  /* reading /proc/self/stat should always succeed, so try only once */
     }
   if (file)
     n = fscanf (file,
@@ -230,7 +200,8 @@ thread_info_from_stat_L (SfiThread *self,
 #define ACCOUNTING_MSECS        (500)
 
 static inline void
-sfi_thread_accounting_L (SfiThread *self)
+sfi_thread_accounting_L (SfiThread *self,
+                         gboolean   force_update)
 {
   struct timeval stamp, ostamp = self->ac.stamp;
   guint diff = 0;
@@ -240,12 +211,12 @@ sfi_thread_accounting_L (SfiThread *self)
       diff = timeval_usecs (&stamp) - timeval_usecs (&ostamp);
       diff = MAX (diff, 0);
     }
-  if (diff >= ACCOUNTING_MSECS * 1000)  /* limit accounting to a few times per second */
+  if (force_update || diff >= ACCOUNTING_MSECS * 1000)  /* limit accounting to a few times per second */
     {
       struct rusage res = { { 0 } };
       gint64 utime = self->ac.utime;
       gint64 stime = self->ac.stime;
-      gdouble dfact = 1000000.0 / diff;
+      gdouble dfact = 1000000.0 / MAX (diff, 1);
       self->ac.stamp = stamp;
       getrusage (RUSAGE_SELF, &res);
       self->ac.utime = timeval_usecs (&res.ru_utime); /* user time used */
@@ -265,11 +236,34 @@ sfi_thread_accounting_L (SfiThread *self)
     }
 }
 
-void
+static gpointer
+sfi_thread_exec (gpointer thread)
+{
+  SfiThread *self;
+  sfi_thread_table.thread_set_handle (thread);
+  
+  self = sfi_thread_self ();
+  g_assert (self == thread);
+  
+  thread_get_tid (thread);
+  
+  SFI_SYNC_LOCK (&global_thread_mutex);
+  global_thread_list = sfi_ring_append (global_thread_list, self);
+  self->accounting = 1;
+  sfi_thread_accounting_L (self, TRUE);
+  sfi_cond_broadcast (&global_thread_cond);
+  SFI_SYNC_UNLOCK (&global_thread_mutex);
+  
+  self->func (self->data);
+
+  /* sfi_thread_handle_deleted() does final destruction */
+  return NULL;
+}
+
+static void
 sfi_thread_handle_deleted (SfiThread *thread)
 {
-  g_datalist_clear (&thread->qdata);
-  
+  thread->wakeup_func = NULL;
   if (thread->wakeup_destroy)
     {
       GDestroyNotify wakeup_destroy = thread->wakeup_destroy;
@@ -277,6 +271,10 @@ sfi_thread_handle_deleted (SfiThread *thread)
       wakeup_destroy (thread->wakeup_data);
     }
   
+  g_datalist_clear (&thread->qdata);
+  
+  sfi_guard_deregister_all (thread);
+
   SFI_SYNC_LOCK (&global_thread_mutex);
   global_thread_list = sfi_ring_remove (global_thread_list, thread);
   if (thread->awake_stamp)
@@ -423,6 +421,36 @@ sfi_thread_self_pid (void)
   return sfi_thread_self ()->tid;
 }
 
+/**
+ * sfi_thread_get_pid
+ * @thread:  a valid %SfiThread handle
+ * @RETURNS: thread id
+ * Return the specific id for @thread. This function is highly
+ * system dependant. The thread id may deviate from the overall
+ * process id or not. On linux, threads have their own id,
+ * allthough since kernel 2.6, they share the same process id.
+ */
+gint
+sfi_thread_get_pid (SfiThread *thread)
+{
+  thread = thread ? thread : sfi_thread_self();
+  return thread->tid;
+}
+
+/**
+ * sfi_thread_get_name
+ * @thread:  a valid %SfiThread handle
+ * @RETURNS: thread name
+ * Return the name of @thread as specified upon invokation of
+ * sfi_thread_run() or assigned by sfi_thread_set_name().
+ */
+const gchar*
+sfi_thread_get_name (SfiThread *thread)
+{
+  thread = thread ? thread : sfi_thread_self();
+  return thread->name;
+}
+
 static void
 sfi_thread_wakeup_L (SfiThread *thread)
 {
@@ -459,7 +487,7 @@ sfi_thread_sleep (glong max_useconds)
       sfi_cond_init (self->wakeup_cond);
     }
   
-  sfi_thread_accounting_L (self);
+  sfi_thread_accounting_L (self, FALSE);
   
   if (!self->got_wakeup && max_useconds != 0)
     {
@@ -485,7 +513,9 @@ sfi_thread_sleep (glong max_useconds)
  * Set the wakeup function for the current thread. This enables
  * the thread to be woken up through sfi_thread_wakeup() even
  * if not sleeping in sfi_thread_sleep(). The wakeup function
- * must be thread-safe, so it may be called from any thread.
+ * must be thread-safe, so it may be called from any thread,
+ * and it should be fast, because the global thread system lock
+ * is held during its invokation.
  * Per thread, the wakeup function may be set only once.
  */
 void
@@ -636,7 +666,7 @@ sfi_thread_aborted (void)
   gboolean aborted;
   
   SFI_SYNC_LOCK (&global_thread_mutex);
-  sfi_thread_accounting_L (self);
+  sfi_thread_accounting_L (self, FALSE);
   aborted = self->aborted != FALSE;
   SFI_SYNC_UNLOCK (&global_thread_mutex);
   
@@ -734,6 +764,233 @@ sfi_thread_info_free (SfiThreadInfo  *info)
 }
 
 
+/* --- hazard pointer guards --- */
+struct SfiGuard
+{
+  SfiGuard  *next;       /* global guard list */
+  SfiThread *thread;
+  SfiGuard  *cache_next; /* per thread free list */
+  guint      n_values;
+  gpointer   values[1];  /* variable length array */
+};
+static SfiGuard * volatile guard_list = NULL;
+static gint       volatile guard_list_length = 0;
+#define SFI_GUARD_ALIGN  (4)
+#define guard2values(ptr)       G_STRUCT_MEMBER_P (ptr, +G_STRUCT_OFFSET (SfiGuard, values[0]))
+#define values2guard(ptr)       G_STRUCT_MEMBER_P (ptr, -G_STRUCT_OFFSET (SfiGuard, values[0]))
+
+/**
+ * sfi_guard_register
+ * @n_hazards: number of required hazard pointers
+ * @RETURNS:   a valid #SfiGuard
+ * Retrieve a new guard for node protection of the current thread.
+ * The exact mechanism of protection is described in sfi_guard_protect().
+ * Note that sfi_guard_snap_values() will walk the hazard pointer
+ * array in ascending order, so that pointers may migrate from array
+ * positions with a lower index to positions with a higher index while
+ * retaining protection, according to condition C2 as described in
+ * http://www.research.ibm.com/people/m/michael/podc-2002.pdf.
+ * If an equally or bigger sized hazard pointer array was previously
+ * deregistered by this thread, registration takes constant time.
+ */
+SfiGuard*
+sfi_guard_register (guint n_hazards)
+{
+  SfiThread *thread = sfi_thread_self();
+  SfiGuard *guard, *last = NULL;
+  /* reuse cached guards */
+  for (guard = thread->guard_cache; guard; last = guard, guard = last->cache_next)
+    if (n_hazards <= guard->n_values)
+      {
+        if (last)
+          last->cache_next = guard->cache_next;
+        else
+          thread->guard_cache = guard->cache_next;
+        guard->cache_next = NULL;
+        break;
+      }
+  /* allocate new guard */
+  if (!guard)
+    {
+      n_hazards = ((MAX (n_hazards, 3) + SFI_GUARD_ALIGN - 1) / SFI_GUARD_ALIGN) * SFI_GUARD_ALIGN;
+      g_atomic_int_add ((gint*) &guard_list_length, n_hazards);
+      guard = g_malloc0 (sizeof (SfiGuard) + (n_hazards - 1) * sizeof (guard->values[0]));
+      guard->n_values = n_hazards;
+      guard->thread = thread;
+      do
+        guard->next = g_atomic_pointer_get (&guard_list);
+      while (!g_atomic_pointer_compare_and_exchange ((gpointer) &guard_list, guard->next, guard));
+    }
+  return guard2values (guard);
+}
+
+/**
+ * sfi_guard_deregister
+ * @guard: a valid #SfiGuard as returned from sfi_guard_register()
+ * Deregister a guard previously registered by a call to sfi_guard_register().
+ * Deregistration is performed in constant time.
+ */
+void
+sfi_guard_deregister (SfiGuard *guard)
+{
+  guard = values2guard (guard);
+  SfiThread *thread = sfi_thread_self();
+  g_return_if_fail (guard->thread == thread);
+  memset (guard->values, 0, sizeof (guard->values[0]) * guard->n_values);
+  /* must we have a memory barrier here? */
+  guard->cache_next = thread->guard_cache;
+  thread->guard_cache = guard;
+}
+
+static void
+sfi_guard_deregister_all (SfiThread *thread)
+{
+  SfiGuard *guard;
+  thread->guard_cache = NULL;
+  for (guard = g_atomic_pointer_get (&guard_list); guard; guard = guard->next)
+    if (guard->thread == thread)
+      {
+        memset (guard->values, 0, sizeof (guard->values[0]) * guard->n_values);
+        guard->cache_next = NULL;
+        g_atomic_pointer_compare_and_exchange ((gpointer*) &guard->thread, thread, NULL); /* reset ->thread with memory barrier */
+      }
+}
+
+/**
+ * sfi_guard_protect
+ * @guard:      a valid #SfiGuard as returned from sfi_guard_register()
+ * @nth_hazard: index of the hazard pointer to use for protection
+ * @value:      a hazardous pointer value or %NULL to reset protection
+ * Protect the node pointed to by @value from being destroyed by another
+ * thread and against the ABA problem caused by premature reuse.
+ * For this to work, threads destroying nodes of the type pointed to by
+ * @value need to suspend destruction as long as nodes are protected,
+ * which can by checked by calls to sfi_guard_is_protected() or by
+ * searching the values returned from sfi_guard_snap_values().
+ * Descriptions of safe memory reclamation and ABA problem detection
+ * via hazard pointers guards can be found in
+ * http://www.research.ibm.com/people/m/michael/podc-2002.pdf,
+ * http://www.cs.brown.edu/people/mph/HerlihyLM02/smli_tr-2002-112.pdf,
+ * http://research.sun.com/scalable/Papers/CATS2003.pdf and
+ * http://www.research.ibm.com/people/m/michael/ieeetpds-2004.pdf.
+ * The exact sequence of steps to protect and access a node is as follows:
+ * @* 1) Store the adress of a node to be protected in a hazard pointer
+ * @* 2) Verify that the hazard pointer points to a valid node
+ * @* 3) Dereference the node only as long as it's protected by the hazard pointer.
+ * @* For example:
+ * @* 0: SfiGuard *guard = sfi_guard_register (1);
+ * @* 1: peek_head_label:
+ * @* 2: auto GSList *node = shared_list_head;
+ * @* 3: sfi_guard_protect (guard, 0, node);
+ * @* 4: if (node != shared_list_head) goto peek_head_label;
+ * @* 5: operate_on_protected_node (node);
+ * @* 6: sfi_guard_deregister (guard);
+ */
+#if 0
+static inline
+void sfi_guard_protect (SfiGuard *guard,  /* defined in sfithreads.h */
+                        guint     nth_hazard,
+                        gpointer  value);
+#endif
+
+/**
+ * sfi_guard_n_snap_values
+ * @RETURNS:   an upper bound on the number of registered hazard pointers
+ * Retrieve an upper bound on the number of hazard pointer value slots
+ * currently required for a successfull call to sfi_guard_snap_values().
+ * Note that a subsequent call to sfi_guard_snap_values() may still fail
+ * due to addtional guards being registerted meanwhile. In such a case
+ * sfi_guard_n_snap_values() and sfi_guard_snap_values() can simply be
+ * called again.
+ */
+guint
+sfi_guard_n_snap_values (void)
+{
+  return g_atomic_int_get ((gint*) &guard_list_length);
+}
+
+/**
+ * sfi_guard_snap_values
+ * @n_values:  location of n_values variable
+ * @values:    value array to fill in
+ * @RETURNS:   %TRUE if @values provided enough space and is filled
+ * Make a snapshot of all non-NULL hazard pointer values.
+ * %TRUE is returned if the number of non-NULL hazard pointer
+ * values didn't exceed the size of the input value array provided
+ * by @n_values, and all values are returned in the array pointed
+ * to by @values.
+ * The number of values filled in is returned in @n_values.
+ * %FALSE is returned if not enough space was available to return
+ * all non-NULL values. sfi_guard_n_snap_values() may be used to
+ * retrieve the current upper bound on the number of registered
+ * guards. Note that a successive call to sfi_guard_snap_values() with
+ * the requested number of value slots supplied may still fail,
+ * because additional guards may have been registered meanwhile.
+ * In such a case sfi_guard_n_snap_values() and sfi_guard_snap_values()
+ * can simply be called again.
+ * This funciton will always walk the hazard pointer arrays supplied
+ * by sfi_guard_register() in ascending order, to allow pointer migration
+ * from lower to higher array indieces while retaining protection.
+ * The returned pointer values are unordered, so in order to perform
+ * multiple pointer lookups, we recommend sorting the returned array
+ * and then doing binary lookups. However if only a single pointer
+ * is to be looked up, calling sfi_guard_is_protected() should be
+ * considered.
+ */
+gboolean
+sfi_guard_snap_values (guint          *n_values,
+                       gpointer       *values)
+{
+  guint i, n = 0;
+  SfiGuard *guard;
+  for (guard = g_atomic_pointer_get (&guard_list); guard; guard = guard->next)
+    if (guard->thread)
+      for (i = 0; i < guard->n_values; i++)
+        {
+          gpointer v = guard->values[i];
+          if (v)
+            {
+              n++;
+              if (n > *n_values)
+                return FALSE;   /* not enough space provided */
+              *values++ = v;
+            }
+        }
+  *n_values = n;                /* number of values used */
+  return TRUE;
+}
+
+/**
+ * sfi_guard_is_protected
+ * @value:    hazard pointer value
+ * @RETURNS:  %TRUE if a hazard pointer protecting @value has been found
+ * Check whether @value is protected by a hazard pointer guard.
+ * If multiple pointer values are to be checked, use sfi_guard_snap_values()
+ * instead, as this function has O(n_hazard_pointers) time complexity.
+ * If only one pointer value needs to be looked up though,
+ * calling sfi_guard_is_protected() will provide a result faster than
+ * calling sfi_guard_snap_values() and looking up the pointer in the
+ * filled-in array.
+ * Lookup within hazard pointer arrays will always occour in ascending
+ * order to allow pointer migration as described in sfi_guard_snap_values()
+ * and sfi_guard_register().
+ */
+gboolean
+sfi_guard_is_protected (gpointer value)
+{
+  if (value)
+    {
+      SfiGuard *guard;
+      guint i;
+      for (guard = g_atomic_pointer_get (&guard_list); guard; guard = guard->next)
+        if (guard->thread)
+          for (i = 0; i < guard->n_values; i++)
+            if (guard->values[i] == value)
+              return TRUE;
+    }
+  return FALSE;
+}
+
 /* --- fallback (GLib) SfiThreadTable --- */
 static GPrivate *fallback_thread_table_key = NULL;
 
@@ -1060,7 +1317,9 @@ _sfi_init_threads (void)
   sfi_mutex_init (&global_thread_mutex);
   sfi_cond_init (&global_thread_cond);
   
-  _sfi_init_memory ();
+  _sfi_init_logging ();
   
+  _sfi_init_memory ();
+
   sfi_thread_self ();
 }
