@@ -15,12 +15,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
-#include "bsewavetool.h"
+#include "bsewavetool.hh"
 #include "topconfig.h"
 #include "sfiutils.h"
-#include "bwtwave.h"
+#include "bwtwave.hh"
 #include <bse/bsemain.h>	/* for bse_init_intern() */
-#include <bse/gslloader.h>
+#include <bse/bseloader.h>
 #include <bse/gslvorbis-enc.h>
 #include <bse/gsldatahandle-vorbis.h>
 #include <stdlib.h>
@@ -52,15 +52,22 @@ list<string>   unlink_file_list;
 
 /* --- main program --- */
 static void
-wavetool_log_handler (SfiLogMessage  *msg)
+wavetool_log_handler (const SfiMessage  *msg)
 {
-  if (msg->level == SFI_LOG_INFO)
+  if (msg->type == SFI_MSG_INFO)
     {
       if (!quiet_infos)
-        g_printerr ("%s\n", msg->message);
+        {
+          if (msg->primary)
+            g_printerr ("%s\n", msg->primary);
+          if (msg->secondary)
+            g_printerr ("%s\n", msg->secondary);
+          if (msg->details)
+            g_printerr ("%s\n", msg->details);
+        }
     }
   else
-    sfi_log_default_handler (msg);
+    sfi_msg_default_handler (msg);
 }
 
 extern "C" int
@@ -79,9 +86,9 @@ main (int   argc,
   sfi_init ();
   int orig_argc = argc;
   bse_init_intern (&argc, &argv, NULL);
-  sfi_debug_allow ("main"); // FIXME
-  sfi_log_set_thread_handler (wavetool_log_handler);
-  sfi_log_assign_level (SFI_LOG_INFO, SFI_LOG_TO_HANDLER);
+  sfi_msg_allow ("main"); // FIXME
+  sfi_msg_set_thread_handler (wavetool_log_handler);
+  sfi_msg_type_configure (SFI_MSG_INFO, SFI_MSG_TO_HANDLER, NULL);
   
   /* pre-parse argument list to decide command */
   wavetool_parse_args (&argc, &argv);
@@ -141,21 +148,21 @@ main (int   argc,
   BseErrorType error = BSE_ERROR_NONE;
   if (!wave)
     {
-      GslWaveFileInfo *winfo = gsl_wave_file_info_load (input_file.c_str(), &error);
+      BseWaveFileInfo *winfo = bse_wave_file_info_load (input_file.c_str(), &error);
       if (winfo && winfo->n_waves == 1)
         {
-          GslWaveDsc *wdsc = gsl_wave_dsc_load (winfo, 0, TRUE, &error);
+          BseWaveDsc *wdsc = bse_wave_dsc_load (winfo, 0, TRUE, &error);
           if (wdsc)
             {
               wave = new Wave (wdsc->name, wdsc->n_channels, wdsc->xinfos);
               guint i;
               for (i = 0; i < wdsc->n_chunks; i++)
                 {
-                  GslDataHandle *dhandle = gsl_wave_handle_create (wdsc, i, &error);
+                  GslDataHandle *dhandle = bse_wave_handle_create (wdsc, i, &error);
                   if (!dhandle)
                     {
                       sfi_warning ("failed to load wave chunk (%.3f) of wave \"%s\" in file \"%s\": %s (loader: %s)",
-                                   wdsc->chunks[i].osc_freq, wdsc->name, input_file.c_str(), bse_error_blurb (error), gsl_wave_file_info_loader (winfo));
+                                   wdsc->chunks[i].osc_freq, wdsc->name, input_file.c_str(), bse_error_blurb (error), bse_wave_file_info_loader (winfo));
                       if (continue_on_error)
                         error = BSE_ERROR_NONE;
                       else
@@ -171,15 +178,15 @@ main (int   argc,
                       gsl_data_handle_unref (dhandle);
                     }
                 }
-              gsl_wave_dsc_free (wdsc);
+              bse_wave_dsc_free (wdsc);
             }
           else
             {
               sfi_warning ("failed to load wave description from file \"%s\": %s (loader: %s)",
-                           input_file.c_str(), bse_error_blurb (error), gsl_wave_file_info_loader (winfo));
+                           input_file.c_str(), bse_error_blurb (error), bse_wave_file_info_loader (winfo));
               error = BSE_ERROR_NONE;
             }
-          gsl_wave_file_info_unref (winfo);
+          bse_wave_file_info_unref (winfo);
         }
     }
   if (!wave && !error)
@@ -297,10 +304,10 @@ wavetool_parse_args (int    *argc_p,
 
   envar = getenv ("BSEWAVETOOL_DEBUG");
   if (envar)
-    sfi_debug_allow (envar);
+    sfi_msg_allow (envar);
   envar = getenv ("BSEWAVETOOL_NO_DEBUG");
   if (envar)
-    sfi_debug_deny (envar);
+    sfi_msg_deny (envar);
   
   for (i = 1; i < argc; i++)
     {
@@ -317,9 +324,9 @@ wavetool_parse_args (int    *argc_p,
           exit (0);
         }
       else if (parse_str_option (argv, i, "--debug", str, argc))
-        sfi_debug_allow (str);
+        sfi_msg_allow (str);
       else if (parse_str_option (argv, i, "--no-debug", str, argc))
-        sfi_debug_deny (str);
+        sfi_msg_deny (str);
       else if (parse_bool_option (argv, i, "-h") ||
                parse_bool_option (argv, i, "--help"))
         {
@@ -812,21 +819,21 @@ public:
     GslDataHandle *dhandle = NULL;
     const char *sample_file = opt.sample_file;
     /* load sample file, auto-detecting file type */
-    GslWaveFileInfo *winfo = gsl_wave_file_info_load (sample_file, &error);
+    BseWaveFileInfo *winfo = bse_wave_file_info_load (sample_file, &error);
     if (winfo && winfo->n_waves == 1)
       {
-        GslWaveDsc *wdsc = gsl_wave_dsc_load (winfo, 0, TRUE, &error);
+        BseWaveDsc *wdsc = bse_wave_dsc_load (winfo, 0, TRUE, &error);
         if (wdsc && wdsc->n_chunks == 1)
-          dhandle = gsl_wave_handle_create (wdsc, 0, &error);
+          dhandle = bse_wave_handle_create (wdsc, 0, &error);
         else if (wdsc)
           error = BSE_ERROR_FORMAT_INVALID;
         if (wdsc)
-          gsl_wave_dsc_free (wdsc);
+          bse_wave_dsc_free (wdsc);
       }
     else if (winfo)
       error = BSE_ERROR_FORMAT_INVALID;
     if (winfo)
-      gsl_wave_file_info_unref (winfo);
+      bse_wave_file_info_unref (winfo);
     return dhandle;
   }
   GslDataHandle*
@@ -919,8 +926,9 @@ public:
             }
           if (error)
             {
-              (continue_on_error ? sfi_warning : sfi_error) ("failed to add wave chunk from file \"%s\": %s",
-                                                             ochunk.sample_file, bse_error_blurb (error));
+              sfi_msg_log (continue_on_error ? SFI_MSG_WARNING : SFI_MSG_ERROR,
+                           SFI_MSG_PRIMARY (_("failed to add wave chunk from file \"%s\": %s"),
+                                            ochunk.sample_file, bse_error_blurb (error)));
               if (!continue_on_error)
                 exit (1);
             }
